Class: KlaviyoAPI::AgeGateProperties

Inherits:
Object
  • Object
show all
Defined in:
lib/klaviyo-api-sdk/models/age_gate_properties.rb

Defined Under Namespace

Classes: EnumAttributeValidator

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ AgeGateProperties

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
# File 'lib/klaviyo-api-sdk/models/age_gate_properties.rb', line 103

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `KlaviyoAPI::AgeGateProperties` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!self.class.attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `KlaviyoAPI::AgeGateProperties`. Please check the name to make sure it's valid. List of attributes: " + self.class.attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'display_device')
    if (value = attributes[:'display_device']).is_a?(Array)
      self.display_device = value
    end
  end

  if attributes.key?(:'label')
    self.label = attributes[:'label']
  end

  if attributes.key?(:'show_label')
    self.show_label = attributes[:'show_label']
  else
    self.show_label = false
  end

  if attributes.key?(:'placeholder')
    self.placeholder = attributes[:'placeholder']
  end

  if attributes.key?(:'error_messages')
    self.error_messages = attributes[:'error_messages']
  end

  if attributes.key?(:'property_name')
    self.property_name = attributes[:'property_name']
  else
    self.property_name = '$age_gated_date_of_birth'
  end

  if attributes.key?(:'date_format')
    self.date_format = attributes[:'date_format']
  else
    self.date_format = 'MM/DD/YYYY'
  end

  if attributes.key?(:'sms_country_code')
    self.sms_country_code = attributes[:'sms_country_code']
  else
    self.sms_country_code = 'US'
  end

  if attributes.key?(:'required')
    self.required = attributes[:'required']
  else
    self.required = true
  end
end

Instance Attribute Details

#date_formatObject

Returns the value of attribute date_format.



29
30
31
# File 'lib/klaviyo-api-sdk/models/age_gate_properties.rb', line 29

def date_format
  @date_format
end

#display_deviceObject

Returns the value of attribute display_device.



17
18
19
# File 'lib/klaviyo-api-sdk/models/age_gate_properties.rb', line 17

def display_device
  @display_device
end

#error_messagesObject

Returns the value of attribute error_messages.



25
26
27
# File 'lib/klaviyo-api-sdk/models/age_gate_properties.rb', line 25

def error_messages
  @error_messages
end

#labelObject

Returns the value of attribute label.



19
20
21
# File 'lib/klaviyo-api-sdk/models/age_gate_properties.rb', line 19

def label
  @label
end

#placeholderObject

Returns the value of attribute placeholder.



23
24
25
# File 'lib/klaviyo-api-sdk/models/age_gate_properties.rb', line 23

def placeholder
  @placeholder
end

#property_nameObject

Returns the value of attribute property_name.



27
28
29
# File 'lib/klaviyo-api-sdk/models/age_gate_properties.rb', line 27

def property_name
  @property_name
end

#requiredObject

Returns the value of attribute required.



34
35
36
# File 'lib/klaviyo-api-sdk/models/age_gate_properties.rb', line 34

def required
  @required
end

#show_labelObject

Returns the value of attribute show_label.



21
22
23
# File 'lib/klaviyo-api-sdk/models/age_gate_properties.rb', line 21

def show_label
  @show_label
end

#sms_country_codeObject

SMS County Code Enum.



32
33
34
# File 'lib/klaviyo-api-sdk/models/age_gate_properties.rb', line 32

def sms_country_code
  @sms_country_code
end

Class Method Details

.acceptable_attributesObject

Returns all the JSON keys this model knows about



74
75
76
# File 'lib/klaviyo-api-sdk/models/age_gate_properties.rb', line 74

def self.acceptable_attributes
  attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



59
60
61
62
63
64
65
66
67
68
69
70
71
# File 'lib/klaviyo-api-sdk/models/age_gate_properties.rb', line 59

def self.attribute_map
  {
    :'display_device' => :'display_device',
    :'label' => :'label',
    :'show_label' => :'show_label',
    :'placeholder' => :'placeholder',
    :'error_messages' => :'error_messages',
    :'property_name' => :'property_name',
    :'date_format' => :'date_format',
    :'sms_country_code' => :'sms_country_code',
    :'required' => :'required'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



245
246
247
# File 'lib/klaviyo-api-sdk/models/age_gate_properties.rb', line 245

def self.build_from_hash(attributes)
  new.build_from_hash(attributes)
end

.openapi_nullableObject

List of attributes with nullable: true



94
95
96
97
98
99
# File 'lib/klaviyo-api-sdk/models/age_gate_properties.rb', line 94

def self.openapi_nullable
  Set.new([
    :'label',
    :'placeholder',
  ])
end

.openapi_typesObject

Attribute type mapping.



79
80
81
82
83
84
85
86
87
88
89
90
91
# File 'lib/klaviyo-api-sdk/models/age_gate_properties.rb', line 79

def self.openapi_types
  {
    :'display_device' => :'Array<String>',
    :'label' => :'String',
    :'show_label' => :'Boolean',
    :'placeholder' => :'String',
    :'error_messages' => :'ErrorMessages',
    :'property_name' => :'String',
    :'date_format' => :'String',
    :'sms_country_code' => :'String',
    :'required' => :'Boolean'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



216
217
218
219
220
221
222
223
224
225
226
227
228
# File 'lib/klaviyo-api-sdk/models/age_gate_properties.rb', line 216

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      display_device == o.display_device &&
      label == o.label &&
      show_label == o.show_label &&
      placeholder == o.placeholder &&
      error_messages == o.error_messages &&
      property_name == o.property_name &&
      date_format == o.date_format &&
      sms_country_code == o.sms_country_code &&
      required == o.required
end

#_deserialize(type, value) ⇒ Object

Deserializes the data based on type

Parameters:

  • string

    type Data type

  • string

    value Value to be deserialized

Returns:

  • (Object)

    Deserialized data



276
277
278
279
280
281
282
283
284
285
286
287
288
289
290
291
292
293
294
295
296
297
298
299
300
301
302
303
304
305
306
307
308
309
310
311
312
313
# File 'lib/klaviyo-api-sdk/models/age_gate_properties.rb', line 276

def _deserialize(type, value)
  case type.to_sym
  when :Time
    Time.parse(value)
  when :Date
    Date.parse(value)
  when :String
    value.to_s
  when :Integer
    value.to_i
  when :Float
    value.to_f
  when :Boolean
    if value.to_s =~ /\A(true|t|yes|y|1)\z/i
      true
    else
      false
    end
  when :Object
    # generic object (usually a Hash), return directly
    value
  when /\AArray<(?<inner_type>.+)>\z/
    inner_type = Regexp.last_match[:inner_type]
    value.map { |v| _deserialize(inner_type, v) }
  when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/
    k_type = Regexp.last_match[:k_type]
    v_type = Regexp.last_match[:v_type]
    {}.tap do |hash|
      value.each do |k, v|
        hash[_deserialize(k_type, k)] = _deserialize(v_type, v)
      end
    end
  else # model
    # models (e.g. Pet) or oneOf
    klass = KlaviyoAPI.const_get(type)
    klass.respond_to?(:openapi_one_of) ? klass.build(value) : klass.build_from_hash(value)
  end
end

#_to_hash(value) ⇒ Hash

Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value

Parameters:

  • value (Object)

    Any valid value

Returns:

  • (Hash)

    Returns the value in the form of hash



347
348
349
350
351
352
353
354
355
356
357
358
359
# File 'lib/klaviyo-api-sdk/models/age_gate_properties.rb', line 347

def _to_hash(value)
  if value.is_a?(Array)
    value.compact.map { |v| _to_hash(v) }
  elsif value.is_a?(Hash)
    {}.tap do |hash|
      value.each { |k, v| hash[k] = _to_hash(v) }
    end
  elsif value.respond_to? :to_hash
    value.to_hash
  else
    value
  end
end

#build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



252
253
254
255
256
257
258
259
260
261
262
263
264
265
266
267
268
269
270
# File 'lib/klaviyo-api-sdk/models/age_gate_properties.rb', line 252

def build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  self.class.openapi_types.each_pair do |key, type|
    if attributes[self.class.attribute_map[key]].nil? && self.class.openapi_nullable.include?(key)
      self.send("#{key}=", nil)
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[self.class.attribute_map[key]].is_a?(Array)
        self.send("#{key}=", attributes[self.class.attribute_map[key]].map { |v| _deserialize($1, v) })
      end
    elsif !attributes[self.class.attribute_map[key]].nil?
      self.send("#{key}=", _deserialize(type, attributes[self.class.attribute_map[key]]))
    end
  end

  self
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


232
233
234
# File 'lib/klaviyo-api-sdk/models/age_gate_properties.rb', line 232

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



238
239
240
# File 'lib/klaviyo-api-sdk/models/age_gate_properties.rb', line 238

def hash
  [display_device, label, show_label, placeholder, error_messages, property_name, date_format, sms_country_code, required].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



167
168
169
170
# File 'lib/klaviyo-api-sdk/models/age_gate_properties.rb', line 167

def list_invalid_properties
  invalid_properties = Array.new
  invalid_properties
end

#to_bodyHash

to_body is an alias to to_hash (backward compatibility)

Returns:

  • (Hash)

    Returns the object in the form of hash



323
324
325
# File 'lib/klaviyo-api-sdk/models/age_gate_properties.rb', line 323

def to_body
  to_hash
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



329
330
331
332
333
334
335
336
337
338
339
340
341
# File 'lib/klaviyo-api-sdk/models/age_gate_properties.rb', line 329

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#to_sString

Returns the string representation of the object

Returns:

  • (String)

    String presentation of the object



317
318
319
# File 'lib/klaviyo-api-sdk/models/age_gate_properties.rb', line 317

def to_s
  to_hash.to_s
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



174
175
176
177
178
179
180
181
182
# File 'lib/klaviyo-api-sdk/models/age_gate_properties.rb', line 174

def valid?
  property_name_validator = EnumAttributeValidator.new('String', ["$age_gated_date_of_birth"])
  return false unless property_name_validator.valid?(@property_name)
  sms_country_code_validator = EnumAttributeValidator.new('String', ["AT", "AU", "CH", "DE", "ES", "FR", "GB", "IE", "IT", "PT", "US"])
  return false unless sms_country_code_validator.valid?(@sms_country_code)
  required_validator = EnumAttributeValidator.new('Boolean', ["true"])
  return false unless required_validator.valid?(@required)
  true
end