Class: KlaviyoAPI::BaseStyleStyles

Inherits:
Object
  • Object
show all
Defined in:
lib/klaviyo-api-sdk/models/base_style_styles.rb

Defined Under Namespace

Classes: EnumAttributeValidator

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ BaseStyleStyles

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
210
211
212
213
214
# File 'lib/klaviyo-api-sdk/models/base_style_styles.rb', line 142

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `KlaviyoAPI::BaseStyleStyles` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!self.class.attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `KlaviyoAPI::BaseStyleStyles`. Please check the name to make sure it's valid. List of attributes: " + self.class.attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'background_asset_id')
    self.background_asset_id = attributes[:'background_asset_id']
  end

  if attributes.key?(:'background_format')
    self.background_format = attributes[:'background_format']
  end

  if attributes.key?(:'background_position')
    self.background_position = attributes[:'background_position']
  end

  if attributes.key?(:'background_repeat')
    self.background_repeat = attributes[:'background_repeat']
  end

  if attributes.key?(:'background_url')
    self.background_url = attributes[:'background_url']
  end

  if attributes.key?(:'border_color')
    self.border_color = attributes[:'border_color']
  end

  if attributes.key?(:'border_radius')
    self.border_radius = attributes[:'border_radius']
  end

  if attributes.key?(:'border_style')
    self.border_style = attributes[:'border_style']
  end

  if attributes.key?(:'border_width')
    self.border_width = attributes[:'border_width']
  end

  if attributes.key?(:'content_background_color')
    self.content_background_color = attributes[:'content_background_color']
  end

  if attributes.key?(:'inner_padding_bottom')
    self.inner_padding_bottom = attributes[:'inner_padding_bottom']
  end

  if attributes.key?(:'inner_padding_left')
    self.inner_padding_left = attributes[:'inner_padding_left']
  end

  if attributes.key?(:'inner_padding_right')
    self.inner_padding_right = attributes[:'inner_padding_right']
  end

  if attributes.key?(:'inner_padding_top')
    self.inner_padding_top = attributes[:'inner_padding_top']
  end

  if attributes.key?(:'margin_top')
    self.margin_top = attributes[:'margin_top']
  end
end

Instance Attribute Details

#background_asset_idObject

Returns the value of attribute background_asset_id.



17
18
19
# File 'lib/klaviyo-api-sdk/models/base_style_styles.rb', line 17

def background_asset_id
  @background_asset_id
end

#background_formatObject

Background format.



20
21
22
# File 'lib/klaviyo-api-sdk/models/base_style_styles.rb', line 20

def background_format
  @background_format
end

#background_positionObject

Background position.



23
24
25
# File 'lib/klaviyo-api-sdk/models/base_style_styles.rb', line 23

def background_position
  @background_position
end

#background_repeatObject

Returns the value of attribute background_repeat.



25
26
27
# File 'lib/klaviyo-api-sdk/models/base_style_styles.rb', line 25

def background_repeat
  @background_repeat
end

#background_urlObject

Returns the value of attribute background_url.



27
28
29
# File 'lib/klaviyo-api-sdk/models/base_style_styles.rb', line 27

def background_url
  @background_url
end

#border_colorObject

Returns the value of attribute border_color.



29
30
31
# File 'lib/klaviyo-api-sdk/models/base_style_styles.rb', line 29

def border_color
  @border_color
end

#border_radiusObject

Returns the value of attribute border_radius.



31
32
33
# File 'lib/klaviyo-api-sdk/models/base_style_styles.rb', line 31

def border_radius
  @border_radius
end

#border_styleObject

Border style.



34
35
36
# File 'lib/klaviyo-api-sdk/models/base_style_styles.rb', line 34

def border_style
  @border_style
end

#border_widthObject

Returns the value of attribute border_width.



36
37
38
# File 'lib/klaviyo-api-sdk/models/base_style_styles.rb', line 36

def border_width
  @border_width
end

#content_background_colorObject

Returns the value of attribute content_background_color.



38
39
40
# File 'lib/klaviyo-api-sdk/models/base_style_styles.rb', line 38

def content_background_color
  @content_background_color
end

#inner_padding_bottomObject

Returns the value of attribute inner_padding_bottom.



40
41
42
# File 'lib/klaviyo-api-sdk/models/base_style_styles.rb', line 40

def inner_padding_bottom
  @inner_padding_bottom
end

#inner_padding_leftObject

Returns the value of attribute inner_padding_left.



42
43
44
# File 'lib/klaviyo-api-sdk/models/base_style_styles.rb', line 42

def inner_padding_left
  @inner_padding_left
end

#inner_padding_rightObject

Returns the value of attribute inner_padding_right.



44
45
46
# File 'lib/klaviyo-api-sdk/models/base_style_styles.rb', line 44

def inner_padding_right
  @inner_padding_right
end

#inner_padding_topObject

Returns the value of attribute inner_padding_top.



46
47
48
# File 'lib/klaviyo-api-sdk/models/base_style_styles.rb', line 46

def inner_padding_top
  @inner_padding_top
end

#margin_topObject

Returns the value of attribute margin_top.



48
49
50
# File 'lib/klaviyo-api-sdk/models/base_style_styles.rb', line 48

def margin_top
  @margin_top
end

Class Method Details

.acceptable_attributesObject

Returns all the JSON keys this model knows about



94
95
96
# File 'lib/klaviyo-api-sdk/models/base_style_styles.rb', line 94

def self.acceptable_attributes
  attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



73
74
75
76
77
78
79
80
81
82
83
84
85
86
87
88
89
90
91
# File 'lib/klaviyo-api-sdk/models/base_style_styles.rb', line 73

def self.attribute_map
  {
    :'background_asset_id' => :'background_asset_id',
    :'background_format' => :'background_format',
    :'background_position' => :'background_position',
    :'background_repeat' => :'background_repeat',
    :'background_url' => :'background_url',
    :'border_color' => :'border_color',
    :'border_radius' => :'border_radius',
    :'border_style' => :'border_style',
    :'border_width' => :'border_width',
    :'content_background_color' => :'content_background_color',
    :'inner_padding_bottom' => :'inner_padding_bottom',
    :'inner_padding_left' => :'inner_padding_left',
    :'inner_padding_right' => :'inner_padding_right',
    :'inner_padding_top' => :'inner_padding_top',
    :'margin_top' => :'margin_top'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



302
303
304
# File 'lib/klaviyo-api-sdk/models/base_style_styles.rb', line 302

def self.build_from_hash(attributes)
  new.build_from_hash(attributes)
end

.openapi_nullableObject

List of attributes with nullable: true



120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
# File 'lib/klaviyo-api-sdk/models/base_style_styles.rb', line 120

def self.openapi_nullable
  Set.new([
    :'background_asset_id',
    :'background_format',
    :'background_position',
    :'background_repeat',
    :'background_url',
    :'border_color',
    :'border_radius',
    :'border_style',
    :'border_width',
    :'content_background_color',
    :'inner_padding_bottom',
    :'inner_padding_left',
    :'inner_padding_right',
    :'inner_padding_top',
    :'margin_top'
  ])
end

.openapi_typesObject

Attribute type mapping.



99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
# File 'lib/klaviyo-api-sdk/models/base_style_styles.rb', line 99

def self.openapi_types
  {
    :'background_asset_id' => :'String',
    :'background_format' => :'String',
    :'background_position' => :'String',
    :'background_repeat' => :'Boolean',
    :'background_url' => :'String',
    :'border_color' => :'String',
    :'border_radius' => :'Integer',
    :'border_style' => :'String',
    :'border_width' => :'Integer',
    :'content_background_color' => :'String',
    :'inner_padding_bottom' => :'Integer',
    :'inner_padding_left' => :'Integer',
    :'inner_padding_right' => :'Integer',
    :'inner_padding_top' => :'Integer',
    :'margin_top' => :'Integer'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



267
268
269
270
271
272
273
274
275
276
277
278
279
280
281
282
283
284
285
# File 'lib/klaviyo-api-sdk/models/base_style_styles.rb', line 267

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      background_asset_id == o.background_asset_id &&
      background_format == o.background_format &&
      background_position == o.background_position &&
      background_repeat == o.background_repeat &&
      background_url == o.background_url &&
      border_color == o.border_color &&
      border_radius == o.border_radius &&
      border_style == o.border_style &&
      border_width == o.border_width &&
      content_background_color == o.content_background_color &&
      inner_padding_bottom == o.inner_padding_bottom &&
      inner_padding_left == o.inner_padding_left &&
      inner_padding_right == o.inner_padding_right &&
      inner_padding_top == o.inner_padding_top &&
      margin_top == o.margin_top
end

#_deserialize(type, value) ⇒ Object

Deserializes the data based on type

Parameters:

  • string

    type Data type

  • string

    value Value to be deserialized

Returns:

  • (Object)

    Deserialized data



333
334
335
336
337
338
339
340
341
342
343
344
345
346
347
348
349
350
351
352
353
354
355
356
357
358
359
360
361
362
363
364
365
366
367
368
369
370
# File 'lib/klaviyo-api-sdk/models/base_style_styles.rb', line 333

def _deserialize(type, value)
  case type.to_sym
  when :Time
    Time.parse(value)
  when :Date
    Date.parse(value)
  when :String
    value.to_s
  when :Integer
    value.to_i
  when :Float
    value.to_f
  when :Boolean
    if value.to_s =~ /\A(true|t|yes|y|1)\z/i
      true
    else
      false
    end
  when :Object
    # generic object (usually a Hash), return directly
    value
  when /\AArray<(?<inner_type>.+)>\z/
    inner_type = Regexp.last_match[:inner_type]
    value.map { |v| _deserialize(inner_type, v) }
  when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/
    k_type = Regexp.last_match[:k_type]
    v_type = Regexp.last_match[:v_type]
    {}.tap do |hash|
      value.each do |k, v|
        hash[_deserialize(k_type, k)] = _deserialize(v_type, v)
      end
    end
  else # model
    # models (e.g. Pet) or oneOf
    klass = KlaviyoAPI.const_get(type)
    klass.respond_to?(:openapi_one_of) ? klass.build(value) : klass.build_from_hash(value)
  end
end

#_to_hash(value) ⇒ Hash

Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value

Parameters:

  • value (Object)

    Any valid value

Returns:

  • (Hash)

    Returns the value in the form of hash



404
405
406
407
408
409
410
411
412
413
414
415
416
# File 'lib/klaviyo-api-sdk/models/base_style_styles.rb', line 404

def _to_hash(value)
  if value.is_a?(Array)
    value.compact.map { |v| _to_hash(v) }
  elsif value.is_a?(Hash)
    {}.tap do |hash|
      value.each { |k, v| hash[k] = _to_hash(v) }
    end
  elsif value.respond_to? :to_hash
    value.to_hash
  else
    value
  end
end

#build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



309
310
311
312
313
314
315
316
317
318
319
320
321
322
323
324
325
326
327
# File 'lib/klaviyo-api-sdk/models/base_style_styles.rb', line 309

def build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  self.class.openapi_types.each_pair do |key, type|
    if attributes[self.class.attribute_map[key]].nil? && self.class.openapi_nullable.include?(key)
      self.send("#{key}=", nil)
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[self.class.attribute_map[key]].is_a?(Array)
        self.send("#{key}=", attributes[self.class.attribute_map[key]].map { |v| _deserialize($1, v) })
      end
    elsif !attributes[self.class.attribute_map[key]].nil?
      self.send("#{key}=", _deserialize(type, attributes[self.class.attribute_map[key]]))
    end
  end

  self
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


289
290
291
# File 'lib/klaviyo-api-sdk/models/base_style_styles.rb', line 289

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



295
296
297
# File 'lib/klaviyo-api-sdk/models/base_style_styles.rb', line 295

def hash
  [background_asset_id, background_format, background_position, background_repeat, background_url, border_color, border_radius, border_style, border_width, content_background_color, inner_padding_bottom, inner_padding_left, inner_padding_right, inner_padding_top, margin_top].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



218
219
220
221
# File 'lib/klaviyo-api-sdk/models/base_style_styles.rb', line 218

def list_invalid_properties
  invalid_properties = Array.new
  invalid_properties
end

#to_bodyHash

to_body is an alias to to_hash (backward compatibility)

Returns:

  • (Hash)

    Returns the object in the form of hash



380
381
382
# File 'lib/klaviyo-api-sdk/models/base_style_styles.rb', line 380

def to_body
  to_hash
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



386
387
388
389
390
391
392
393
394
395
396
397
398
# File 'lib/klaviyo-api-sdk/models/base_style_styles.rb', line 386

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#to_sString

Returns the string representation of the object

Returns:

  • (String)

    String presentation of the object



374
375
376
# File 'lib/klaviyo-api-sdk/models/base_style_styles.rb', line 374

def to_s
  to_hash.to_s
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



225
226
227
228
229
230
231
232
233
# File 'lib/klaviyo-api-sdk/models/base_style_styles.rb', line 225

def valid?
  background_format_validator = EnumAttributeValidator.new('String', ["auto", "contain", "cover", "initial", "repeat"])
  return false unless background_format_validator.valid?(@background_format)
  background_position_validator = EnumAttributeValidator.new('String', ["center-bottom", "center-center", "center-top", "left-bottom", "left-center", "left-top", "right-bottom", "right-center", "right-top"])
  return false unless background_position_validator.valid?(@background_position)
  border_style_validator = EnumAttributeValidator.new('String', ["dashed", "dotted", "groove", "inset", "none", "outset", "ridge", "solid"])
  return false unless border_style_validator.valid?(@border_style)
  true
end