Class: KlaviyoAPI::ButtonStyles

Inherits:
Object
  • Object
show all
Defined in:
lib/klaviyo-api-sdk/models/button_styles.rb

Defined Under Namespace

Classes: EnumAttributeValidator

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ ButtonStyles

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
# File 'lib/klaviyo-api-sdk/models/button_styles.rb', line 109

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `KlaviyoAPI::ButtonStyles` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!self.class.attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `KlaviyoAPI::ButtonStyles`. Please check the name to make sure it's valid. List of attributes: " + self.class.attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'padding')
    self.padding = attributes[:'padding']
  end

  if attributes.key?(:'background_color')
    self.background_color = attributes[:'background_color']
  end

  if attributes.key?(:'width')
    self.width = attributes[:'width']
  else
    self.width = 'fill'
  end

  if attributes.key?(:'height')
    self.height = attributes[:'height']
  else
    self.height = 50
  end

  if attributes.key?(:'hover_background_color')
    self.hover_background_color = attributes[:'hover_background_color']
  end

  if attributes.key?(:'hover_text_color')
    self.hover_text_color = attributes[:'hover_text_color']
  end

  if attributes.key?(:'border_styles')
    self.border_styles = attributes[:'border_styles']
  end

  if attributes.key?(:'text_styles')
    self.text_styles = attributes[:'text_styles']
  end

  if attributes.key?(:'color')
    self.color = attributes[:'color']
  end

  if attributes.key?(:'drop_shadow')
    self.drop_shadow = attributes[:'drop_shadow']
  end
end

Instance Attribute Details

#background_colorObject

Returns the value of attribute background_color.



19
20
21
# File 'lib/klaviyo-api-sdk/models/button_styles.rb', line 19

def background_color
  @background_color
end

#border_stylesObject

Returns the value of attribute border_styles.



30
31
32
# File 'lib/klaviyo-api-sdk/models/button_styles.rb', line 30

def border_styles
  @border_styles
end

#colorObject

Returns the value of attribute color.



34
35
36
# File 'lib/klaviyo-api-sdk/models/button_styles.rb', line 34

def color
  @color
end

#drop_shadowObject

Returns the value of attribute drop_shadow.



36
37
38
# File 'lib/klaviyo-api-sdk/models/button_styles.rb', line 36

def drop_shadow
  @drop_shadow
end

#heightObject

Returns the value of attribute height.



24
25
26
# File 'lib/klaviyo-api-sdk/models/button_styles.rb', line 24

def height
  @height
end

#hover_background_colorObject

Returns the value of attribute hover_background_color.



26
27
28
# File 'lib/klaviyo-api-sdk/models/button_styles.rb', line 26

def hover_background_color
  @hover_background_color
end

#hover_text_colorObject

Returns the value of attribute hover_text_color.



28
29
30
# File 'lib/klaviyo-api-sdk/models/button_styles.rb', line 28

def hover_text_color
  @hover_text_color
end

#paddingObject

Returns the value of attribute padding.



17
18
19
# File 'lib/klaviyo-api-sdk/models/button_styles.rb', line 17

def padding
  @padding
end

#text_stylesObject

Returns the value of attribute text_styles.



32
33
34
# File 'lib/klaviyo-api-sdk/models/button_styles.rb', line 32

def text_styles
  @text_styles
end

#widthObject

Valid button block widths.



22
23
24
# File 'lib/klaviyo-api-sdk/models/button_styles.rb', line 22

def width
  @width
end

Class Method Details

.acceptable_attributesObject

Returns all the JSON keys this model knows about



77
78
79
# File 'lib/klaviyo-api-sdk/models/button_styles.rb', line 77

def self.acceptable_attributes
  attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



61
62
63
64
65
66
67
68
69
70
71
72
73
74
# File 'lib/klaviyo-api-sdk/models/button_styles.rb', line 61

def self.attribute_map
  {
    :'padding' => :'padding',
    :'background_color' => :'background_color',
    :'width' => :'width',
    :'height' => :'height',
    :'hover_background_color' => :'hover_background_color',
    :'hover_text_color' => :'hover_text_color',
    :'border_styles' => :'border_styles',
    :'text_styles' => :'text_styles',
    :'color' => :'color',
    :'drop_shadow' => :'drop_shadow'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



224
225
226
# File 'lib/klaviyo-api-sdk/models/button_styles.rb', line 224

def self.build_from_hash(attributes)
  new.build_from_hash(attributes)
end

.openapi_nullableObject

List of attributes with nullable: true



98
99
100
101
102
103
104
105
# File 'lib/klaviyo-api-sdk/models/button_styles.rb', line 98

def self.openapi_nullable
  Set.new([
    :'background_color',
    :'hover_background_color',
    :'hover_text_color',
    :'color',
  ])
end

.openapi_typesObject

Attribute type mapping.



82
83
84
85
86
87
88
89
90
91
92
93
94
95
# File 'lib/klaviyo-api-sdk/models/button_styles.rb', line 82

def self.openapi_types
  {
    :'padding' => :'Padding',
    :'background_color' => :'String',
    :'width' => :'String',
    :'height' => :'Integer',
    :'hover_background_color' => :'String',
    :'hover_text_color' => :'String',
    :'border_styles' => :'BorderStyle',
    :'text_styles' => :'TextStyleV0',
    :'color' => :'String',
    :'drop_shadow' => :'ButtonDropShadowStyles'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



194
195
196
197
198
199
200
201
202
203
204
205
206
207
# File 'lib/klaviyo-api-sdk/models/button_styles.rb', line 194

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      padding == o.padding &&
      background_color == o.background_color &&
      width == o.width &&
      height == o.height &&
      hover_background_color == o.hover_background_color &&
      hover_text_color == o.hover_text_color &&
      border_styles == o.border_styles &&
      text_styles == o.text_styles &&
      color == o.color &&
      drop_shadow == o.drop_shadow
end

#_deserialize(type, value) ⇒ Object

Deserializes the data based on type

Parameters:

  • string

    type Data type

  • string

    value Value to be deserialized

Returns:

  • (Object)

    Deserialized data



255
256
257
258
259
260
261
262
263
264
265
266
267
268
269
270
271
272
273
274
275
276
277
278
279
280
281
282
283
284
285
286
287
288
289
290
291
292
# File 'lib/klaviyo-api-sdk/models/button_styles.rb', line 255

def _deserialize(type, value)
  case type.to_sym
  when :Time
    Time.parse(value)
  when :Date
    Date.parse(value)
  when :String
    value.to_s
  when :Integer
    value.to_i
  when :Float
    value.to_f
  when :Boolean
    if value.to_s =~ /\A(true|t|yes|y|1)\z/i
      true
    else
      false
    end
  when :Object
    # generic object (usually a Hash), return directly
    value
  when /\AArray<(?<inner_type>.+)>\z/
    inner_type = Regexp.last_match[:inner_type]
    value.map { |v| _deserialize(inner_type, v) }
  when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/
    k_type = Regexp.last_match[:k_type]
    v_type = Regexp.last_match[:v_type]
    {}.tap do |hash|
      value.each do |k, v|
        hash[_deserialize(k_type, k)] = _deserialize(v_type, v)
      end
    end
  else # model
    # models (e.g. Pet) or oneOf
    klass = KlaviyoAPI.const_get(type)
    klass.respond_to?(:openapi_one_of) ? klass.build(value) : klass.build_from_hash(value)
  end
end

#_to_hash(value) ⇒ Hash

Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value

Parameters:

  • value (Object)

    Any valid value

Returns:

  • (Hash)

    Returns the value in the form of hash



326
327
328
329
330
331
332
333
334
335
336
337
338
# File 'lib/klaviyo-api-sdk/models/button_styles.rb', line 326

def _to_hash(value)
  if value.is_a?(Array)
    value.compact.map { |v| _to_hash(v) }
  elsif value.is_a?(Hash)
    {}.tap do |hash|
      value.each { |k, v| hash[k] = _to_hash(v) }
    end
  elsif value.respond_to? :to_hash
    value.to_hash
  else
    value
  end
end

#build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



231
232
233
234
235
236
237
238
239
240
241
242
243
244
245
246
247
248
249
# File 'lib/klaviyo-api-sdk/models/button_styles.rb', line 231

def build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  self.class.openapi_types.each_pair do |key, type|
    if attributes[self.class.attribute_map[key]].nil? && self.class.openapi_nullable.include?(key)
      self.send("#{key}=", nil)
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[self.class.attribute_map[key]].is_a?(Array)
        self.send("#{key}=", attributes[self.class.attribute_map[key]].map { |v| _deserialize($1, v) })
      end
    elsif !attributes[self.class.attribute_map[key]].nil?
      self.send("#{key}=", _deserialize(type, attributes[self.class.attribute_map[key]]))
    end
  end

  self
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


211
212
213
# File 'lib/klaviyo-api-sdk/models/button_styles.rb', line 211

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



217
218
219
# File 'lib/klaviyo-api-sdk/models/button_styles.rb', line 217

def hash
  [padding, background_color, width, height, hover_background_color, hover_text_color, border_styles, text_styles, color, drop_shadow].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



169
170
171
172
# File 'lib/klaviyo-api-sdk/models/button_styles.rb', line 169

def list_invalid_properties
  invalid_properties = Array.new
  invalid_properties
end

#to_bodyHash

to_body is an alias to to_hash (backward compatibility)

Returns:

  • (Hash)

    Returns the object in the form of hash



302
303
304
# File 'lib/klaviyo-api-sdk/models/button_styles.rb', line 302

def to_body
  to_hash
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



308
309
310
311
312
313
314
315
316
317
318
319
320
# File 'lib/klaviyo-api-sdk/models/button_styles.rb', line 308

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#to_sString

Returns the string representation of the object

Returns:

  • (String)

    String presentation of the object



296
297
298
# File 'lib/klaviyo-api-sdk/models/button_styles.rb', line 296

def to_s
  to_hash.to_s
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



176
177
178
179
180
# File 'lib/klaviyo-api-sdk/models/button_styles.rb', line 176

def valid?
  width_validator = EnumAttributeValidator.new('String', ["fill", "fit"])
  return false unless width_validator.valid?(@width)
  true
end