Class: KlaviyoAPI::CatalogItemCreateQueryAsSubResourceAttributes

Inherits:
Object
  • Object
show all
Defined in:
lib/klaviyo-api-sdk/models/catalog_item_create_query_as_sub_resource_attributes.rb

Defined Under Namespace

Classes: EnumAttributeValidator

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ CatalogItemCreateQueryAsSubResourceAttributes

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
# File 'lib/klaviyo-api-sdk/models/catalog_item_create_query_as_sub_resource_attributes.rb', line 110

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `KlaviyoAPI::CatalogItemCreateQueryAsSubResourceAttributes` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!self.class.attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `KlaviyoAPI::CatalogItemCreateQueryAsSubResourceAttributes`. Please check the name to make sure it's valid. List of attributes: " + self.class.attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'external_id')
    self.external_id = attributes[:'external_id']
  end

  if attributes.key?(:'integration_type')
    self.integration_type = attributes[:'integration_type']
  end

  if attributes.key?(:'title')
    self.title = attributes[:'title']
  end

  if attributes.key?(:'catalog_type')
    self.catalog_type = attributes[:'catalog_type']
  end

  if attributes.key?(:'description')
    self.description = attributes[:'description']
  end

  if attributes.key?(:'url')
    self.url = attributes[:'url']
  end

  if attributes.key?(:'image_full_url')
    self.image_full_url = attributes[:'image_full_url']
  end

  if attributes.key?(:'image_thumbnail_url')
    self.image_thumbnail_url = attributes[:'image_thumbnail_url']
  end

  if attributes.key?(:'images')
    if (value = attributes[:'images']).is_a?(Array)
      self.images = value
    end
  end

  if attributes.key?(:'custom_metadata')
    self. = attributes[:'custom_metadata']
  end

  if attributes.key?(:'published')
    self.published = attributes[:'published']
  end
end

Instance Attribute Details

#catalog_typeObject

Returns the value of attribute catalog_type.



25
26
27
# File 'lib/klaviyo-api-sdk/models/catalog_item_create_query_as_sub_resource_attributes.rb', line 25

def catalog_type
  @catalog_type
end

#custom_metadataObject

Returns the value of attribute custom_metadata.



37
38
39
# File 'lib/klaviyo-api-sdk/models/catalog_item_create_query_as_sub_resource_attributes.rb', line 37

def 
  
end

#descriptionObject

Returns the value of attribute description.



27
28
29
# File 'lib/klaviyo-api-sdk/models/catalog_item_create_query_as_sub_resource_attributes.rb', line 27

def description
  @description
end

#external_idObject

Returns the value of attribute external_id.



18
19
20
# File 'lib/klaviyo-api-sdk/models/catalog_item_create_query_as_sub_resource_attributes.rb', line 18

def external_id
  @external_id
end

#image_full_urlObject

Returns the value of attribute image_full_url.



31
32
33
# File 'lib/klaviyo-api-sdk/models/catalog_item_create_query_as_sub_resource_attributes.rb', line 31

def image_full_url
  @image_full_url
end

#image_thumbnail_urlObject

Returns the value of attribute image_thumbnail_url.



33
34
35
# File 'lib/klaviyo-api-sdk/models/catalog_item_create_query_as_sub_resource_attributes.rb', line 33

def image_thumbnail_url
  @image_thumbnail_url
end

#imagesObject

Returns the value of attribute images.



35
36
37
# File 'lib/klaviyo-api-sdk/models/catalog_item_create_query_as_sub_resource_attributes.rb', line 35

def images
  @images
end

#integration_typeObject

The integration type. Currently, this can only be set to $custom (and defaults to $custom if not included in the payload).



21
22
23
# File 'lib/klaviyo-api-sdk/models/catalog_item_create_query_as_sub_resource_attributes.rb', line 21

def integration_type
  @integration_type
end

#publishedObject

Returns the value of attribute published.



39
40
41
# File 'lib/klaviyo-api-sdk/models/catalog_item_create_query_as_sub_resource_attributes.rb', line 39

def published
  @published
end

#titleObject

Returns the value of attribute title.



23
24
25
# File 'lib/klaviyo-api-sdk/models/catalog_item_create_query_as_sub_resource_attributes.rb', line 23

def title
  @title
end

#urlObject

Returns the value of attribute url.



29
30
31
# File 'lib/klaviyo-api-sdk/models/catalog_item_create_query_as_sub_resource_attributes.rb', line 29

def url
  @url
end

Class Method Details

.acceptable_attributesObject

Returns all the JSON keys this model knows about



81
82
83
# File 'lib/klaviyo-api-sdk/models/catalog_item_create_query_as_sub_resource_attributes.rb', line 81

def self.acceptable_attributes
  attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



64
65
66
67
68
69
70
71
72
73
74
75
76
77
78
# File 'lib/klaviyo-api-sdk/models/catalog_item_create_query_as_sub_resource_attributes.rb', line 64

def self.attribute_map
  {
    :'external_id' => :'external_id',
    :'integration_type' => :'integration_type',
    :'title' => :'title',
    :'catalog_type' => :'catalog_type',
    :'description' => :'description',
    :'url' => :'url',
    :'image_full_url' => :'image_full_url',
    :'image_thumbnail_url' => :'image_thumbnail_url',
    :'images' => :'images',
    :'custom_metadata' => :'custom_metadata',
    :'published' => :'published'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



248
249
250
# File 'lib/klaviyo-api-sdk/models/catalog_item_create_query_as_sub_resource_attributes.rb', line 248

def self.build_from_hash(attributes)
  new.build_from_hash(attributes)
end

.openapi_nullableObject

List of attributes with nullable: true



103
104
105
106
# File 'lib/klaviyo-api-sdk/models/catalog_item_create_query_as_sub_resource_attributes.rb', line 103

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
# File 'lib/klaviyo-api-sdk/models/catalog_item_create_query_as_sub_resource_attributes.rb', line 86

def self.openapi_types
  {
    :'external_id' => :'String',
    :'integration_type' => :'String',
    :'title' => :'String',
    :'catalog_type' => :'String',
    :'description' => :'String',
    :'url' => :'String',
    :'image_full_url' => :'String',
    :'image_thumbnail_url' => :'String',
    :'images' => :'Array<String>',
    :'custom_metadata' => :'Object',
    :'published' => :'Boolean'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



217
218
219
220
221
222
223
224
225
226
227
228
229
230
231
# File 'lib/klaviyo-api-sdk/models/catalog_item_create_query_as_sub_resource_attributes.rb', line 217

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      external_id == o.external_id &&
      integration_type == o.integration_type &&
      title == o.title &&
      catalog_type == o.catalog_type &&
      description == o.description &&
      url == o.url &&
      image_full_url == o.image_full_url &&
      image_thumbnail_url == o.image_thumbnail_url &&
      images == o.images &&
       == o. &&
      published == o.published
end

#_deserialize(type, value) ⇒ Object

Deserializes the data based on type

Parameters:

  • string

    type Data type

  • string

    value Value to be deserialized

Returns:

  • (Object)

    Deserialized data



279
280
281
282
283
284
285
286
287
288
289
290
291
292
293
294
295
296
297
298
299
300
301
302
303
304
305
306
307
308
309
310
311
312
313
314
315
316
# File 'lib/klaviyo-api-sdk/models/catalog_item_create_query_as_sub_resource_attributes.rb', line 279

def _deserialize(type, value)
  case type.to_sym
  when :Time
    Time.parse(value)
  when :Date
    Date.parse(value)
  when :String
    value.to_s
  when :Integer
    value.to_i
  when :Float
    value.to_f
  when :Boolean
    if value.to_s =~ /\A(true|t|yes|y|1)\z/i
      true
    else
      false
    end
  when :Object
    # generic object (usually a Hash), return directly
    value
  when /\AArray<(?<inner_type>.+)>\z/
    inner_type = Regexp.last_match[:inner_type]
    value.map { |v| _deserialize(inner_type, v) }
  when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/
    k_type = Regexp.last_match[:k_type]
    v_type = Regexp.last_match[:v_type]
    {}.tap do |hash|
      value.each do |k, v|
        hash[_deserialize(k_type, k)] = _deserialize(v_type, v)
      end
    end
  else # model
    # models (e.g. Pet) or oneOf
    klass = KlaviyoAPI.const_get(type)
    klass.respond_to?(:openapi_one_of) ? klass.build(value) : klass.build_from_hash(value)
  end
end

#_to_hash(value) ⇒ Hash

Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value

Parameters:

  • value (Object)

    Any valid value

Returns:

  • (Hash)

    Returns the value in the form of hash



350
351
352
353
354
355
356
357
358
359
360
361
362
# File 'lib/klaviyo-api-sdk/models/catalog_item_create_query_as_sub_resource_attributes.rb', line 350

def _to_hash(value)
  if value.is_a?(Array)
    value.compact.map { |v| _to_hash(v) }
  elsif value.is_a?(Hash)
    {}.tap do |hash|
      value.each { |k, v| hash[k] = _to_hash(v) }
    end
  elsif value.respond_to? :to_hash
    value.to_hash
  else
    value
  end
end

#build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



255
256
257
258
259
260
261
262
263
264
265
266
267
268
269
270
271
272
273
# File 'lib/klaviyo-api-sdk/models/catalog_item_create_query_as_sub_resource_attributes.rb', line 255

def build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  self.class.openapi_types.each_pair do |key, type|
    if attributes[self.class.attribute_map[key]].nil? && self.class.openapi_nullable.include?(key)
      self.send("#{key}=", nil)
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[self.class.attribute_map[key]].is_a?(Array)
        self.send("#{key}=", attributes[self.class.attribute_map[key]].map { |v| _deserialize($1, v) })
      end
    elsif !attributes[self.class.attribute_map[key]].nil?
      self.send("#{key}=", _deserialize(type, attributes[self.class.attribute_map[key]]))
    end
  end

  self
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


235
236
237
# File 'lib/klaviyo-api-sdk/models/catalog_item_create_query_as_sub_resource_attributes.rb', line 235

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



241
242
243
# File 'lib/klaviyo-api-sdk/models/catalog_item_create_query_as_sub_resource_attributes.rb', line 241

def hash
  [external_id, integration_type, title, catalog_type, description, url, image_full_url, image_thumbnail_url, images, , published].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
# File 'lib/klaviyo-api-sdk/models/catalog_item_create_query_as_sub_resource_attributes.rb', line 172

def list_invalid_properties
  invalid_properties = Array.new
  if @external_id.nil?
    invalid_properties.push('invalid value for "external_id", external_id cannot be nil.')
  end

  if @title.nil?
    invalid_properties.push('invalid value for "title", title cannot be nil.')
  end

  if @description.nil?
    invalid_properties.push('invalid value for "description", description cannot be nil.')
  end

  if @url.nil?
    invalid_properties.push('invalid value for "url", url cannot be nil.')
  end

  invalid_properties
end

#to_bodyHash

to_body is an alias to to_hash (backward compatibility)

Returns:

  • (Hash)

    Returns the object in the form of hash



326
327
328
# File 'lib/klaviyo-api-sdk/models/catalog_item_create_query_as_sub_resource_attributes.rb', line 326

def to_body
  to_hash
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



332
333
334
335
336
337
338
339
340
341
342
343
344
# File 'lib/klaviyo-api-sdk/models/catalog_item_create_query_as_sub_resource_attributes.rb', line 332

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#to_sString

Returns the string representation of the object

Returns:

  • (String)

    String presentation of the object



320
321
322
# File 'lib/klaviyo-api-sdk/models/catalog_item_create_query_as_sub_resource_attributes.rb', line 320

def to_s
  to_hash.to_s
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



195
196
197
198
199
200
201
202
203
# File 'lib/klaviyo-api-sdk/models/catalog_item_create_query_as_sub_resource_attributes.rb', line 195

def valid?
  return false if @external_id.nil?
  integration_type_validator = EnumAttributeValidator.new('String', ["$custom"])
  return false unless integration_type_validator.valid?(@integration_type)
  return false if @title.nil?
  return false if @description.nil?
  return false if @url.nil?
  true
end