Class: KlaviyoAPI::ConversationsApi
- Inherits:
-
Object
- Object
- KlaviyoAPI::ConversationsApi
- Defined in:
- lib/klaviyo-api-sdk/api/conversations_api.rb
Instance Attribute Summary collapse
-
#api_client ⇒ Object
Returns the value of attribute api_client.
Instance Method Summary collapse
-
#create_conversation_message(conversation_message_create_query, opts = {}) ⇒ nil
Create Conversation Message Send an outbound message to a conversation.
-
#create_conversation_message_with_http_info(conversation_message_create_query, opts = {}) ⇒ Array<(nil, Integer, Hash)>
Create Conversation Message Send an outbound message to a conversation.
-
#initialize(api_client = ApiClient.default) ⇒ ConversationsApi
constructor
A new instance of ConversationsApi.
Constructor Details
#initialize(api_client = ApiClient.default) ⇒ ConversationsApi
Returns a new instance of ConversationsApi.
18 19 20 |
# File 'lib/klaviyo-api-sdk/api/conversations_api.rb', line 18 def initialize(api_client = ApiClient.default) @api_client = api_client end |
Instance Attribute Details
#api_client ⇒ Object
Returns the value of attribute api_client.
16 17 18 |
# File 'lib/klaviyo-api-sdk/api/conversations_api.rb', line 16 def api_client @api_client end |
Instance Method Details
#create_conversation_message(conversation_message_create_query, opts = {}) ⇒ nil
Create Conversation Message Send an outbound message to a conversation. Requires OAuth authentication and account-level enablement. To request access, reach out in the [developer community](community.klaviyo.com/groups/developer-group-64).
*Rate limits*:
Burst: ‘3/s`
Steady: `60/m` Scopes: `conversations:write`
26 27 28 29 |
# File 'lib/klaviyo-api-sdk/api/conversations_api.rb', line 26 def (, opts = {}) (, opts) nil end |
#create_conversation_message_with_http_info(conversation_message_create_query, opts = {}) ⇒ Array<(nil, Integer, Hash)>
Create Conversation Message Send an outbound message to a conversation. Requires OAuth authentication and account-level enablement. To request access, reach out in the [developer community](community.klaviyo.com/groups/developer-group-64).<br><br>*Rate limits*:<br>Burst: `3/s`<br>Steady: `60/m` Scopes: `conversations:write`
36 37 38 39 40 41 42 43 44 45 46 47 48 49 50 51 52 53 54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 |
# File 'lib/klaviyo-api-sdk/api/conversations_api.rb', line 36 def (, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: ConversationsApi.create_conversation_message ...' end # verify the required parameter 'conversation_message_create_query' is set if @api_client.config.client_side_validation && .nil? fail ArgumentError, "Missing the required parameter 'conversation_message_create_query' when calling ConversationsApi.create_conversation_message" end # resource path local_var_path = '/api/conversation-messages' # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # klaviyo api revision header_params['revision'] = ENV['KLAVIYO_API_REVISION'] || ENV['API_REVISION'] || "2026-04-15" # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/vnd.api+json']) # HTTP header 'Content-Type' content_type = @api_client.select_header_content_type(['application/vnd.api+json']) if !content_type.nil? header_params['Content-Type'] = content_type end # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] || @api_client.object_to_http_body() # return_type return_type = opts[:debug_return_type] # auth_names auth_names = opts[:debug_auth_names] || ['Klaviyo-API-Key', 'OAuth'] = opts.merge( :operation => :"ConversationsApi.create_conversation_message", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:POST, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: ConversationsApi#create_conversation_message\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |