Class: KlaviyoAPI::CouponBlockStyles

Inherits:
Object
  • Object
show all
Defined in:
lib/klaviyo-api-sdk/models/coupon_block_styles.rb

Defined Under Namespace

Classes: EnumAttributeValidator

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ CouponBlockStyles

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



217
218
219
220
221
222
223
224
225
226
227
228
229
230
231
232
233
234
235
236
237
238
239
240
241
242
243
244
245
246
247
248
249
250
251
252
253
254
255
256
257
258
259
260
261
262
263
264
265
266
267
268
269
270
271
272
273
274
275
276
277
278
279
280
281
282
283
284
285
286
287
288
289
290
291
292
293
294
295
296
297
298
299
300
301
302
303
304
305
306
307
308
309
310
311
312
313
314
315
316
317
318
319
320
321
322
323
324
325
326
327
328
329
330
331
332
333
334
335
336
337
338
339
340
341
342
343
344
345
346
347
348
349
# File 'lib/klaviyo-api-sdk/models/coupon_block_styles.rb', line 217

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `KlaviyoAPI::CouponBlockStyles` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!self.class.attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `KlaviyoAPI::CouponBlockStyles`. Please check the name to make sure it's valid. List of attributes: " + self.class.attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'background_color')
    self.background_color = attributes[:'background_color']
  end

  if attributes.key?(:'block_background_color')
    self.block_background_color = attributes[:'block_background_color']
  end

  if attributes.key?(:'block_padding_bottom')
    self.block_padding_bottom = attributes[:'block_padding_bottom']
  end

  if attributes.key?(:'block_padding_left')
    self.block_padding_left = attributes[:'block_padding_left']
  end

  if attributes.key?(:'block_padding_right')
    self.block_padding_right = attributes[:'block_padding_right']
  end

  if attributes.key?(:'block_padding_top')
    self.block_padding_top = attributes[:'block_padding_top']
  end

  if attributes.key?(:'border_color')
    self.border_color = attributes[:'border_color']
  end

  if attributes.key?(:'border_radius')
    self.border_radius = attributes[:'border_radius']
  end

  if attributes.key?(:'border_style')
    self.border_style = attributes[:'border_style']
  end

  if attributes.key?(:'border_width')
    self.border_width = attributes[:'border_width']
  end

  if attributes.key?(:'color')
    self.color = attributes[:'color']
  end

  if attributes.key?(:'font_family')
    self.font_family = attributes[:'font_family']
  end

  if attributes.key?(:'font_size')
    self.font_size = attributes[:'font_size']
  end

  if attributes.key?(:'font_style')
    self.font_style = attributes[:'font_style']
  end

  if attributes.key?(:'font_weight')
    self.font_weight = attributes[:'font_weight']
  end

  if attributes.key?(:'header_font_family')
    self.header_font_family = attributes[:'header_font_family']
  end

  if attributes.key?(:'header_font_size')
    self.header_font_size = attributes[:'header_font_size']
  end

  if attributes.key?(:'header_padding_bottom')
    self.header_padding_bottom = attributes[:'header_padding_bottom']
  end

  if attributes.key?(:'header_padding_left')
    self.header_padding_left = attributes[:'header_padding_left']
  end

  if attributes.key?(:'header_padding_right')
    self.header_padding_right = attributes[:'header_padding_right']
  end

  if attributes.key?(:'header_padding_top')
    self.header_padding_top = attributes[:'header_padding_top']
  end

  if attributes.key?(:'inner_padding_bottom')
    self.inner_padding_bottom = attributes[:'inner_padding_bottom']
  end

  if attributes.key?(:'inner_padding_left')
    self.inner_padding_left = attributes[:'inner_padding_left']
  end

  if attributes.key?(:'inner_padding_right')
    self.inner_padding_right = attributes[:'inner_padding_right']
  end

  if attributes.key?(:'inner_padding_top')
    self.inner_padding_top = attributes[:'inner_padding_top']
  end

  if attributes.key?(:'letter_spacing')
    self.letter_spacing = attributes[:'letter_spacing']
  end

  if attributes.key?(:'mobile_stretch_content')
    self.mobile_stretch_content = attributes[:'mobile_stretch_content']
  end

  if attributes.key?(:'stretch')
    self.stretch = attributes[:'stretch']
  end

  if attributes.key?(:'text_align')
    self.text_align = attributes[:'text_align']
  end

  if attributes.key?(:'text_decoration')
    self.text_decoration = attributes[:'text_decoration']
  end
end

Instance Attribute Details

#background_colorObject

Returns the value of attribute background_color.



17
18
19
# File 'lib/klaviyo-api-sdk/models/coupon_block_styles.rb', line 17

def background_color
  @background_color
end

#block_background_colorObject

Returns the value of attribute block_background_color.



19
20
21
# File 'lib/klaviyo-api-sdk/models/coupon_block_styles.rb', line 19

def block_background_color
  @block_background_color
end

#block_padding_bottomObject

Returns the value of attribute block_padding_bottom.



21
22
23
# File 'lib/klaviyo-api-sdk/models/coupon_block_styles.rb', line 21

def block_padding_bottom
  @block_padding_bottom
end

#block_padding_leftObject

Returns the value of attribute block_padding_left.



23
24
25
# File 'lib/klaviyo-api-sdk/models/coupon_block_styles.rb', line 23

def block_padding_left
  @block_padding_left
end

#block_padding_rightObject

Returns the value of attribute block_padding_right.



25
26
27
# File 'lib/klaviyo-api-sdk/models/coupon_block_styles.rb', line 25

def block_padding_right
  @block_padding_right
end

#block_padding_topObject

Returns the value of attribute block_padding_top.



27
28
29
# File 'lib/klaviyo-api-sdk/models/coupon_block_styles.rb', line 27

def block_padding_top
  @block_padding_top
end

#border_colorObject

Returns the value of attribute border_color.



29
30
31
# File 'lib/klaviyo-api-sdk/models/coupon_block_styles.rb', line 29

def border_color
  @border_color
end

#border_radiusObject

Returns the value of attribute border_radius.



31
32
33
# File 'lib/klaviyo-api-sdk/models/coupon_block_styles.rb', line 31

def border_radius
  @border_radius
end

#border_styleObject

Border style.



34
35
36
# File 'lib/klaviyo-api-sdk/models/coupon_block_styles.rb', line 34

def border_style
  @border_style
end

#border_widthObject

Returns the value of attribute border_width.



36
37
38
# File 'lib/klaviyo-api-sdk/models/coupon_block_styles.rb', line 36

def border_width
  @border_width
end

#colorObject

Returns the value of attribute color.



38
39
40
# File 'lib/klaviyo-api-sdk/models/coupon_block_styles.rb', line 38

def color
  @color
end

#font_familyObject

Returns the value of attribute font_family.



40
41
42
# File 'lib/klaviyo-api-sdk/models/coupon_block_styles.rb', line 40

def font_family
  @font_family
end

#font_sizeObject

Returns the value of attribute font_size.



42
43
44
# File 'lib/klaviyo-api-sdk/models/coupon_block_styles.rb', line 42

def font_size
  @font_size
end

#font_styleObject

Font style.



45
46
47
# File 'lib/klaviyo-api-sdk/models/coupon_block_styles.rb', line 45

def font_style
  @font_style
end

#font_weightObject

Returns the value of attribute font_weight.



47
48
49
# File 'lib/klaviyo-api-sdk/models/coupon_block_styles.rb', line 47

def font_weight
  @font_weight
end

#header_font_familyObject

Returns the value of attribute header_font_family.



49
50
51
# File 'lib/klaviyo-api-sdk/models/coupon_block_styles.rb', line 49

def header_font_family
  @header_font_family
end

#header_font_sizeObject

Returns the value of attribute header_font_size.



51
52
53
# File 'lib/klaviyo-api-sdk/models/coupon_block_styles.rb', line 51

def header_font_size
  @header_font_size
end

#header_padding_bottomObject

Returns the value of attribute header_padding_bottom.



53
54
55
# File 'lib/klaviyo-api-sdk/models/coupon_block_styles.rb', line 53

def header_padding_bottom
  @header_padding_bottom
end

#header_padding_leftObject

Returns the value of attribute header_padding_left.



55
56
57
# File 'lib/klaviyo-api-sdk/models/coupon_block_styles.rb', line 55

def header_padding_left
  @header_padding_left
end

#header_padding_rightObject

Returns the value of attribute header_padding_right.



57
58
59
# File 'lib/klaviyo-api-sdk/models/coupon_block_styles.rb', line 57

def header_padding_right
  @header_padding_right
end

#header_padding_topObject

Returns the value of attribute header_padding_top.



59
60
61
# File 'lib/klaviyo-api-sdk/models/coupon_block_styles.rb', line 59

def header_padding_top
  @header_padding_top
end

#inner_padding_bottomObject

Returns the value of attribute inner_padding_bottom.



61
62
63
# File 'lib/klaviyo-api-sdk/models/coupon_block_styles.rb', line 61

def inner_padding_bottom
  @inner_padding_bottom
end

#inner_padding_leftObject

Returns the value of attribute inner_padding_left.



63
64
65
# File 'lib/klaviyo-api-sdk/models/coupon_block_styles.rb', line 63

def inner_padding_left
  @inner_padding_left
end

#inner_padding_rightObject

Returns the value of attribute inner_padding_right.



65
66
67
# File 'lib/klaviyo-api-sdk/models/coupon_block_styles.rb', line 65

def inner_padding_right
  @inner_padding_right
end

#inner_padding_topObject

Returns the value of attribute inner_padding_top.



67
68
69
# File 'lib/klaviyo-api-sdk/models/coupon_block_styles.rb', line 67

def inner_padding_top
  @inner_padding_top
end

#letter_spacingObject

Returns the value of attribute letter_spacing.



69
70
71
# File 'lib/klaviyo-api-sdk/models/coupon_block_styles.rb', line 69

def letter_spacing
  @letter_spacing
end

#mobile_stretch_contentObject

Returns the value of attribute mobile_stretch_content.



71
72
73
# File 'lib/klaviyo-api-sdk/models/coupon_block_styles.rb', line 71

def mobile_stretch_content
  @mobile_stretch_content
end

#stretchObject

Returns the value of attribute stretch.



73
74
75
# File 'lib/klaviyo-api-sdk/models/coupon_block_styles.rb', line 73

def stretch
  @stretch
end

#text_alignObject

Text Alignment.



76
77
78
# File 'lib/klaviyo-api-sdk/models/coupon_block_styles.rb', line 76

def text_align
  @text_align
end

#text_decorationObject

Returns the value of attribute text_decoration.



78
79
80
# File 'lib/klaviyo-api-sdk/models/coupon_block_styles.rb', line 78

def text_decoration
  @text_decoration
end

Class Method Details

.acceptable_attributesObject

Returns all the JSON keys this model knows about



139
140
141
# File 'lib/klaviyo-api-sdk/models/coupon_block_styles.rb', line 139

def self.acceptable_attributes
  attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
# File 'lib/klaviyo-api-sdk/models/coupon_block_styles.rb', line 103

def self.attribute_map
  {
    :'background_color' => :'background_color',
    :'block_background_color' => :'block_background_color',
    :'block_padding_bottom' => :'block_padding_bottom',
    :'block_padding_left' => :'block_padding_left',
    :'block_padding_right' => :'block_padding_right',
    :'block_padding_top' => :'block_padding_top',
    :'border_color' => :'border_color',
    :'border_radius' => :'border_radius',
    :'border_style' => :'border_style',
    :'border_width' => :'border_width',
    :'color' => :'color',
    :'font_family' => :'font_family',
    :'font_size' => :'font_size',
    :'font_style' => :'font_style',
    :'font_weight' => :'font_weight',
    :'header_font_family' => :'header_font_family',
    :'header_font_size' => :'header_font_size',
    :'header_padding_bottom' => :'header_padding_bottom',
    :'header_padding_left' => :'header_padding_left',
    :'header_padding_right' => :'header_padding_right',
    :'header_padding_top' => :'header_padding_top',
    :'inner_padding_bottom' => :'inner_padding_bottom',
    :'inner_padding_left' => :'inner_padding_left',
    :'inner_padding_right' => :'inner_padding_right',
    :'inner_padding_top' => :'inner_padding_top',
    :'letter_spacing' => :'letter_spacing',
    :'mobile_stretch_content' => :'mobile_stretch_content',
    :'stretch' => :'stretch',
    :'text_align' => :'text_align',
    :'text_decoration' => :'text_decoration'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



452
453
454
# File 'lib/klaviyo-api-sdk/models/coupon_block_styles.rb', line 452

def self.build_from_hash(attributes)
  new.build_from_hash(attributes)
end

.openapi_nullableObject

List of attributes with nullable: true



180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
210
211
212
213
# File 'lib/klaviyo-api-sdk/models/coupon_block_styles.rb', line 180

def self.openapi_nullable
  Set.new([
    :'background_color',
    :'block_background_color',
    :'block_padding_bottom',
    :'block_padding_left',
    :'block_padding_right',
    :'block_padding_top',
    :'border_color',
    :'border_radius',
    :'border_style',
    :'border_width',
    :'color',
    :'font_family',
    :'font_size',
    :'font_style',
    :'font_weight',
    :'header_font_family',
    :'header_font_size',
    :'header_padding_bottom',
    :'header_padding_left',
    :'header_padding_right',
    :'header_padding_top',
    :'inner_padding_bottom',
    :'inner_padding_left',
    :'inner_padding_right',
    :'inner_padding_top',
    :'letter_spacing',
    :'mobile_stretch_content',
    :'stretch',
    :'text_align',
    :'text_decoration'
  ])
end

.openapi_typesObject

Attribute type mapping.



144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
# File 'lib/klaviyo-api-sdk/models/coupon_block_styles.rb', line 144

def self.openapi_types
  {
    :'background_color' => :'String',
    :'block_background_color' => :'String',
    :'block_padding_bottom' => :'Integer',
    :'block_padding_left' => :'Integer',
    :'block_padding_right' => :'Integer',
    :'block_padding_top' => :'Integer',
    :'border_color' => :'String',
    :'border_radius' => :'Integer',
    :'border_style' => :'String',
    :'border_width' => :'Integer',
    :'color' => :'String',
    :'font_family' => :'String',
    :'font_size' => :'Integer',
    :'font_style' => :'String',
    :'font_weight' => :'String',
    :'header_font_family' => :'String',
    :'header_font_size' => :'Integer',
    :'header_padding_bottom' => :'Integer',
    :'header_padding_left' => :'Integer',
    :'header_padding_right' => :'Integer',
    :'header_padding_top' => :'Integer',
    :'inner_padding_bottom' => :'Integer',
    :'inner_padding_left' => :'Integer',
    :'inner_padding_right' => :'Integer',
    :'inner_padding_top' => :'Integer',
    :'letter_spacing' => :'Integer',
    :'mobile_stretch_content' => :'Boolean',
    :'stretch' => :'Boolean',
    :'text_align' => :'String',
    :'text_decoration' => :'String'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



402
403
404
405
406
407
408
409
410
411
412
413
414
415
416
417
418
419
420
421
422
423
424
425
426
427
428
429
430
431
432
433
434
435
# File 'lib/klaviyo-api-sdk/models/coupon_block_styles.rb', line 402

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      background_color == o.background_color &&
      block_background_color == o.block_background_color &&
      block_padding_bottom == o.block_padding_bottom &&
      block_padding_left == o.block_padding_left &&
      block_padding_right == o.block_padding_right &&
      block_padding_top == o.block_padding_top &&
      border_color == o.border_color &&
      border_radius == o.border_radius &&
      border_style == o.border_style &&
      border_width == o.border_width &&
      color == o.color &&
      font_family == o.font_family &&
      font_size == o.font_size &&
      font_style == o.font_style &&
      font_weight == o.font_weight &&
      header_font_family == o.header_font_family &&
      header_font_size == o.header_font_size &&
      header_padding_bottom == o.header_padding_bottom &&
      header_padding_left == o.header_padding_left &&
      header_padding_right == o.header_padding_right &&
      header_padding_top == o.header_padding_top &&
      inner_padding_bottom == o.inner_padding_bottom &&
      inner_padding_left == o.inner_padding_left &&
      inner_padding_right == o.inner_padding_right &&
      inner_padding_top == o.inner_padding_top &&
      letter_spacing == o.letter_spacing &&
      mobile_stretch_content == o.mobile_stretch_content &&
      stretch == o.stretch &&
      text_align == o.text_align &&
      text_decoration == o.text_decoration
end

#_deserialize(type, value) ⇒ Object

Deserializes the data based on type

Parameters:

  • string

    type Data type

  • string

    value Value to be deserialized

Returns:

  • (Object)

    Deserialized data



483
484
485
486
487
488
489
490
491
492
493
494
495
496
497
498
499
500
501
502
503
504
505
506
507
508
509
510
511
512
513
514
515
516
517
518
519
520
# File 'lib/klaviyo-api-sdk/models/coupon_block_styles.rb', line 483

def _deserialize(type, value)
  case type.to_sym
  when :Time
    Time.parse(value)
  when :Date
    Date.parse(value)
  when :String
    value.to_s
  when :Integer
    value.to_i
  when :Float
    value.to_f
  when :Boolean
    if value.to_s =~ /\A(true|t|yes|y|1)\z/i
      true
    else
      false
    end
  when :Object
    # generic object (usually a Hash), return directly
    value
  when /\AArray<(?<inner_type>.+)>\z/
    inner_type = Regexp.last_match[:inner_type]
    value.map { |v| _deserialize(inner_type, v) }
  when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/
    k_type = Regexp.last_match[:k_type]
    v_type = Regexp.last_match[:v_type]
    {}.tap do |hash|
      value.each do |k, v|
        hash[_deserialize(k_type, k)] = _deserialize(v_type, v)
      end
    end
  else # model
    # models (e.g. Pet) or oneOf
    klass = KlaviyoAPI.const_get(type)
    klass.respond_to?(:openapi_one_of) ? klass.build(value) : klass.build_from_hash(value)
  end
end

#_to_hash(value) ⇒ Hash

Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value

Parameters:

  • value (Object)

    Any valid value

Returns:

  • (Hash)

    Returns the value in the form of hash



554
555
556
557
558
559
560
561
562
563
564
565
566
# File 'lib/klaviyo-api-sdk/models/coupon_block_styles.rb', line 554

def _to_hash(value)
  if value.is_a?(Array)
    value.compact.map { |v| _to_hash(v) }
  elsif value.is_a?(Hash)
    {}.tap do |hash|
      value.each { |k, v| hash[k] = _to_hash(v) }
    end
  elsif value.respond_to? :to_hash
    value.to_hash
  else
    value
  end
end

#build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



459
460
461
462
463
464
465
466
467
468
469
470
471
472
473
474
475
476
477
# File 'lib/klaviyo-api-sdk/models/coupon_block_styles.rb', line 459

def build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  self.class.openapi_types.each_pair do |key, type|
    if attributes[self.class.attribute_map[key]].nil? && self.class.openapi_nullable.include?(key)
      self.send("#{key}=", nil)
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[self.class.attribute_map[key]].is_a?(Array)
        self.send("#{key}=", attributes[self.class.attribute_map[key]].map { |v| _deserialize($1, v) })
      end
    elsif !attributes[self.class.attribute_map[key]].nil?
      self.send("#{key}=", _deserialize(type, attributes[self.class.attribute_map[key]]))
    end
  end

  self
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


439
440
441
# File 'lib/klaviyo-api-sdk/models/coupon_block_styles.rb', line 439

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



445
446
447
# File 'lib/klaviyo-api-sdk/models/coupon_block_styles.rb', line 445

def hash
  [background_color, block_background_color, block_padding_bottom, block_padding_left, block_padding_right, block_padding_top, border_color, border_radius, border_style, border_width, color, font_family, font_size, font_style, font_weight, header_font_family, header_font_size, header_padding_bottom, header_padding_left, header_padding_right, header_padding_top, inner_padding_bottom, inner_padding_left, inner_padding_right, inner_padding_top, letter_spacing, mobile_stretch_content, stretch, text_align, text_decoration].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



353
354
355
356
# File 'lib/klaviyo-api-sdk/models/coupon_block_styles.rb', line 353

def list_invalid_properties
  invalid_properties = Array.new
  invalid_properties
end

#to_bodyHash

to_body is an alias to to_hash (backward compatibility)

Returns:

  • (Hash)

    Returns the object in the form of hash



530
531
532
# File 'lib/klaviyo-api-sdk/models/coupon_block_styles.rb', line 530

def to_body
  to_hash
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



536
537
538
539
540
541
542
543
544
545
546
547
548
# File 'lib/klaviyo-api-sdk/models/coupon_block_styles.rb', line 536

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#to_sString

Returns the string representation of the object

Returns:

  • (String)

    String presentation of the object



524
525
526
# File 'lib/klaviyo-api-sdk/models/coupon_block_styles.rb', line 524

def to_s
  to_hash.to_s
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



360
361
362
363
364
365
366
367
368
# File 'lib/klaviyo-api-sdk/models/coupon_block_styles.rb', line 360

def valid?
  border_style_validator = EnumAttributeValidator.new('String', ["dashed", "dotted", "groove", "inset", "none", "outset", "ridge", "solid"])
  return false unless border_style_validator.valid?(@border_style)
  font_style_validator = EnumAttributeValidator.new('String', ["italic", "normal"])
  return false unless font_style_validator.valid?(@font_style)
  text_align_validator = EnumAttributeValidator.new('String', ["center", "left", "right"])
  return false unless text_align_validator.valid?(@text_align)
  true
end