Class: KlaviyoAPI::FlowPushNotification

Inherits:
Object
  • Object
show all
Defined in:
lib/klaviyo-api-sdk/models/flow_push_notification.rb

Defined Under Namespace

Classes: EnumAttributeValidator

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ FlowPushNotification

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
210
211
212
213
214
215
216
217
218
219
220
221
222
223
224
225
226
227
228
229
230
231
232
233
234
235
236
237
238
239
240
241
242
243
244
245
246
247
248
249
250
251
252
253
254
255
256
257
# File 'lib/klaviyo-api-sdk/models/flow_push_notification.rb', line 159

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `KlaviyoAPI::FlowPushNotification` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!self.class.attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `KlaviyoAPI::FlowPushNotification`. Please check the name to make sure it's valid. List of attributes: " + self.class.attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'title')
    self.title = attributes[:'title']
  end

  if attributes.key?(:'body')
    self.body = attributes[:'body']
  end

  if attributes.key?(:'sound')
    self.sound = attributes[:'sound']
  else
    self.sound = false
  end

  if attributes.key?(:'badge')
    self.badge = attributes[:'badge']
  else
    self.badge = false
  end

  if attributes.key?(:'badge_options')
    self.badge_options = attributes[:'badge_options']
  end

  if attributes.key?(:'image_id')
    self.image_id = attributes[:'image_id']
  end

  if attributes.key?(:'dynamic_image')
    self.dynamic_image = attributes[:'dynamic_image']
  end

  if attributes.key?(:'video_asset_id')
    self.video_asset_id = attributes[:'video_asset_id']
  end

  if attributes.key?(:'on_open')
    self.on_open = attributes[:'on_open']
  else
    self.on_open = 'home'
  end

  if attributes.key?(:'ios_link')
    self.ios_link = attributes[:'ios_link']
  end

  if attributes.key?(:'android_link')
    self.android_link = attributes[:'android_link']
  end

  if attributes.key?(:'push_type')
    self.push_type = attributes[:'push_type']
  end

  if attributes.key?(:'kv_pairs')
    self.kv_pairs = attributes[:'kv_pairs']
  end

  if attributes.key?(:'conversion_metric_id')
    self.conversion_metric_id = attributes[:'conversion_metric_id']
  end

  if attributes.key?(:'smart_sending_enabled')
    self.smart_sending_enabled = attributes[:'smart_sending_enabled']
  else
    self.smart_sending_enabled = true
  end

  if attributes.key?(:'additional_filters')
    self.additional_filters = attributes[:'additional_filters']
  end

  if attributes.key?(:'action_buttons')
    if (value = attributes[:'action_buttons']).is_a?(Array)
      self.action_buttons = value
    end
  end

  if attributes.key?(:'name')
    self.name = attributes[:'name']
  end

  if attributes.key?(:'id')
    self.id = attributes[:'id']
  end
end

Instance Attribute Details

#action_buttonsObject

Returns the value of attribute action_buttons.



54
55
56
# File 'lib/klaviyo-api-sdk/models/flow_push_notification.rb', line 54

def action_buttons
  @action_buttons
end

#additional_filtersObject

Returns the value of attribute additional_filters.



52
53
54
# File 'lib/klaviyo-api-sdk/models/flow_push_notification.rb', line 52

def additional_filters
  @additional_filters
end

Returns the value of attribute android_link.



41
42
43
# File 'lib/klaviyo-api-sdk/models/flow_push_notification.rb', line 41

def android_link
  @android_link
end

#badgeObject

Returns the value of attribute badge.



23
24
25
# File 'lib/klaviyo-api-sdk/models/flow_push_notification.rb', line 23

def badge
  @badge
end

#badge_optionsObject

Returns the value of attribute badge_options.



25
26
27
# File 'lib/klaviyo-api-sdk/models/flow_push_notification.rb', line 25

def badge_options
  @badge_options
end

#bodyObject

Returns the value of attribute body.



19
20
21
# File 'lib/klaviyo-api-sdk/models/flow_push_notification.rb', line 19

def body
  @body
end

#conversion_metric_idObject

Returns the value of attribute conversion_metric_id.



48
49
50
# File 'lib/klaviyo-api-sdk/models/flow_push_notification.rb', line 48

def conversion_metric_id
  @conversion_metric_id
end

#dynamic_imageObject

A dynamic image asset to include in the push notification.



31
32
33
# File 'lib/klaviyo-api-sdk/models/flow_push_notification.rb', line 31

def dynamic_image
  @dynamic_image
end

#idObject

Not allowed on create.



59
60
61
# File 'lib/klaviyo-api-sdk/models/flow_push_notification.rb', line 59

def id
  @id
end

#image_idObject

The id of an ImageAsset. If provided, this will take precedence over a dynamic_image.



28
29
30
# File 'lib/klaviyo-api-sdk/models/flow_push_notification.rb', line 28

def image_id
  @image_id
end

Returns the value of attribute ios_link.



39
40
41
# File 'lib/klaviyo-api-sdk/models/flow_push_notification.rb', line 39

def ios_link
  @ios_link
end

#kv_pairsObject

Returns the value of attribute kv_pairs.



46
47
48
# File 'lib/klaviyo-api-sdk/models/flow_push_notification.rb', line 46

def kv_pairs
  @kv_pairs
end

#nameObject

Returns the value of attribute name.



56
57
58
# File 'lib/klaviyo-api-sdk/models/flow_push_notification.rb', line 56

def name
  @name
end

#on_openObject

See PushLinkAction in app. This is not a flow action, but the literal action that should be taken when the push notification is tapped.



37
38
39
# File 'lib/klaviyo-api-sdk/models/flow_push_notification.rb', line 37

def on_open
  @on_open
end

#push_typeObject

The type of push notification to send.



44
45
46
# File 'lib/klaviyo-api-sdk/models/flow_push_notification.rb', line 44

def push_type
  @push_type
end

#smart_sending_enabledObject

Returns the value of attribute smart_sending_enabled.



50
51
52
# File 'lib/klaviyo-api-sdk/models/flow_push_notification.rb', line 50

def smart_sending_enabled
  @smart_sending_enabled
end

#soundObject

Returns the value of attribute sound.



21
22
23
# File 'lib/klaviyo-api-sdk/models/flow_push_notification.rb', line 21

def sound
  @sound
end

#titleObject

Returns the value of attribute title.



17
18
19
# File 'lib/klaviyo-api-sdk/models/flow_push_notification.rb', line 17

def title
  @title
end

#video_asset_idObject

The ULID of a video asset. If provided, videos and images are mutually exclusive.



34
35
36
# File 'lib/klaviyo-api-sdk/models/flow_push_notification.rb', line 34

def video_asset_id
  @video_asset_id
end

Class Method Details

.acceptable_attributesObject

Returns all the JSON keys this model knows about



109
110
111
# File 'lib/klaviyo-api-sdk/models/flow_push_notification.rb', line 109

def self.acceptable_attributes
  attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
# File 'lib/klaviyo-api-sdk/models/flow_push_notification.rb', line 84

def self.attribute_map
  {
    :'title' => :'title',
    :'body' => :'body',
    :'sound' => :'sound',
    :'badge' => :'badge',
    :'badge_options' => :'badge_options',
    :'image_id' => :'image_id',
    :'dynamic_image' => :'dynamic_image',
    :'video_asset_id' => :'video_asset_id',
    :'on_open' => :'on_open',
    :'ios_link' => :'ios_link',
    :'android_link' => :'android_link',
    :'push_type' => :'push_type',
    :'kv_pairs' => :'kv_pairs',
    :'conversion_metric_id' => :'conversion_metric_id',
    :'smart_sending_enabled' => :'smart_sending_enabled',
    :'additional_filters' => :'additional_filters',
    :'action_buttons' => :'action_buttons',
    :'name' => :'name',
    :'id' => :'id'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



342
343
344
# File 'lib/klaviyo-api-sdk/models/flow_push_notification.rb', line 342

def self.build_from_hash(attributes)
  new.build_from_hash(attributes)
end

.openapi_nullableObject

List of attributes with nullable: true



139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
# File 'lib/klaviyo-api-sdk/models/flow_push_notification.rb', line 139

def self.openapi_nullable
  Set.new([
    :'title',
    :'image_id',
    :'dynamic_image',
    :'video_asset_id',
    :'ios_link',
    :'android_link',
    :'push_type',
    :'kv_pairs',
    :'conversion_metric_id',
    :'additional_filters',
    :'action_buttons',
    :'name',
    :'id'
  ])
end

.openapi_typesObject

Attribute type mapping.



114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
# File 'lib/klaviyo-api-sdk/models/flow_push_notification.rb', line 114

def self.openapi_types
  {
    :'title' => :'String',
    :'body' => :'String',
    :'sound' => :'Boolean',
    :'badge' => :'Boolean',
    :'badge_options' => :'FlowPushNotificationBadgeOptions',
    :'image_id' => :'String',
    :'dynamic_image' => :'String',
    :'video_asset_id' => :'String',
    :'on_open' => :'String',
    :'ios_link' => :'String',
    :'android_link' => :'String',
    :'push_type' => :'String',
    :'kv_pairs' => :'Object',
    :'conversion_metric_id' => :'String',
    :'smart_sending_enabled' => :'Boolean',
    :'additional_filters' => :'FlowPushNotificationAdditionalFilters',
    :'action_buttons' => :'Array<PushActionButton>',
    :'name' => :'String',
    :'id' => :'String'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



303
304
305
306
307
308
309
310
311
312
313
314
315
316
317
318
319
320
321
322
323
324
325
# File 'lib/klaviyo-api-sdk/models/flow_push_notification.rb', line 303

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      title == o.title &&
      body == o.body &&
      sound == o.sound &&
      badge == o.badge &&
      badge_options == o.badge_options &&
      image_id == o.image_id &&
      dynamic_image == o.dynamic_image &&
      video_asset_id == o.video_asset_id &&
      on_open == o.on_open &&
      ios_link == o.ios_link &&
      android_link == o.android_link &&
      push_type == o.push_type &&
      kv_pairs == o.kv_pairs &&
      conversion_metric_id == o.conversion_metric_id &&
      smart_sending_enabled == o.smart_sending_enabled &&
      additional_filters == o.additional_filters &&
      action_buttons == o.action_buttons &&
      name == o.name &&
      id == o.id
end

#_deserialize(type, value) ⇒ Object

Deserializes the data based on type

Parameters:

  • string

    type Data type

  • string

    value Value to be deserialized

Returns:

  • (Object)

    Deserialized data



373
374
375
376
377
378
379
380
381
382
383
384
385
386
387
388
389
390
391
392
393
394
395
396
397
398
399
400
401
402
403
404
405
406
407
408
409
410
# File 'lib/klaviyo-api-sdk/models/flow_push_notification.rb', line 373

def _deserialize(type, value)
  case type.to_sym
  when :Time
    Time.parse(value)
  when :Date
    Date.parse(value)
  when :String
    value.to_s
  when :Integer
    value.to_i
  when :Float
    value.to_f
  when :Boolean
    if value.to_s =~ /\A(true|t|yes|y|1)\z/i
      true
    else
      false
    end
  when :Object
    # generic object (usually a Hash), return directly
    value
  when /\AArray<(?<inner_type>.+)>\z/
    inner_type = Regexp.last_match[:inner_type]
    value.map { |v| _deserialize(inner_type, v) }
  when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/
    k_type = Regexp.last_match[:k_type]
    v_type = Regexp.last_match[:v_type]
    {}.tap do |hash|
      value.each do |k, v|
        hash[_deserialize(k_type, k)] = _deserialize(v_type, v)
      end
    end
  else # model
    # models (e.g. Pet) or oneOf
    klass = KlaviyoAPI.const_get(type)
    klass.respond_to?(:openapi_one_of) ? klass.build(value) : klass.build_from_hash(value)
  end
end

#_to_hash(value) ⇒ Hash

Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value

Parameters:

  • value (Object)

    Any valid value

Returns:

  • (Hash)

    Returns the value in the form of hash



444
445
446
447
448
449
450
451
452
453
454
455
456
# File 'lib/klaviyo-api-sdk/models/flow_push_notification.rb', line 444

def _to_hash(value)
  if value.is_a?(Array)
    value.compact.map { |v| _to_hash(v) }
  elsif value.is_a?(Hash)
    {}.tap do |hash|
      value.each { |k, v| hash[k] = _to_hash(v) }
    end
  elsif value.respond_to? :to_hash
    value.to_hash
  else
    value
  end
end

#build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



349
350
351
352
353
354
355
356
357
358
359
360
361
362
363
364
365
366
367
# File 'lib/klaviyo-api-sdk/models/flow_push_notification.rb', line 349

def build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  self.class.openapi_types.each_pair do |key, type|
    if attributes[self.class.attribute_map[key]].nil? && self.class.openapi_nullable.include?(key)
      self.send("#{key}=", nil)
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[self.class.attribute_map[key]].is_a?(Array)
        self.send("#{key}=", attributes[self.class.attribute_map[key]].map { |v| _deserialize($1, v) })
      end
    elsif !attributes[self.class.attribute_map[key]].nil?
      self.send("#{key}=", _deserialize(type, attributes[self.class.attribute_map[key]]))
    end
  end

  self
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


329
330
331
# File 'lib/klaviyo-api-sdk/models/flow_push_notification.rb', line 329

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



335
336
337
# File 'lib/klaviyo-api-sdk/models/flow_push_notification.rb', line 335

def hash
  [title, body, sound, badge, badge_options, image_id, dynamic_image, video_asset_id, on_open, ios_link, android_link, push_type, kv_pairs, conversion_metric_id, smart_sending_enabled, additional_filters, action_buttons, name, id].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



261
262
263
264
265
266
267
268
# File 'lib/klaviyo-api-sdk/models/flow_push_notification.rb', line 261

def list_invalid_properties
  invalid_properties = Array.new
  if @body.nil?
    invalid_properties.push('invalid value for "body", body cannot be nil.')
  end

  invalid_properties
end

#to_bodyHash

to_body is an alias to to_hash (backward compatibility)

Returns:

  • (Hash)

    Returns the object in the form of hash



420
421
422
# File 'lib/klaviyo-api-sdk/models/flow_push_notification.rb', line 420

def to_body
  to_hash
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



426
427
428
429
430
431
432
433
434
435
436
437
438
# File 'lib/klaviyo-api-sdk/models/flow_push_notification.rb', line 426

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#to_sString

Returns the string representation of the object

Returns:

  • (String)

    String presentation of the object



414
415
416
# File 'lib/klaviyo-api-sdk/models/flow_push_notification.rb', line 414

def to_s
  to_hash.to_s
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



272
273
274
275
276
277
278
279
# File 'lib/klaviyo-api-sdk/models/flow_push_notification.rb', line 272

def valid?
  return false if @body.nil?
  on_open_validator = EnumAttributeValidator.new('String', ["home", "link"])
  return false unless on_open_validator.valid?(@on_open)
  push_type_validator = EnumAttributeValidator.new('String', ["silent", "standard"])
  return false unless push_type_validator.valid?(@push_type)
  true
end