Class: KlaviyoAPI::FlowSms

Inherits:
Object
  • Object
show all
Defined in:
lib/klaviyo-api-sdk/models/flow_sms.rb

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ FlowSms

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
210
211
212
213
214
215
216
217
218
219
220
# File 'lib/klaviyo-api-sdk/models/flow_sms.rb', line 120

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `KlaviyoAPI::FlowSms` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!self.class.attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `KlaviyoAPI::FlowSms`. Please check the name to make sure it's valid. List of attributes: " + self.class.attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'body')
    self.body = attributes[:'body']
  end

  if attributes.key?(:'image_id')
    self.image_id = attributes[:'image_id']
  end

  if attributes.key?(:'dynamic_image')
    self.dynamic_image = attributes[:'dynamic_image']
  end

  if attributes.key?(:'shorten_links')
    self.shorten_links = attributes[:'shorten_links']
  else
    self.shorten_links = true
  end

  if attributes.key?(:'include_contact_card')
    self.include_contact_card = attributes[:'include_contact_card']
  else
    self.include_contact_card = false
  end

  if attributes.key?(:'add_org_prefix')
    self.add_org_prefix = attributes[:'add_org_prefix']
  else
    self.add_org_prefix = true
  end

  if attributes.key?(:'add_info_link')
    self.add_info_link = attributes[:'add_info_link']
  else
    self.add_info_link = true
  end

  if attributes.key?(:'add_opt_out_language')
    self.add_opt_out_language = attributes[:'add_opt_out_language']
  else
    self.add_opt_out_language = false
  end

  if attributes.key?(:'smart_sending_enabled')
    self.smart_sending_enabled = attributes[:'smart_sending_enabled']
  else
    self.smart_sending_enabled = true
  end

  if attributes.key?(:'sms_quiet_hours_enabled')
    self.sms_quiet_hours_enabled = attributes[:'sms_quiet_hours_enabled']
  else
    self.sms_quiet_hours_enabled = true
  end

  if attributes.key?(:'transactional')
    self.transactional = attributes[:'transactional']
  else
    self.transactional = false
  end

  if attributes.key?(:'add_tracking_params')
    self.add_tracking_params = attributes[:'add_tracking_params']
  else
    self.add_tracking_params = false
  end

  if attributes.key?(:'custom_tracking_params')
    if (value = attributes[:'custom_tracking_params']).is_a?(Array)
      self.custom_tracking_params = value
    end
  end

  if attributes.key?(:'template_id')
    self.template_id = attributes[:'template_id']
  end

  if attributes.key?(:'additional_filters')
    self.additional_filters = attributes[:'additional_filters']
  end

  if attributes.key?(:'name')
    self.name = attributes[:'name']
  end

  if attributes.key?(:'id')
    self.id = attributes[:'id']
  end
end

Instance Attribute Details

Returns the value of attribute add_info_link.



31
32
33
# File 'lib/klaviyo-api-sdk/models/flow_sms.rb', line 31

def add_info_link
  @add_info_link
end

#add_opt_out_languageObject

Returns the value of attribute add_opt_out_language.



33
34
35
# File 'lib/klaviyo-api-sdk/models/flow_sms.rb', line 33

def add_opt_out_language
  @add_opt_out_language
end

#add_org_prefixObject

Returns the value of attribute add_org_prefix.



29
30
31
# File 'lib/klaviyo-api-sdk/models/flow_sms.rb', line 29

def add_org_prefix
  @add_org_prefix
end

#add_tracking_paramsObject

Returns the value of attribute add_tracking_params.



41
42
43
# File 'lib/klaviyo-api-sdk/models/flow_sms.rb', line 41

def add_tracking_params
  @add_tracking_params
end

#additional_filtersObject

Returns the value of attribute additional_filters.



47
48
49
# File 'lib/klaviyo-api-sdk/models/flow_sms.rb', line 47

def additional_filters
  @additional_filters
end

#bodyObject

Returns the value of attribute body.



17
18
19
# File 'lib/klaviyo-api-sdk/models/flow_sms.rb', line 17

def body
  @body
end

#custom_tracking_paramsObject

Returns the value of attribute custom_tracking_params.



43
44
45
# File 'lib/klaviyo-api-sdk/models/flow_sms.rb', line 43

def custom_tracking_params
  @custom_tracking_params
end

#dynamic_imageObject

A dynamic image asset to include in the SMS message.



23
24
25
# File 'lib/klaviyo-api-sdk/models/flow_sms.rb', line 23

def dynamic_image
  @dynamic_image
end

#idObject

Not allowed on create.



52
53
54
# File 'lib/klaviyo-api-sdk/models/flow_sms.rb', line 52

def id
  @id
end

#image_idObject

The id of an ImageAsset. If provided, this will take precedence over a dynamic_image.



20
21
22
# File 'lib/klaviyo-api-sdk/models/flow_sms.rb', line 20

def image_id
  @image_id
end

#include_contact_cardObject

Returns the value of attribute include_contact_card.



27
28
29
# File 'lib/klaviyo-api-sdk/models/flow_sms.rb', line 27

def include_contact_card
  @include_contact_card
end

#nameObject

Returns the value of attribute name.



49
50
51
# File 'lib/klaviyo-api-sdk/models/flow_sms.rb', line 49

def name
  @name
end

Returns the value of attribute shorten_links.



25
26
27
# File 'lib/klaviyo-api-sdk/models/flow_sms.rb', line 25

def shorten_links
  @shorten_links
end

#smart_sending_enabledObject

Returns the value of attribute smart_sending_enabled.



35
36
37
# File 'lib/klaviyo-api-sdk/models/flow_sms.rb', line 35

def smart_sending_enabled
  @smart_sending_enabled
end

#sms_quiet_hours_enabledObject

Returns the value of attribute sms_quiet_hours_enabled.



37
38
39
# File 'lib/klaviyo-api-sdk/models/flow_sms.rb', line 37

def sms_quiet_hours_enabled
  @sms_quiet_hours_enabled
end

#template_idObject

Returns the value of attribute template_id.



45
46
47
# File 'lib/klaviyo-api-sdk/models/flow_sms.rb', line 45

def template_id
  @template_id
end

#transactionalObject

Returns the value of attribute transactional.



39
40
41
# File 'lib/klaviyo-api-sdk/models/flow_sms.rb', line 39

def transactional
  @transactional
end

Class Method Details

.acceptable_attributesObject

Returns all the JSON keys this model knows about



78
79
80
# File 'lib/klaviyo-api-sdk/models/flow_sms.rb', line 78

def self.acceptable_attributes
  attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



55
56
57
58
59
60
61
62
63
64
65
66
67
68
69
70
71
72
73
74
75
# File 'lib/klaviyo-api-sdk/models/flow_sms.rb', line 55

def self.attribute_map
  {
    :'body' => :'body',
    :'image_id' => :'image_id',
    :'dynamic_image' => :'dynamic_image',
    :'shorten_links' => :'shorten_links',
    :'include_contact_card' => :'include_contact_card',
    :'add_org_prefix' => :'add_org_prefix',
    :'add_info_link' => :'add_info_link',
    :'add_opt_out_language' => :'add_opt_out_language',
    :'smart_sending_enabled' => :'smart_sending_enabled',
    :'sms_quiet_hours_enabled' => :'sms_quiet_hours_enabled',
    :'transactional' => :'transactional',
    :'add_tracking_params' => :'add_tracking_params',
    :'custom_tracking_params' => :'custom_tracking_params',
    :'template_id' => :'template_id',
    :'additional_filters' => :'additional_filters',
    :'name' => :'name',
    :'id' => :'id'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



279
280
281
# File 'lib/klaviyo-api-sdk/models/flow_sms.rb', line 279

def self.build_from_hash(attributes)
  new.build_from_hash(attributes)
end

.openapi_nullableObject

List of attributes with nullable: true



106
107
108
109
110
111
112
113
114
115
116
# File 'lib/klaviyo-api-sdk/models/flow_sms.rb', line 106

def self.openapi_nullable
  Set.new([
    :'image_id',
    :'dynamic_image',
    :'custom_tracking_params',
    :'template_id',
    :'additional_filters',
    :'name',
    :'id'
  ])
end

.openapi_typesObject

Attribute type mapping.



83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
# File 'lib/klaviyo-api-sdk/models/flow_sms.rb', line 83

def self.openapi_types
  {
    :'body' => :'String',
    :'image_id' => :'String',
    :'dynamic_image' => :'String',
    :'shorten_links' => :'Boolean',
    :'include_contact_card' => :'Boolean',
    :'add_org_prefix' => :'Boolean',
    :'add_info_link' => :'Boolean',
    :'add_opt_out_language' => :'Boolean',
    :'smart_sending_enabled' => :'Boolean',
    :'sms_quiet_hours_enabled' => :'Boolean',
    :'transactional' => :'Boolean',
    :'add_tracking_params' => :'Boolean',
    :'custom_tracking_params' => :'Array<UtmParam>',
    :'template_id' => :'String',
    :'additional_filters' => :'FlowSmsAdditionalFilters',
    :'name' => :'String',
    :'id' => :'String'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



242
243
244
245
246
247
248
249
250
251
252
253
254
255
256
257
258
259
260
261
262
# File 'lib/klaviyo-api-sdk/models/flow_sms.rb', line 242

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      body == o.body &&
      image_id == o.image_id &&
      dynamic_image == o.dynamic_image &&
      shorten_links == o.shorten_links &&
      include_contact_card == o.include_contact_card &&
      add_org_prefix == o.add_org_prefix &&
      add_info_link == o.add_info_link &&
      add_opt_out_language == o.add_opt_out_language &&
      smart_sending_enabled == o.smart_sending_enabled &&
      sms_quiet_hours_enabled == o.sms_quiet_hours_enabled &&
      transactional == o.transactional &&
      add_tracking_params == o.add_tracking_params &&
      custom_tracking_params == o.custom_tracking_params &&
      template_id == o.template_id &&
      additional_filters == o.additional_filters &&
      name == o.name &&
      id == o.id
end

#_deserialize(type, value) ⇒ Object

Deserializes the data based on type

Parameters:

  • string

    type Data type

  • string

    value Value to be deserialized

Returns:

  • (Object)

    Deserialized data



310
311
312
313
314
315
316
317
318
319
320
321
322
323
324
325
326
327
328
329
330
331
332
333
334
335
336
337
338
339
340
341
342
343
344
345
346
347
# File 'lib/klaviyo-api-sdk/models/flow_sms.rb', line 310

def _deserialize(type, value)
  case type.to_sym
  when :Time
    Time.parse(value)
  when :Date
    Date.parse(value)
  when :String
    value.to_s
  when :Integer
    value.to_i
  when :Float
    value.to_f
  when :Boolean
    if value.to_s =~ /\A(true|t|yes|y|1)\z/i
      true
    else
      false
    end
  when :Object
    # generic object (usually a Hash), return directly
    value
  when /\AArray<(?<inner_type>.+)>\z/
    inner_type = Regexp.last_match[:inner_type]
    value.map { |v| _deserialize(inner_type, v) }
  when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/
    k_type = Regexp.last_match[:k_type]
    v_type = Regexp.last_match[:v_type]
    {}.tap do |hash|
      value.each do |k, v|
        hash[_deserialize(k_type, k)] = _deserialize(v_type, v)
      end
    end
  else # model
    # models (e.g. Pet) or oneOf
    klass = KlaviyoAPI.const_get(type)
    klass.respond_to?(:openapi_one_of) ? klass.build(value) : klass.build_from_hash(value)
  end
end

#_to_hash(value) ⇒ Hash

Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value

Parameters:

  • value (Object)

    Any valid value

Returns:

  • (Hash)

    Returns the value in the form of hash



381
382
383
384
385
386
387
388
389
390
391
392
393
# File 'lib/klaviyo-api-sdk/models/flow_sms.rb', line 381

def _to_hash(value)
  if value.is_a?(Array)
    value.compact.map { |v| _to_hash(v) }
  elsif value.is_a?(Hash)
    {}.tap do |hash|
      value.each { |k, v| hash[k] = _to_hash(v) }
    end
  elsif value.respond_to? :to_hash
    value.to_hash
  else
    value
  end
end

#build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



286
287
288
289
290
291
292
293
294
295
296
297
298
299
300
301
302
303
304
# File 'lib/klaviyo-api-sdk/models/flow_sms.rb', line 286

def build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  self.class.openapi_types.each_pair do |key, type|
    if attributes[self.class.attribute_map[key]].nil? && self.class.openapi_nullable.include?(key)
      self.send("#{key}=", nil)
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[self.class.attribute_map[key]].is_a?(Array)
        self.send("#{key}=", attributes[self.class.attribute_map[key]].map { |v| _deserialize($1, v) })
      end
    elsif !attributes[self.class.attribute_map[key]].nil?
      self.send("#{key}=", _deserialize(type, attributes[self.class.attribute_map[key]]))
    end
  end

  self
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


266
267
268
# File 'lib/klaviyo-api-sdk/models/flow_sms.rb', line 266

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



272
273
274
# File 'lib/klaviyo-api-sdk/models/flow_sms.rb', line 272

def hash
  [body, image_id, dynamic_image, shorten_links, include_contact_card, add_org_prefix, add_info_link, add_opt_out_language, smart_sending_enabled, sms_quiet_hours_enabled, transactional, add_tracking_params, custom_tracking_params, template_id, additional_filters, name, id].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



224
225
226
227
228
229
230
231
# File 'lib/klaviyo-api-sdk/models/flow_sms.rb', line 224

def list_invalid_properties
  invalid_properties = Array.new
  if @body.nil?
    invalid_properties.push('invalid value for "body", body cannot be nil.')
  end

  invalid_properties
end

#to_bodyHash

to_body is an alias to to_hash (backward compatibility)

Returns:

  • (Hash)

    Returns the object in the form of hash



357
358
359
# File 'lib/klaviyo-api-sdk/models/flow_sms.rb', line 357

def to_body
  to_hash
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



363
364
365
366
367
368
369
370
371
372
373
374
375
# File 'lib/klaviyo-api-sdk/models/flow_sms.rb', line 363

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#to_sString

Returns the string representation of the object

Returns:

  • (String)

    String presentation of the object



351
352
353
# File 'lib/klaviyo-api-sdk/models/flow_sms.rb', line 351

def to_s
  to_hash.to_s
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



235
236
237
238
# File 'lib/klaviyo-api-sdk/models/flow_sms.rb', line 235

def valid?
  return false if @body.nil?
  true
end