Class: KlaviyoAPI::HeaderImageSubBlock

Inherits:
Object
  • Object
show all
Defined in:
lib/klaviyo-api-sdk/models/header_image_sub_block.rb

Defined Under Namespace

Classes: EnumAttributeValidator

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ HeaderImageSubBlock

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
# File 'lib/klaviyo-api-sdk/models/header_image_sub_block.rb', line 119

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `KlaviyoAPI::HeaderImageSubBlock` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!self.class.attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `KlaviyoAPI::HeaderImageSubBlock`. Please check the name to make sure it's valid. List of attributes: " + self.class.attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'id')
    self.id = attributes[:'id']
  end

  if attributes.key?(:'type')
    self.type = attributes[:'type']
  end

  if attributes.key?(:'alt_text')
    self.alt_text = attributes[:'alt_text']
  end

  if attributes.key?(:'asset_id')
    self.asset_id = attributes[:'asset_id']
  end

  if attributes.key?(:'background_color')
    self.background_color = attributes[:'background_color']
  end

  if attributes.key?(:'height')
    self.height = attributes[:'height']
  end

  if attributes.key?(:'href')
    self.href = attributes[:'href']
  end

  if attributes.key?(:'max_width')
    self.max_width = attributes[:'max_width']
  end

  if attributes.key?(:'show_on')
    self.show_on = attributes[:'show_on']
  end

  if attributes.key?(:'src')
    self.src = attributes[:'src']
  end

  if attributes.key?(:'width')
    self.width = attributes[:'width']
  end
end

Instance Attribute Details

#alt_textObject

Returns the value of attribute alt_text.



21
22
23
# File 'lib/klaviyo-api-sdk/models/header_image_sub_block.rb', line 21

def alt_text
  @alt_text
end

#asset_idObject

Returns the value of attribute asset_id.



23
24
25
# File 'lib/klaviyo-api-sdk/models/header_image_sub_block.rb', line 23

def asset_id
  @asset_id
end

#background_colorObject

Returns the value of attribute background_color.



25
26
27
# File 'lib/klaviyo-api-sdk/models/header_image_sub_block.rb', line 25

def background_color
  @background_color
end

#heightObject

Returns the value of attribute height.



27
28
29
# File 'lib/klaviyo-api-sdk/models/header_image_sub_block.rb', line 27

def height
  @height
end

#hrefObject

Returns the value of attribute href.



29
30
31
# File 'lib/klaviyo-api-sdk/models/header_image_sub_block.rb', line 29

def href
  @href
end

#idObject

Returns the value of attribute id.



17
18
19
# File 'lib/klaviyo-api-sdk/models/header_image_sub_block.rb', line 17

def id
  @id
end

#max_widthObject

Returns the value of attribute max_width.



31
32
33
# File 'lib/klaviyo-api-sdk/models/header_image_sub_block.rb', line 31

def max_width
  @max_width
end

#show_onObject

Show on.



34
35
36
# File 'lib/klaviyo-api-sdk/models/header_image_sub_block.rb', line 34

def show_on
  @show_on
end

#srcObject

Returns the value of attribute src.



36
37
38
# File 'lib/klaviyo-api-sdk/models/header_image_sub_block.rb', line 36

def src
  @src
end

#typeObject

Returns the value of attribute type.



19
20
21
# File 'lib/klaviyo-api-sdk/models/header_image_sub_block.rb', line 19

def type
  @type
end

#widthObject

Returns the value of attribute width.



38
39
40
# File 'lib/klaviyo-api-sdk/models/header_image_sub_block.rb', line 38

def width
  @width
end

Class Method Details

.acceptable_attributesObject

Returns all the JSON keys this model knows about



80
81
82
# File 'lib/klaviyo-api-sdk/models/header_image_sub_block.rb', line 80

def self.acceptable_attributes
  attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



63
64
65
66
67
68
69
70
71
72
73
74
75
76
77
# File 'lib/klaviyo-api-sdk/models/header_image_sub_block.rb', line 63

def self.attribute_map
  {
    :'id' => :'id',
    :'type' => :'type',
    :'alt_text' => :'alt_text',
    :'asset_id' => :'asset_id',
    :'background_color' => :'background_color',
    :'height' => :'height',
    :'href' => :'href',
    :'max_width' => :'max_width',
    :'show_on' => :'show_on',
    :'src' => :'src',
    :'width' => :'width'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



252
253
254
# File 'lib/klaviyo-api-sdk/models/header_image_sub_block.rb', line 252

def self.build_from_hash(attributes)
  new.build_from_hash(attributes)
end

.openapi_nullableObject

List of attributes with nullable: true



102
103
104
105
106
107
108
109
110
111
112
113
114
115
# File 'lib/klaviyo-api-sdk/models/header_image_sub_block.rb', line 102

def self.openapi_nullable
  Set.new([
    :'id',
    :'alt_text',
    :'asset_id',
    :'background_color',
    :'height',
    :'href',
    :'max_width',
    :'show_on',
    :'src',
    :'width'
  ])
end

.openapi_typesObject

Attribute type mapping.



85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
# File 'lib/klaviyo-api-sdk/models/header_image_sub_block.rb', line 85

def self.openapi_types
  {
    :'id' => :'String',
    :'type' => :'String',
    :'alt_text' => :'String',
    :'asset_id' => :'String',
    :'background_color' => :'String',
    :'height' => :'Integer',
    :'href' => :'String',
    :'max_width' => :'Integer',
    :'show_on' => :'String',
    :'src' => :'String',
    :'width' => :'Integer'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



221
222
223
224
225
226
227
228
229
230
231
232
233
234
235
# File 'lib/klaviyo-api-sdk/models/header_image_sub_block.rb', line 221

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      id == o.id &&
      type == o.type &&
      alt_text == o.alt_text &&
      asset_id == o.asset_id &&
      background_color == o.background_color &&
      height == o.height &&
      href == o.href &&
      max_width == o.max_width &&
      show_on == o.show_on &&
      src == o.src &&
      width == o.width
end

#_deserialize(type, value) ⇒ Object

Deserializes the data based on type

Parameters:

  • string

    type Data type

  • string

    value Value to be deserialized

Returns:

  • (Object)

    Deserialized data



283
284
285
286
287
288
289
290
291
292
293
294
295
296
297
298
299
300
301
302
303
304
305
306
307
308
309
310
311
312
313
314
315
316
317
318
319
320
# File 'lib/klaviyo-api-sdk/models/header_image_sub_block.rb', line 283

def _deserialize(type, value)
  case type.to_sym
  when :Time
    Time.parse(value)
  when :Date
    Date.parse(value)
  when :String
    value.to_s
  when :Integer
    value.to_i
  when :Float
    value.to_f
  when :Boolean
    if value.to_s =~ /\A(true|t|yes|y|1)\z/i
      true
    else
      false
    end
  when :Object
    # generic object (usually a Hash), return directly
    value
  when /\AArray<(?<inner_type>.+)>\z/
    inner_type = Regexp.last_match[:inner_type]
    value.map { |v| _deserialize(inner_type, v) }
  when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/
    k_type = Regexp.last_match[:k_type]
    v_type = Regexp.last_match[:v_type]
    {}.tap do |hash|
      value.each do |k, v|
        hash[_deserialize(k_type, k)] = _deserialize(v_type, v)
      end
    end
  else # model
    # models (e.g. Pet) or oneOf
    klass = KlaviyoAPI.const_get(type)
    klass.respond_to?(:openapi_one_of) ? klass.build(value) : klass.build_from_hash(value)
  end
end

#_to_hash(value) ⇒ Hash

Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value

Parameters:

  • value (Object)

    Any valid value

Returns:

  • (Hash)

    Returns the value in the form of hash



354
355
356
357
358
359
360
361
362
363
364
365
366
# File 'lib/klaviyo-api-sdk/models/header_image_sub_block.rb', line 354

def _to_hash(value)
  if value.is_a?(Array)
    value.compact.map { |v| _to_hash(v) }
  elsif value.is_a?(Hash)
    {}.tap do |hash|
      value.each { |k, v| hash[k] = _to_hash(v) }
    end
  elsif value.respond_to? :to_hash
    value.to_hash
  else
    value
  end
end

#build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



259
260
261
262
263
264
265
266
267
268
269
270
271
272
273
274
275
276
277
# File 'lib/klaviyo-api-sdk/models/header_image_sub_block.rb', line 259

def build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  self.class.openapi_types.each_pair do |key, type|
    if attributes[self.class.attribute_map[key]].nil? && self.class.openapi_nullable.include?(key)
      self.send("#{key}=", nil)
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[self.class.attribute_map[key]].is_a?(Array)
        self.send("#{key}=", attributes[self.class.attribute_map[key]].map { |v| _deserialize($1, v) })
      end
    elsif !attributes[self.class.attribute_map[key]].nil?
      self.send("#{key}=", _deserialize(type, attributes[self.class.attribute_map[key]]))
    end
  end

  self
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


239
240
241
# File 'lib/klaviyo-api-sdk/models/header_image_sub_block.rb', line 239

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



245
246
247
# File 'lib/klaviyo-api-sdk/models/header_image_sub_block.rb', line 245

def hash
  [id, type, alt_text, asset_id, background_color, height, href, max_width, show_on, src, width].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



179
180
181
182
183
184
185
186
# File 'lib/klaviyo-api-sdk/models/header_image_sub_block.rb', line 179

def list_invalid_properties
  invalid_properties = Array.new
  if @type.nil?
    invalid_properties.push('invalid value for "type", type cannot be nil.')
  end

  invalid_properties
end

#to_bodyHash

to_body is an alias to to_hash (backward compatibility)

Returns:

  • (Hash)

    Returns the object in the form of hash



330
331
332
# File 'lib/klaviyo-api-sdk/models/header_image_sub_block.rb', line 330

def to_body
  to_hash
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



336
337
338
339
340
341
342
343
344
345
346
347
348
# File 'lib/klaviyo-api-sdk/models/header_image_sub_block.rb', line 336

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#to_sString

Returns the string representation of the object

Returns:

  • (String)

    String presentation of the object



324
325
326
# File 'lib/klaviyo-api-sdk/models/header_image_sub_block.rb', line 324

def to_s
  to_hash.to_s
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



190
191
192
193
194
195
196
197
# File 'lib/klaviyo-api-sdk/models/header_image_sub_block.rb', line 190

def valid?
  return false if @type.nil?
  type_validator = EnumAttributeValidator.new('String', ["header_link_bar_image"])
  return false unless type_validator.valid?(@type)
  show_on_validator = EnumAttributeValidator.new('String', ["all", "desktop", "mobile"])
  return false unless show_on_validator.valid?(@show_on)
  true
end