Class: KlaviyoAPI::HeadingStyleStyles

Inherits:
Object
  • Object
show all
Defined in:
lib/klaviyo-api-sdk/models/heading_style_styles.rb

Defined Under Namespace

Classes: EnumAttributeValidator

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ HeadingStyleStyles

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
# File 'lib/klaviyo-api-sdk/models/heading_style_styles.rb', line 126

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `KlaviyoAPI::HeadingStyleStyles` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!self.class.attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `KlaviyoAPI::HeadingStyleStyles`. Please check the name to make sure it's valid. List of attributes: " + self.class.attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'color')
    self.color = attributes[:'color']
  end

  if attributes.key?(:'font_family')
    self.font_family = attributes[:'font_family']
  end

  if attributes.key?(:'font_size')
    self.font_size = attributes[:'font_size']
  end

  if attributes.key?(:'font_style')
    self.font_style = attributes[:'font_style']
  end

  if attributes.key?(:'font_weight')
    self.font_weight = attributes[:'font_weight']
  end

  if attributes.key?(:'letter_spacing')
    self.letter_spacing = attributes[:'letter_spacing']
  end

  if attributes.key?(:'line_height')
    self.line_height = attributes[:'line_height']
  end

  if attributes.key?(:'margin_bottom')
    self.margin_bottom = attributes[:'margin_bottom']
  end

  if attributes.key?(:'mobile_font_size')
    self.mobile_font_size = attributes[:'mobile_font_size']
  end

  if attributes.key?(:'mobile_line_height')
    self.mobile_line_height = attributes[:'mobile_line_height']
  end

  if attributes.key?(:'text_align')
    self.text_align = attributes[:'text_align']
  end

  if attributes.key?(:'text_decoration')
    self.text_decoration = attributes[:'text_decoration']
  end
end

Instance Attribute Details

#colorObject

Returns the value of attribute color.



17
18
19
# File 'lib/klaviyo-api-sdk/models/heading_style_styles.rb', line 17

def color
  @color
end

#font_familyObject

Returns the value of attribute font_family.



19
20
21
# File 'lib/klaviyo-api-sdk/models/heading_style_styles.rb', line 19

def font_family
  @font_family
end

#font_sizeObject

Returns the value of attribute font_size.



21
22
23
# File 'lib/klaviyo-api-sdk/models/heading_style_styles.rb', line 21

def font_size
  @font_size
end

#font_styleObject

Font style.



24
25
26
# File 'lib/klaviyo-api-sdk/models/heading_style_styles.rb', line 24

def font_style
  @font_style
end

#font_weightObject

Returns the value of attribute font_weight.



26
27
28
# File 'lib/klaviyo-api-sdk/models/heading_style_styles.rb', line 26

def font_weight
  @font_weight
end

#letter_spacingObject

Returns the value of attribute letter_spacing.



28
29
30
# File 'lib/klaviyo-api-sdk/models/heading_style_styles.rb', line 28

def letter_spacing
  @letter_spacing
end

#line_heightObject

Returns the value of attribute line_height.



30
31
32
# File 'lib/klaviyo-api-sdk/models/heading_style_styles.rb', line 30

def line_height
  @line_height
end

#margin_bottomObject

Returns the value of attribute margin_bottom.



32
33
34
# File 'lib/klaviyo-api-sdk/models/heading_style_styles.rb', line 32

def margin_bottom
  @margin_bottom
end

#mobile_font_sizeObject

Returns the value of attribute mobile_font_size.



34
35
36
# File 'lib/klaviyo-api-sdk/models/heading_style_styles.rb', line 34

def mobile_font_size
  @mobile_font_size
end

#mobile_line_heightObject

Returns the value of attribute mobile_line_height.



36
37
38
# File 'lib/klaviyo-api-sdk/models/heading_style_styles.rb', line 36

def mobile_line_height
  @mobile_line_height
end

#text_alignObject

Text Alignment.



39
40
41
# File 'lib/klaviyo-api-sdk/models/heading_style_styles.rb', line 39

def text_align
  @text_align
end

#text_decorationObject

Returns the value of attribute text_decoration.



41
42
43
# File 'lib/klaviyo-api-sdk/models/heading_style_styles.rb', line 41

def text_decoration
  @text_decoration
end

Class Method Details

.acceptable_attributesObject

Returns all the JSON keys this model knows about



84
85
86
# File 'lib/klaviyo-api-sdk/models/heading_style_styles.rb', line 84

def self.acceptable_attributes
  attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



66
67
68
69
70
71
72
73
74
75
76
77
78
79
80
81
# File 'lib/klaviyo-api-sdk/models/heading_style_styles.rb', line 66

def self.attribute_map
  {
    :'color' => :'color',
    :'font_family' => :'font_family',
    :'font_size' => :'font_size',
    :'font_style' => :'font_style',
    :'font_weight' => :'font_weight',
    :'letter_spacing' => :'letter_spacing',
    :'line_height' => :'line_height',
    :'margin_bottom' => :'margin_bottom',
    :'mobile_font_size' => :'mobile_font_size',
    :'mobile_line_height' => :'mobile_line_height',
    :'text_align' => :'text_align',
    :'text_decoration' => :'text_decoration'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



259
260
261
# File 'lib/klaviyo-api-sdk/models/heading_style_styles.rb', line 259

def self.build_from_hash(attributes)
  new.build_from_hash(attributes)
end

.openapi_nullableObject

List of attributes with nullable: true



107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
# File 'lib/klaviyo-api-sdk/models/heading_style_styles.rb', line 107

def self.openapi_nullable
  Set.new([
    :'color',
    :'font_family',
    :'font_size',
    :'font_style',
    :'font_weight',
    :'letter_spacing',
    :'line_height',
    :'margin_bottom',
    :'mobile_font_size',
    :'mobile_line_height',
    :'text_align',
    :'text_decoration'
  ])
end

.openapi_typesObject

Attribute type mapping.



89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
# File 'lib/klaviyo-api-sdk/models/heading_style_styles.rb', line 89

def self.openapi_types
  {
    :'color' => :'String',
    :'font_family' => :'String',
    :'font_size' => :'Integer',
    :'font_style' => :'String',
    :'font_weight' => :'String',
    :'letter_spacing' => :'Integer',
    :'line_height' => :'Float',
    :'margin_bottom' => :'Integer',
    :'mobile_font_size' => :'Integer',
    :'mobile_line_height' => :'Float',
    :'text_align' => :'String',
    :'text_decoration' => :'String'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



227
228
229
230
231
232
233
234
235
236
237
238
239
240
241
242
# File 'lib/klaviyo-api-sdk/models/heading_style_styles.rb', line 227

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      color == o.color &&
      font_family == o.font_family &&
      font_size == o.font_size &&
      font_style == o.font_style &&
      font_weight == o.font_weight &&
      letter_spacing == o.letter_spacing &&
      line_height == o.line_height &&
      margin_bottom == o.margin_bottom &&
      mobile_font_size == o.mobile_font_size &&
      mobile_line_height == o.mobile_line_height &&
      text_align == o.text_align &&
      text_decoration == o.text_decoration
end

#_deserialize(type, value) ⇒ Object

Deserializes the data based on type

Parameters:

  • string

    type Data type

  • string

    value Value to be deserialized

Returns:

  • (Object)

    Deserialized data



290
291
292
293
294
295
296
297
298
299
300
301
302
303
304
305
306
307
308
309
310
311
312
313
314
315
316
317
318
319
320
321
322
323
324
325
326
327
# File 'lib/klaviyo-api-sdk/models/heading_style_styles.rb', line 290

def _deserialize(type, value)
  case type.to_sym
  when :Time
    Time.parse(value)
  when :Date
    Date.parse(value)
  when :String
    value.to_s
  when :Integer
    value.to_i
  when :Float
    value.to_f
  when :Boolean
    if value.to_s =~ /\A(true|t|yes|y|1)\z/i
      true
    else
      false
    end
  when :Object
    # generic object (usually a Hash), return directly
    value
  when /\AArray<(?<inner_type>.+)>\z/
    inner_type = Regexp.last_match[:inner_type]
    value.map { |v| _deserialize(inner_type, v) }
  when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/
    k_type = Regexp.last_match[:k_type]
    v_type = Regexp.last_match[:v_type]
    {}.tap do |hash|
      value.each do |k, v|
        hash[_deserialize(k_type, k)] = _deserialize(v_type, v)
      end
    end
  else # model
    # models (e.g. Pet) or oneOf
    klass = KlaviyoAPI.const_get(type)
    klass.respond_to?(:openapi_one_of) ? klass.build(value) : klass.build_from_hash(value)
  end
end

#_to_hash(value) ⇒ Hash

Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value

Parameters:

  • value (Object)

    Any valid value

Returns:

  • (Hash)

    Returns the value in the form of hash



361
362
363
364
365
366
367
368
369
370
371
372
373
# File 'lib/klaviyo-api-sdk/models/heading_style_styles.rb', line 361

def _to_hash(value)
  if value.is_a?(Array)
    value.compact.map { |v| _to_hash(v) }
  elsif value.is_a?(Hash)
    {}.tap do |hash|
      value.each { |k, v| hash[k] = _to_hash(v) }
    end
  elsif value.respond_to? :to_hash
    value.to_hash
  else
    value
  end
end

#build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



266
267
268
269
270
271
272
273
274
275
276
277
278
279
280
281
282
283
284
# File 'lib/klaviyo-api-sdk/models/heading_style_styles.rb', line 266

def build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  self.class.openapi_types.each_pair do |key, type|
    if attributes[self.class.attribute_map[key]].nil? && self.class.openapi_nullable.include?(key)
      self.send("#{key}=", nil)
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[self.class.attribute_map[key]].is_a?(Array)
        self.send("#{key}=", attributes[self.class.attribute_map[key]].map { |v| _deserialize($1, v) })
      end
    elsif !attributes[self.class.attribute_map[key]].nil?
      self.send("#{key}=", _deserialize(type, attributes[self.class.attribute_map[key]]))
    end
  end

  self
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


246
247
248
# File 'lib/klaviyo-api-sdk/models/heading_style_styles.rb', line 246

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



252
253
254
# File 'lib/klaviyo-api-sdk/models/heading_style_styles.rb', line 252

def hash
  [color, font_family, font_size, font_style, font_weight, letter_spacing, line_height, margin_bottom, mobile_font_size, mobile_line_height, text_align, text_decoration].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



190
191
192
193
# File 'lib/klaviyo-api-sdk/models/heading_style_styles.rb', line 190

def list_invalid_properties
  invalid_properties = Array.new
  invalid_properties
end

#to_bodyHash

to_body is an alias to to_hash (backward compatibility)

Returns:

  • (Hash)

    Returns the object in the form of hash



337
338
339
# File 'lib/klaviyo-api-sdk/models/heading_style_styles.rb', line 337

def to_body
  to_hash
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



343
344
345
346
347
348
349
350
351
352
353
354
355
# File 'lib/klaviyo-api-sdk/models/heading_style_styles.rb', line 343

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#to_sString

Returns the string representation of the object

Returns:

  • (String)

    String presentation of the object



331
332
333
# File 'lib/klaviyo-api-sdk/models/heading_style_styles.rb', line 331

def to_s
  to_hash.to_s
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



197
198
199
200
201
202
203
# File 'lib/klaviyo-api-sdk/models/heading_style_styles.rb', line 197

def valid?
  font_style_validator = EnumAttributeValidator.new('String', ["italic", "normal"])
  return false unless font_style_validator.valid?(@font_style)
  text_align_validator = EnumAttributeValidator.new('String', ["center", "left", "right"])
  return false unless text_align_validator.valid?(@text_align)
  true
end