Class: KlaviyoAPI::HorizontalRuleBlockStyles

Inherits:
Object
  • Object
show all
Defined in:
lib/klaviyo-api-sdk/models/horizontal_rule_block_styles.rb

Defined Under Namespace

Classes: EnumAttributeValidator

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ HorizontalRuleBlockStyles

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
# File 'lib/klaviyo-api-sdk/models/horizontal_rule_block_styles.rb', line 110

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `KlaviyoAPI::HorizontalRuleBlockStyles` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!self.class.attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `KlaviyoAPI::HorizontalRuleBlockStyles`. Please check the name to make sure it's valid. List of attributes: " + self.class.attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'block_background_color')
    self.block_background_color = attributes[:'block_background_color']
  end

  if attributes.key?(:'block_padding_bottom')
    self.block_padding_bottom = attributes[:'block_padding_bottom']
  end

  if attributes.key?(:'block_padding_left')
    self.block_padding_left = attributes[:'block_padding_left']
  end

  if attributes.key?(:'block_padding_right')
    self.block_padding_right = attributes[:'block_padding_right']
  end

  if attributes.key?(:'block_padding_top')
    self.block_padding_top = attributes[:'block_padding_top']
  end

  if attributes.key?(:'border_color')
    self.border_color = attributes[:'border_color']
  end

  if attributes.key?(:'border_style')
    self.border_style = attributes[:'border_style']
  end

  if attributes.key?(:'border_width')
    self.border_width = attributes[:'border_width']
  end

  if attributes.key?(:'mobile_stretch_content')
    self.mobile_stretch_content = attributes[:'mobile_stretch_content']
  end
end

Instance Attribute Details

#block_background_colorObject

Returns the value of attribute block_background_color.



17
18
19
# File 'lib/klaviyo-api-sdk/models/horizontal_rule_block_styles.rb', line 17

def block_background_color
  @block_background_color
end

#block_padding_bottomObject

Returns the value of attribute block_padding_bottom.



19
20
21
# File 'lib/klaviyo-api-sdk/models/horizontal_rule_block_styles.rb', line 19

def block_padding_bottom
  @block_padding_bottom
end

#block_padding_leftObject

Returns the value of attribute block_padding_left.



21
22
23
# File 'lib/klaviyo-api-sdk/models/horizontal_rule_block_styles.rb', line 21

def block_padding_left
  @block_padding_left
end

#block_padding_rightObject

Returns the value of attribute block_padding_right.



23
24
25
# File 'lib/klaviyo-api-sdk/models/horizontal_rule_block_styles.rb', line 23

def block_padding_right
  @block_padding_right
end

#block_padding_topObject

Returns the value of attribute block_padding_top.



25
26
27
# File 'lib/klaviyo-api-sdk/models/horizontal_rule_block_styles.rb', line 25

def block_padding_top
  @block_padding_top
end

#border_colorObject

Returns the value of attribute border_color.



27
28
29
# File 'lib/klaviyo-api-sdk/models/horizontal_rule_block_styles.rb', line 27

def border_color
  @border_color
end

#border_styleObject

Border style.



30
31
32
# File 'lib/klaviyo-api-sdk/models/horizontal_rule_block_styles.rb', line 30

def border_style
  @border_style
end

#border_widthObject

Returns the value of attribute border_width.



32
33
34
# File 'lib/klaviyo-api-sdk/models/horizontal_rule_block_styles.rb', line 32

def border_width
  @border_width
end

#mobile_stretch_contentObject

Returns the value of attribute mobile_stretch_content.



34
35
36
# File 'lib/klaviyo-api-sdk/models/horizontal_rule_block_styles.rb', line 34

def mobile_stretch_content
  @mobile_stretch_content
end

Class Method Details

.acceptable_attributesObject

Returns all the JSON keys this model knows about



74
75
76
# File 'lib/klaviyo-api-sdk/models/horizontal_rule_block_styles.rb', line 74

def self.acceptable_attributes
  attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



59
60
61
62
63
64
65
66
67
68
69
70
71
# File 'lib/klaviyo-api-sdk/models/horizontal_rule_block_styles.rb', line 59

def self.attribute_map
  {
    :'block_background_color' => :'block_background_color',
    :'block_padding_bottom' => :'block_padding_bottom',
    :'block_padding_left' => :'block_padding_left',
    :'block_padding_right' => :'block_padding_right',
    :'block_padding_top' => :'block_padding_top',
    :'border_color' => :'border_color',
    :'border_style' => :'border_style',
    :'border_width' => :'border_width',
    :'mobile_stretch_content' => :'mobile_stretch_content'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



216
217
218
# File 'lib/klaviyo-api-sdk/models/horizontal_rule_block_styles.rb', line 216

def self.build_from_hash(attributes)
  new.build_from_hash(attributes)
end

.openapi_nullableObject

List of attributes with nullable: true



94
95
96
97
98
99
100
101
102
103
104
105
106
# File 'lib/klaviyo-api-sdk/models/horizontal_rule_block_styles.rb', line 94

def self.openapi_nullable
  Set.new([
    :'block_background_color',
    :'block_padding_bottom',
    :'block_padding_left',
    :'block_padding_right',
    :'block_padding_top',
    :'border_color',
    :'border_style',
    :'border_width',
    :'mobile_stretch_content'
  ])
end

.openapi_typesObject

Attribute type mapping.



79
80
81
82
83
84
85
86
87
88
89
90
91
# File 'lib/klaviyo-api-sdk/models/horizontal_rule_block_styles.rb', line 79

def self.openapi_types
  {
    :'block_background_color' => :'String',
    :'block_padding_bottom' => :'Integer',
    :'block_padding_left' => :'Integer',
    :'block_padding_right' => :'Integer',
    :'block_padding_top' => :'Integer',
    :'border_color' => :'String',
    :'border_style' => :'String',
    :'border_width' => :'Integer',
    :'mobile_stretch_content' => :'Boolean'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



187
188
189
190
191
192
193
194
195
196
197
198
199
# File 'lib/klaviyo-api-sdk/models/horizontal_rule_block_styles.rb', line 187

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      block_background_color == o.block_background_color &&
      block_padding_bottom == o.block_padding_bottom &&
      block_padding_left == o.block_padding_left &&
      block_padding_right == o.block_padding_right &&
      block_padding_top == o.block_padding_top &&
      border_color == o.border_color &&
      border_style == o.border_style &&
      border_width == o.border_width &&
      mobile_stretch_content == o.mobile_stretch_content
end

#_deserialize(type, value) ⇒ Object

Deserializes the data based on type

Parameters:

  • string

    type Data type

  • string

    value Value to be deserialized

Returns:

  • (Object)

    Deserialized data



247
248
249
250
251
252
253
254
255
256
257
258
259
260
261
262
263
264
265
266
267
268
269
270
271
272
273
274
275
276
277
278
279
280
281
282
283
284
# File 'lib/klaviyo-api-sdk/models/horizontal_rule_block_styles.rb', line 247

def _deserialize(type, value)
  case type.to_sym
  when :Time
    Time.parse(value)
  when :Date
    Date.parse(value)
  when :String
    value.to_s
  when :Integer
    value.to_i
  when :Float
    value.to_f
  when :Boolean
    if value.to_s =~ /\A(true|t|yes|y|1)\z/i
      true
    else
      false
    end
  when :Object
    # generic object (usually a Hash), return directly
    value
  when /\AArray<(?<inner_type>.+)>\z/
    inner_type = Regexp.last_match[:inner_type]
    value.map { |v| _deserialize(inner_type, v) }
  when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/
    k_type = Regexp.last_match[:k_type]
    v_type = Regexp.last_match[:v_type]
    {}.tap do |hash|
      value.each do |k, v|
        hash[_deserialize(k_type, k)] = _deserialize(v_type, v)
      end
    end
  else # model
    # models (e.g. Pet) or oneOf
    klass = KlaviyoAPI.const_get(type)
    klass.respond_to?(:openapi_one_of) ? klass.build(value) : klass.build_from_hash(value)
  end
end

#_to_hash(value) ⇒ Hash

Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value

Parameters:

  • value (Object)

    Any valid value

Returns:

  • (Hash)

    Returns the value in the form of hash



318
319
320
321
322
323
324
325
326
327
328
329
330
# File 'lib/klaviyo-api-sdk/models/horizontal_rule_block_styles.rb', line 318

def _to_hash(value)
  if value.is_a?(Array)
    value.compact.map { |v| _to_hash(v) }
  elsif value.is_a?(Hash)
    {}.tap do |hash|
      value.each { |k, v| hash[k] = _to_hash(v) }
    end
  elsif value.respond_to? :to_hash
    value.to_hash
  else
    value
  end
end

#build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



223
224
225
226
227
228
229
230
231
232
233
234
235
236
237
238
239
240
241
# File 'lib/klaviyo-api-sdk/models/horizontal_rule_block_styles.rb', line 223

def build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  self.class.openapi_types.each_pair do |key, type|
    if attributes[self.class.attribute_map[key]].nil? && self.class.openapi_nullable.include?(key)
      self.send("#{key}=", nil)
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[self.class.attribute_map[key]].is_a?(Array)
        self.send("#{key}=", attributes[self.class.attribute_map[key]].map { |v| _deserialize($1, v) })
      end
    elsif !attributes[self.class.attribute_map[key]].nil?
      self.send("#{key}=", _deserialize(type, attributes[self.class.attribute_map[key]]))
    end
  end

  self
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


203
204
205
# File 'lib/klaviyo-api-sdk/models/horizontal_rule_block_styles.rb', line 203

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



209
210
211
# File 'lib/klaviyo-api-sdk/models/horizontal_rule_block_styles.rb', line 209

def hash
  [block_background_color, block_padding_bottom, block_padding_left, block_padding_right, block_padding_top, border_color, border_style, border_width, mobile_stretch_content].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



162
163
164
165
# File 'lib/klaviyo-api-sdk/models/horizontal_rule_block_styles.rb', line 162

def list_invalid_properties
  invalid_properties = Array.new
  invalid_properties
end

#to_bodyHash

to_body is an alias to to_hash (backward compatibility)

Returns:

  • (Hash)

    Returns the object in the form of hash



294
295
296
# File 'lib/klaviyo-api-sdk/models/horizontal_rule_block_styles.rb', line 294

def to_body
  to_hash
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



300
301
302
303
304
305
306
307
308
309
310
311
312
# File 'lib/klaviyo-api-sdk/models/horizontal_rule_block_styles.rb', line 300

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#to_sString

Returns the string representation of the object

Returns:

  • (String)

    String presentation of the object



288
289
290
# File 'lib/klaviyo-api-sdk/models/horizontal_rule_block_styles.rb', line 288

def to_s
  to_hash.to_s
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



169
170
171
172
173
# File 'lib/klaviyo-api-sdk/models/horizontal_rule_block_styles.rb', line 169

def valid?
  border_style_validator = EnumAttributeValidator.new('String', ["dashed", "dotted", "groove", "inset", "none", "outset", "ridge", "solid"])
  return false unless border_style_validator.valid?(@border_style)
  true
end