Class: KlaviyoAPI::ImageBlockStyles

Inherits:
Object
  • Object
show all
Defined in:
lib/klaviyo-api-sdk/models/image_block_styles.rb

Defined Under Namespace

Classes: EnumAttributeValidator

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ ImageBlockStyles

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
210
211
212
213
214
215
216
217
218
219
220
221
222
223
224
225
226
227
228
229
230
231
232
233
234
235
236
237
238
239
240
241
242
243
244
245
246
247
248
249
# File 'lib/klaviyo-api-sdk/models/image_block_styles.rb', line 161

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `KlaviyoAPI::ImageBlockStyles` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!self.class.attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `KlaviyoAPI::ImageBlockStyles`. Please check the name to make sure it's valid. List of attributes: " + self.class.attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'align')
    self.align = attributes[:'align']
  end

  if attributes.key?(:'background_color')
    self.background_color = attributes[:'background_color']
  end

  if attributes.key?(:'block_background_color')
    self.block_background_color = attributes[:'block_background_color']
  end

  if attributes.key?(:'block_border_color')
    self.block_border_color = attributes[:'block_border_color']
  end

  if attributes.key?(:'block_border_style')
    self.block_border_style = attributes[:'block_border_style']
  end

  if attributes.key?(:'block_border_width')
    self.block_border_width = attributes[:'block_border_width']
  end

  if attributes.key?(:'block_padding_bottom')
    self.block_padding_bottom = attributes[:'block_padding_bottom']
  end

  if attributes.key?(:'block_padding_left')
    self.block_padding_left = attributes[:'block_padding_left']
  end

  if attributes.key?(:'block_padding_right')
    self.block_padding_right = attributes[:'block_padding_right']
  end

  if attributes.key?(:'block_padding_top')
    self.block_padding_top = attributes[:'block_padding_top']
  end

  if attributes.key?(:'full_width_mobile')
    self.full_width_mobile = attributes[:'full_width_mobile']
  end

  if attributes.key?(:'height')
    self.height = attributes[:'height']
  end

  if attributes.key?(:'inner_padding_bottom')
    self.inner_padding_bottom = attributes[:'inner_padding_bottom']
  end

  if attributes.key?(:'inner_padding_left')
    self.inner_padding_left = attributes[:'inner_padding_left']
  end

  if attributes.key?(:'inner_padding_right')
    self.inner_padding_right = attributes[:'inner_padding_right']
  end

  if attributes.key?(:'inner_padding_top')
    self.inner_padding_top = attributes[:'inner_padding_top']
  end

  if attributes.key?(:'max_width')
    self.max_width = attributes[:'max_width']
  end

  if attributes.key?(:'mobile_stretch_content')
    self.mobile_stretch_content = attributes[:'mobile_stretch_content']
  end

  if attributes.key?(:'width')
    self.width = attributes[:'width']
  end
end

Instance Attribute Details

#alignObject

Image Alignment.



18
19
20
# File 'lib/klaviyo-api-sdk/models/image_block_styles.rb', line 18

def align
  @align
end

#background_colorObject

Returns the value of attribute background_color.



20
21
22
# File 'lib/klaviyo-api-sdk/models/image_block_styles.rb', line 20

def background_color
  @background_color
end

#block_background_colorObject

Returns the value of attribute block_background_color.



22
23
24
# File 'lib/klaviyo-api-sdk/models/image_block_styles.rb', line 22

def block_background_color
  @block_background_color
end

#block_border_colorObject

Returns the value of attribute block_border_color.



24
25
26
# File 'lib/klaviyo-api-sdk/models/image_block_styles.rb', line 24

def block_border_color
  @block_border_color
end

#block_border_styleObject

Border style.



27
28
29
# File 'lib/klaviyo-api-sdk/models/image_block_styles.rb', line 27

def block_border_style
  @block_border_style
end

#block_border_widthObject

Returns the value of attribute block_border_width.



29
30
31
# File 'lib/klaviyo-api-sdk/models/image_block_styles.rb', line 29

def block_border_width
  @block_border_width
end

#block_padding_bottomObject

Returns the value of attribute block_padding_bottom.



31
32
33
# File 'lib/klaviyo-api-sdk/models/image_block_styles.rb', line 31

def block_padding_bottom
  @block_padding_bottom
end

#block_padding_leftObject

Returns the value of attribute block_padding_left.



33
34
35
# File 'lib/klaviyo-api-sdk/models/image_block_styles.rb', line 33

def block_padding_left
  @block_padding_left
end

#block_padding_rightObject

Returns the value of attribute block_padding_right.



35
36
37
# File 'lib/klaviyo-api-sdk/models/image_block_styles.rb', line 35

def block_padding_right
  @block_padding_right
end

#block_padding_topObject

Returns the value of attribute block_padding_top.



37
38
39
# File 'lib/klaviyo-api-sdk/models/image_block_styles.rb', line 37

def block_padding_top
  @block_padding_top
end

#full_width_mobileObject

Returns the value of attribute full_width_mobile.



39
40
41
# File 'lib/klaviyo-api-sdk/models/image_block_styles.rb', line 39

def full_width_mobile
  @full_width_mobile
end

#heightObject

Returns the value of attribute height.



41
42
43
# File 'lib/klaviyo-api-sdk/models/image_block_styles.rb', line 41

def height
  @height
end

#inner_padding_bottomObject

Returns the value of attribute inner_padding_bottom.



43
44
45
# File 'lib/klaviyo-api-sdk/models/image_block_styles.rb', line 43

def inner_padding_bottom
  @inner_padding_bottom
end

#inner_padding_leftObject

Returns the value of attribute inner_padding_left.



45
46
47
# File 'lib/klaviyo-api-sdk/models/image_block_styles.rb', line 45

def inner_padding_left
  @inner_padding_left
end

#inner_padding_rightObject

Returns the value of attribute inner_padding_right.



47
48
49
# File 'lib/klaviyo-api-sdk/models/image_block_styles.rb', line 47

def inner_padding_right
  @inner_padding_right
end

#inner_padding_topObject

Returns the value of attribute inner_padding_top.



49
50
51
# File 'lib/klaviyo-api-sdk/models/image_block_styles.rb', line 49

def inner_padding_top
  @inner_padding_top
end

#max_widthObject

Returns the value of attribute max_width.



51
52
53
# File 'lib/klaviyo-api-sdk/models/image_block_styles.rb', line 51

def max_width
  @max_width
end

#mobile_stretch_contentObject

Returns the value of attribute mobile_stretch_content.



53
54
55
# File 'lib/klaviyo-api-sdk/models/image_block_styles.rb', line 53

def mobile_stretch_content
  @mobile_stretch_content
end

#widthObject

Returns the value of attribute width.



55
56
57
# File 'lib/klaviyo-api-sdk/models/image_block_styles.rb', line 55

def width
  @width
end

Class Method Details

.acceptable_attributesObject

Returns all the JSON keys this model knows about



105
106
107
# File 'lib/klaviyo-api-sdk/models/image_block_styles.rb', line 105

def self.acceptable_attributes
  attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



80
81
82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
# File 'lib/klaviyo-api-sdk/models/image_block_styles.rb', line 80

def self.attribute_map
  {
    :'align' => :'align',
    :'background_color' => :'background_color',
    :'block_background_color' => :'block_background_color',
    :'block_border_color' => :'block_border_color',
    :'block_border_style' => :'block_border_style',
    :'block_border_width' => :'block_border_width',
    :'block_padding_bottom' => :'block_padding_bottom',
    :'block_padding_left' => :'block_padding_left',
    :'block_padding_right' => :'block_padding_right',
    :'block_padding_top' => :'block_padding_top',
    :'full_width_mobile' => :'full_width_mobile',
    :'height' => :'height',
    :'inner_padding_bottom' => :'inner_padding_bottom',
    :'inner_padding_left' => :'inner_padding_left',
    :'inner_padding_right' => :'inner_padding_right',
    :'inner_padding_top' => :'inner_padding_top',
    :'max_width' => :'max_width',
    :'mobile_stretch_content' => :'mobile_stretch_content',
    :'width' => :'width'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



329
330
331
# File 'lib/klaviyo-api-sdk/models/image_block_styles.rb', line 329

def self.build_from_hash(attributes)
  new.build_from_hash(attributes)
end

.openapi_nullableObject

List of attributes with nullable: true



135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
# File 'lib/klaviyo-api-sdk/models/image_block_styles.rb', line 135

def self.openapi_nullable
  Set.new([
    :'align',
    :'background_color',
    :'block_background_color',
    :'block_border_color',
    :'block_border_style',
    :'block_border_width',
    :'block_padding_bottom',
    :'block_padding_left',
    :'block_padding_right',
    :'block_padding_top',
    :'full_width_mobile',
    :'height',
    :'inner_padding_bottom',
    :'inner_padding_left',
    :'inner_padding_right',
    :'inner_padding_top',
    :'max_width',
    :'mobile_stretch_content',
    :'width'
  ])
end

.openapi_typesObject

Attribute type mapping.



110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
# File 'lib/klaviyo-api-sdk/models/image_block_styles.rb', line 110

def self.openapi_types
  {
    :'align' => :'String',
    :'background_color' => :'String',
    :'block_background_color' => :'String',
    :'block_border_color' => :'String',
    :'block_border_style' => :'String',
    :'block_border_width' => :'Integer',
    :'block_padding_bottom' => :'Integer',
    :'block_padding_left' => :'Integer',
    :'block_padding_right' => :'Integer',
    :'block_padding_top' => :'Integer',
    :'full_width_mobile' => :'Boolean',
    :'height' => :'Integer',
    :'inner_padding_bottom' => :'Integer',
    :'inner_padding_left' => :'Integer',
    :'inner_padding_right' => :'Integer',
    :'inner_padding_top' => :'Integer',
    :'max_width' => :'Integer',
    :'mobile_stretch_content' => :'Boolean',
    :'width' => :'Integer'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



290
291
292
293
294
295
296
297
298
299
300
301
302
303
304
305
306
307
308
309
310
311
312
# File 'lib/klaviyo-api-sdk/models/image_block_styles.rb', line 290

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      align == o.align &&
      background_color == o.background_color &&
      block_background_color == o.block_background_color &&
      block_border_color == o.block_border_color &&
      block_border_style == o.block_border_style &&
      block_border_width == o.block_border_width &&
      block_padding_bottom == o.block_padding_bottom &&
      block_padding_left == o.block_padding_left &&
      block_padding_right == o.block_padding_right &&
      block_padding_top == o.block_padding_top &&
      full_width_mobile == o.full_width_mobile &&
      height == o.height &&
      inner_padding_bottom == o.inner_padding_bottom &&
      inner_padding_left == o.inner_padding_left &&
      inner_padding_right == o.inner_padding_right &&
      inner_padding_top == o.inner_padding_top &&
      max_width == o.max_width &&
      mobile_stretch_content == o.mobile_stretch_content &&
      width == o.width
end

#_deserialize(type, value) ⇒ Object

Deserializes the data based on type

Parameters:

  • string

    type Data type

  • string

    value Value to be deserialized

Returns:

  • (Object)

    Deserialized data



360
361
362
363
364
365
366
367
368
369
370
371
372
373
374
375
376
377
378
379
380
381
382
383
384
385
386
387
388
389
390
391
392
393
394
395
396
397
# File 'lib/klaviyo-api-sdk/models/image_block_styles.rb', line 360

def _deserialize(type, value)
  case type.to_sym
  when :Time
    Time.parse(value)
  when :Date
    Date.parse(value)
  when :String
    value.to_s
  when :Integer
    value.to_i
  when :Float
    value.to_f
  when :Boolean
    if value.to_s =~ /\A(true|t|yes|y|1)\z/i
      true
    else
      false
    end
  when :Object
    # generic object (usually a Hash), return directly
    value
  when /\AArray<(?<inner_type>.+)>\z/
    inner_type = Regexp.last_match[:inner_type]
    value.map { |v| _deserialize(inner_type, v) }
  when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/
    k_type = Regexp.last_match[:k_type]
    v_type = Regexp.last_match[:v_type]
    {}.tap do |hash|
      value.each do |k, v|
        hash[_deserialize(k_type, k)] = _deserialize(v_type, v)
      end
    end
  else # model
    # models (e.g. Pet) or oneOf
    klass = KlaviyoAPI.const_get(type)
    klass.respond_to?(:openapi_one_of) ? klass.build(value) : klass.build_from_hash(value)
  end
end

#_to_hash(value) ⇒ Hash

Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value

Parameters:

  • value (Object)

    Any valid value

Returns:

  • (Hash)

    Returns the value in the form of hash



431
432
433
434
435
436
437
438
439
440
441
442
443
# File 'lib/klaviyo-api-sdk/models/image_block_styles.rb', line 431

def _to_hash(value)
  if value.is_a?(Array)
    value.compact.map { |v| _to_hash(v) }
  elsif value.is_a?(Hash)
    {}.tap do |hash|
      value.each { |k, v| hash[k] = _to_hash(v) }
    end
  elsif value.respond_to? :to_hash
    value.to_hash
  else
    value
  end
end

#build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



336
337
338
339
340
341
342
343
344
345
346
347
348
349
350
351
352
353
354
# File 'lib/klaviyo-api-sdk/models/image_block_styles.rb', line 336

def build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  self.class.openapi_types.each_pair do |key, type|
    if attributes[self.class.attribute_map[key]].nil? && self.class.openapi_nullable.include?(key)
      self.send("#{key}=", nil)
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[self.class.attribute_map[key]].is_a?(Array)
        self.send("#{key}=", attributes[self.class.attribute_map[key]].map { |v| _deserialize($1, v) })
      end
    elsif !attributes[self.class.attribute_map[key]].nil?
      self.send("#{key}=", _deserialize(type, attributes[self.class.attribute_map[key]]))
    end
  end

  self
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


316
317
318
# File 'lib/klaviyo-api-sdk/models/image_block_styles.rb', line 316

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



322
323
324
# File 'lib/klaviyo-api-sdk/models/image_block_styles.rb', line 322

def hash
  [align, background_color, block_background_color, block_border_color, block_border_style, block_border_width, block_padding_bottom, block_padding_left, block_padding_right, block_padding_top, full_width_mobile, height, inner_padding_bottom, inner_padding_left, inner_padding_right, inner_padding_top, max_width, mobile_stretch_content, width].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



253
254
255
256
# File 'lib/klaviyo-api-sdk/models/image_block_styles.rb', line 253

def list_invalid_properties
  invalid_properties = Array.new
  invalid_properties
end

#to_bodyHash

to_body is an alias to to_hash (backward compatibility)

Returns:

  • (Hash)

    Returns the object in the form of hash



407
408
409
# File 'lib/klaviyo-api-sdk/models/image_block_styles.rb', line 407

def to_body
  to_hash
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



413
414
415
416
417
418
419
420
421
422
423
424
425
# File 'lib/klaviyo-api-sdk/models/image_block_styles.rb', line 413

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#to_sString

Returns the string representation of the object

Returns:

  • (String)

    String presentation of the object



401
402
403
# File 'lib/klaviyo-api-sdk/models/image_block_styles.rb', line 401

def to_s
  to_hash.to_s
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



260
261
262
263
264
265
266
# File 'lib/klaviyo-api-sdk/models/image_block_styles.rb', line 260

def valid?
  align_validator = EnumAttributeValidator.new('String', ["center", "left", "right"])
  return false unless align_validator.valid?(@align)
  block_border_style_validator = EnumAttributeValidator.new('String', ["dashed", "dotted", "groove", "inset", "none", "outset", "ridge", "solid"])
  return false unless block_border_style_validator.valid?(@block_border_style)
  true
end