Class: KlaviyoAPI::ReviewBlockStyles

Inherits:
Object
  • Object
show all
Defined in:
lib/klaviyo-api-sdk/models/review_block_styles.rb

Defined Under Namespace

Classes: EnumAttributeValidator

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ ReviewBlockStyles

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



349
350
351
352
353
354
355
356
357
358
359
360
361
362
363
364
365
366
367
368
369
370
371
372
373
374
375
376
377
378
379
380
381
382
383
384
385
386
387
388
389
390
391
392
393
394
395
396
397
398
399
400
401
402
403
404
405
406
407
408
409
410
411
412
413
414
415
416
417
418
419
420
421
422
423
424
425
426
427
428
429
430
431
432
433
434
435
436
437
438
439
440
441
442
443
444
445
446
447
448
449
450
451
452
453
454
455
456
457
458
459
460
461
462
463
464
465
466
467
468
469
470
471
472
473
474
475
476
477
478
479
480
481
482
483
484
485
486
487
488
489
490
491
492
493
494
495
496
497
498
499
500
501
502
503
504
505
506
507
508
509
510
511
512
513
514
515
516
517
518
519
520
521
522
523
524
525
526
527
528
529
530
531
532
533
534
535
536
537
538
539
540
541
542
543
544
545
546
547
548
549
550
551
552
553
554
555
556
557
558
559
560
561
562
563
564
565
566
567
568
569
570
571
572
573
574
575
576
577
# File 'lib/klaviyo-api-sdk/models/review_block_styles.rb', line 349

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `KlaviyoAPI::ReviewBlockStyles` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!self.class.attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `KlaviyoAPI::ReviewBlockStyles`. Please check the name to make sure it's valid. List of attributes: " + self.class.attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'author_align')
    self.author_align = attributes[:'author_align']
  end

  if attributes.key?(:'author_color')
    self.author_color = attributes[:'author_color']
  end

  if attributes.key?(:'author_font_family')
    self.author_font_family = attributes[:'author_font_family']
  end

  if attributes.key?(:'author_font_size')
    self.author_font_size = attributes[:'author_font_size']
  end

  if attributes.key?(:'author_font_style')
    self.author_font_style = attributes[:'author_font_style']
  end

  if attributes.key?(:'author_font_weight')
    self.author_font_weight = attributes[:'author_font_weight']
  end

  if attributes.key?(:'author_letter_spacing')
    self.author_letter_spacing = attributes[:'author_letter_spacing']
  end

  if attributes.key?(:'author_text_decoration')
    self.author_text_decoration = attributes[:'author_text_decoration']
  end

  if attributes.key?(:'block_background_color')
    self.block_background_color = attributes[:'block_background_color']
  end

  if attributes.key?(:'block_padding_bottom')
    self.block_padding_bottom = attributes[:'block_padding_bottom']
  end

  if attributes.key?(:'block_padding_left')
    self.block_padding_left = attributes[:'block_padding_left']
  end

  if attributes.key?(:'block_padding_right')
    self.block_padding_right = attributes[:'block_padding_right']
  end

  if attributes.key?(:'block_padding_top')
    self.block_padding_top = attributes[:'block_padding_top']
  end

  if attributes.key?(:'border_radius')
    self.border_radius = attributes[:'border_radius']
  end

  if attributes.key?(:'border_style')
    self.border_style = attributes[:'border_style']
  end

  if attributes.key?(:'border_width')
    self.border_width = attributes[:'border_width']
  end

  if attributes.key?(:'empty_star_color')
    self.empty_star_color = attributes[:'empty_star_color']
  end

  if attributes.key?(:'layout')
    self.layout = attributes[:'layout']
  end

  if attributes.key?(:'product_name_align')
    self.product_name_align = attributes[:'product_name_align']
  end

  if attributes.key?(:'product_name_color')
    self.product_name_color = attributes[:'product_name_color']
  end

  if attributes.key?(:'product_name_font_family')
    self.product_name_font_family = attributes[:'product_name_font_family']
  end

  if attributes.key?(:'product_name_font_size')
    self.product_name_font_size = attributes[:'product_name_font_size']
  end

  if attributes.key?(:'product_name_font_style')
    self.product_name_font_style = attributes[:'product_name_font_style']
  end

  if attributes.key?(:'product_name_font_weight')
    self.product_name_font_weight = attributes[:'product_name_font_weight']
  end

  if attributes.key?(:'product_name_letter_spacing')
    self.product_name_letter_spacing = attributes[:'product_name_letter_spacing']
  end

  if attributes.key?(:'product_name_text_decoration')
    self.product_name_text_decoration = attributes[:'product_name_text_decoration']
  end

  if attributes.key?(:'quote_align')
    self.quote_align = attributes[:'quote_align']
  end

  if attributes.key?(:'quote_color')
    self.quote_color = attributes[:'quote_color']
  end

  if attributes.key?(:'quote_font_family')
    self.quote_font_family = attributes[:'quote_font_family']
  end

  if attributes.key?(:'quote_font_size')
    self.quote_font_size = attributes[:'quote_font_size']
  end

  if attributes.key?(:'quote_font_style')
    self.quote_font_style = attributes[:'quote_font_style']
  end

  if attributes.key?(:'quote_font_weight')
    self.quote_font_weight = attributes[:'quote_font_weight']
  end

  if attributes.key?(:'quote_letter_spacing')
    self.quote_letter_spacing = attributes[:'quote_letter_spacing']
  end

  if attributes.key?(:'quote_line_height')
    self.quote_line_height = attributes[:'quote_line_height']
  end

  if attributes.key?(:'quote_style')
    self.quote_style = attributes[:'quote_style']
  end

  if attributes.key?(:'quote_text_decoration')
    self.quote_text_decoration = attributes[:'quote_text_decoration']
  end

  if attributes.key?(:'shadow_color')
    self.shadow_color = attributes[:'shadow_color']
  end

  if attributes.key?(:'star_color')
    self.star_color = attributes[:'star_color']
  end

  if attributes.key?(:'star_size')
    self.star_size = attributes[:'star_size']
  end

  if attributes.key?(:'star_rating_shape')
    self.star_rating_shape = attributes[:'star_rating_shape']
  end

  if attributes.key?(:'star_icon_spacing')
    self.star_icon_spacing = attributes[:'star_icon_spacing']
  end

  if attributes.key?(:'star_alignment')
    self.star_alignment = attributes[:'star_alignment']
  end

  if attributes.key?(:'text_area_bg_color')
    self.text_area_bg_color = attributes[:'text_area_bg_color']
  end

  if attributes.key?(:'text_area_border_color')
    self.text_area_border_color = attributes[:'text_area_border_color']
  end

  if attributes.key?(:'verified_color')
    self.verified_color = attributes[:'verified_color']
  end

  if attributes.key?(:'verified_font_family')
    self.verified_font_family = attributes[:'verified_font_family']
  end

  if attributes.key?(:'verified_font_size')
    self.verified_font_size = attributes[:'verified_font_size']
  end

  if attributes.key?(:'verified_font_style')
    self.verified_font_style = attributes[:'verified_font_style']
  end

  if attributes.key?(:'verified_font_weight')
    self.verified_font_weight = attributes[:'verified_font_weight']
  end

  if attributes.key?(:'verified_letter_spacing')
    self.verified_letter_spacing = attributes[:'verified_letter_spacing']
  end

  if attributes.key?(:'verified_text_decoration')
    self.verified_text_decoration = attributes[:'verified_text_decoration']
  end

  if attributes.key?(:'verified_badge_color')
    self.verified_badge_color = attributes[:'verified_badge_color']
  end

  if attributes.key?(:'verified_badge_size')
    self.verified_badge_size = attributes[:'verified_badge_size']
  end

  if attributes.key?(:'verified_badge_style')
    self.verified_badge_style = attributes[:'verified_badge_style']
  end
end

Instance Attribute Details

#author_alignObject

Text Alignment.



18
19
20
# File 'lib/klaviyo-api-sdk/models/review_block_styles.rb', line 18

def author_align
  @author_align
end

#author_colorObject

Returns the value of attribute author_color.



20
21
22
# File 'lib/klaviyo-api-sdk/models/review_block_styles.rb', line 20

def author_color
  @author_color
end

#author_font_familyObject

Returns the value of attribute author_font_family.



22
23
24
# File 'lib/klaviyo-api-sdk/models/review_block_styles.rb', line 22

def author_font_family
  @author_font_family
end

#author_font_sizeObject

Returns the value of attribute author_font_size.



24
25
26
# File 'lib/klaviyo-api-sdk/models/review_block_styles.rb', line 24

def author_font_size
  @author_font_size
end

#author_font_styleObject

Font style.



27
28
29
# File 'lib/klaviyo-api-sdk/models/review_block_styles.rb', line 27

def author_font_style
  @author_font_style
end

#author_font_weightObject

Returns the value of attribute author_font_weight.



29
30
31
# File 'lib/klaviyo-api-sdk/models/review_block_styles.rb', line 29

def author_font_weight
  @author_font_weight
end

#author_letter_spacingObject

Returns the value of attribute author_letter_spacing.



31
32
33
# File 'lib/klaviyo-api-sdk/models/review_block_styles.rb', line 31

def author_letter_spacing
  @author_letter_spacing
end

#author_text_decorationObject

Returns the value of attribute author_text_decoration.



33
34
35
# File 'lib/klaviyo-api-sdk/models/review_block_styles.rb', line 33

def author_text_decoration
  @author_text_decoration
end

#block_background_colorObject

Returns the value of attribute block_background_color.



35
36
37
# File 'lib/klaviyo-api-sdk/models/review_block_styles.rb', line 35

def block_background_color
  @block_background_color
end

#block_padding_bottomObject

Returns the value of attribute block_padding_bottom.



37
38
39
# File 'lib/klaviyo-api-sdk/models/review_block_styles.rb', line 37

def block_padding_bottom
  @block_padding_bottom
end

#block_padding_leftObject

Returns the value of attribute block_padding_left.



39
40
41
# File 'lib/klaviyo-api-sdk/models/review_block_styles.rb', line 39

def block_padding_left
  @block_padding_left
end

#block_padding_rightObject

Returns the value of attribute block_padding_right.



41
42
43
# File 'lib/klaviyo-api-sdk/models/review_block_styles.rb', line 41

def block_padding_right
  @block_padding_right
end

#block_padding_topObject

Returns the value of attribute block_padding_top.



43
44
45
# File 'lib/klaviyo-api-sdk/models/review_block_styles.rb', line 43

def block_padding_top
  @block_padding_top
end

#border_radiusObject

Returns the value of attribute border_radius.



45
46
47
# File 'lib/klaviyo-api-sdk/models/review_block_styles.rb', line 45

def border_radius
  @border_radius
end

#border_styleObject

Border style.



48
49
50
# File 'lib/klaviyo-api-sdk/models/review_block_styles.rb', line 48

def border_style
  @border_style
end

#border_widthObject

Returns the value of attribute border_width.



50
51
52
# File 'lib/klaviyo-api-sdk/models/review_block_styles.rb', line 50

def border_width
  @border_width
end

#empty_star_colorObject

Returns the value of attribute empty_star_color.



52
53
54
# File 'lib/klaviyo-api-sdk/models/review_block_styles.rb', line 52

def empty_star_color
  @empty_star_color
end

#layoutObject

Review block layout options.



55
56
57
# File 'lib/klaviyo-api-sdk/models/review_block_styles.rb', line 55

def layout
  @layout
end

#product_name_alignObject

Text Alignment.



58
59
60
# File 'lib/klaviyo-api-sdk/models/review_block_styles.rb', line 58

def product_name_align
  @product_name_align
end

#product_name_colorObject

Returns the value of attribute product_name_color.



60
61
62
# File 'lib/klaviyo-api-sdk/models/review_block_styles.rb', line 60

def product_name_color
  @product_name_color
end

#product_name_font_familyObject

Returns the value of attribute product_name_font_family.



62
63
64
# File 'lib/klaviyo-api-sdk/models/review_block_styles.rb', line 62

def product_name_font_family
  @product_name_font_family
end

#product_name_font_sizeObject

Returns the value of attribute product_name_font_size.



64
65
66
# File 'lib/klaviyo-api-sdk/models/review_block_styles.rb', line 64

def product_name_font_size
  @product_name_font_size
end

#product_name_font_styleObject

Font style.



67
68
69
# File 'lib/klaviyo-api-sdk/models/review_block_styles.rb', line 67

def product_name_font_style
  @product_name_font_style
end

#product_name_font_weightObject

Returns the value of attribute product_name_font_weight.



69
70
71
# File 'lib/klaviyo-api-sdk/models/review_block_styles.rb', line 69

def product_name_font_weight
  @product_name_font_weight
end

#product_name_letter_spacingObject

Returns the value of attribute product_name_letter_spacing.



71
72
73
# File 'lib/klaviyo-api-sdk/models/review_block_styles.rb', line 71

def product_name_letter_spacing
  @product_name_letter_spacing
end

#product_name_text_decorationObject

Returns the value of attribute product_name_text_decoration.



73
74
75
# File 'lib/klaviyo-api-sdk/models/review_block_styles.rb', line 73

def product_name_text_decoration
  @product_name_text_decoration
end

#quote_alignObject

Text Alignment.



76
77
78
# File 'lib/klaviyo-api-sdk/models/review_block_styles.rb', line 76

def quote_align
  @quote_align
end

#quote_colorObject

Returns the value of attribute quote_color.



78
79
80
# File 'lib/klaviyo-api-sdk/models/review_block_styles.rb', line 78

def quote_color
  @quote_color
end

#quote_font_familyObject

Returns the value of attribute quote_font_family.



80
81
82
# File 'lib/klaviyo-api-sdk/models/review_block_styles.rb', line 80

def quote_font_family
  @quote_font_family
end

#quote_font_sizeObject

Returns the value of attribute quote_font_size.



82
83
84
# File 'lib/klaviyo-api-sdk/models/review_block_styles.rb', line 82

def quote_font_size
  @quote_font_size
end

#quote_font_styleObject

Font style.



85
86
87
# File 'lib/klaviyo-api-sdk/models/review_block_styles.rb', line 85

def quote_font_style
  @quote_font_style
end

#quote_font_weightObject

Returns the value of attribute quote_font_weight.



87
88
89
# File 'lib/klaviyo-api-sdk/models/review_block_styles.rb', line 87

def quote_font_weight
  @quote_font_weight
end

#quote_letter_spacingObject

Returns the value of attribute quote_letter_spacing.



89
90
91
# File 'lib/klaviyo-api-sdk/models/review_block_styles.rb', line 89

def quote_letter_spacing
  @quote_letter_spacing
end

#quote_line_heightObject

Returns the value of attribute quote_line_height.



91
92
93
# File 'lib/klaviyo-api-sdk/models/review_block_styles.rb', line 91

def quote_line_height
  @quote_line_height
end

#quote_styleObject

Review block quote style.



94
95
96
# File 'lib/klaviyo-api-sdk/models/review_block_styles.rb', line 94

def quote_style
  @quote_style
end

#quote_text_decorationObject

Returns the value of attribute quote_text_decoration.



96
97
98
# File 'lib/klaviyo-api-sdk/models/review_block_styles.rb', line 96

def quote_text_decoration
  @quote_text_decoration
end

#shadow_colorObject

Shadow color.



99
100
101
# File 'lib/klaviyo-api-sdk/models/review_block_styles.rb', line 99

def shadow_color
  @shadow_color
end

#star_alignmentObject

Text Alignment.



112
113
114
# File 'lib/klaviyo-api-sdk/models/review_block_styles.rb', line 112

def star_alignment
  @star_alignment
end

#star_colorObject

Returns the value of attribute star_color.



101
102
103
# File 'lib/klaviyo-api-sdk/models/review_block_styles.rb', line 101

def star_color
  @star_color
end

#star_icon_spacingObject

Returns the value of attribute star_icon_spacing.



109
110
111
# File 'lib/klaviyo-api-sdk/models/review_block_styles.rb', line 109

def star_icon_spacing
  @star_icon_spacing
end

#star_rating_shapeObject

Review block star rating shape.



107
108
109
# File 'lib/klaviyo-api-sdk/models/review_block_styles.rb', line 107

def star_rating_shape
  @star_rating_shape
end

#star_sizeObject

Review block star size.



104
105
106
# File 'lib/klaviyo-api-sdk/models/review_block_styles.rb', line 104

def star_size
  @star_size
end

#text_area_bg_colorObject

Returns the value of attribute text_area_bg_color.



114
115
116
# File 'lib/klaviyo-api-sdk/models/review_block_styles.rb', line 114

def text_area_bg_color
  @text_area_bg_color
end

#text_area_border_colorObject

Returns the value of attribute text_area_border_color.



116
117
118
# File 'lib/klaviyo-api-sdk/models/review_block_styles.rb', line 116

def text_area_border_color
  @text_area_border_color
end

#verified_badge_colorObject

Returns the value of attribute verified_badge_color.



133
134
135
# File 'lib/klaviyo-api-sdk/models/review_block_styles.rb', line 133

def verified_badge_color
  @verified_badge_color
end

#verified_badge_sizeObject

Returns the value of attribute verified_badge_size.



135
136
137
# File 'lib/klaviyo-api-sdk/models/review_block_styles.rb', line 135

def verified_badge_size
  @verified_badge_size
end

#verified_badge_styleObject

Review block verified badge style.



138
139
140
# File 'lib/klaviyo-api-sdk/models/review_block_styles.rb', line 138

def verified_badge_style
  @verified_badge_style
end

#verified_colorObject

Returns the value of attribute verified_color.



118
119
120
# File 'lib/klaviyo-api-sdk/models/review_block_styles.rb', line 118

def verified_color
  @verified_color
end

#verified_font_familyObject

Returns the value of attribute verified_font_family.



120
121
122
# File 'lib/klaviyo-api-sdk/models/review_block_styles.rb', line 120

def verified_font_family
  @verified_font_family
end

#verified_font_sizeObject

Returns the value of attribute verified_font_size.



122
123
124
# File 'lib/klaviyo-api-sdk/models/review_block_styles.rb', line 122

def verified_font_size
  @verified_font_size
end

#verified_font_styleObject

Font style.



125
126
127
# File 'lib/klaviyo-api-sdk/models/review_block_styles.rb', line 125

def verified_font_style
  @verified_font_style
end

#verified_font_weightObject

Returns the value of attribute verified_font_weight.



127
128
129
# File 'lib/klaviyo-api-sdk/models/review_block_styles.rb', line 127

def verified_font_weight
  @verified_font_weight
end

#verified_letter_spacingObject

Returns the value of attribute verified_letter_spacing.



129
130
131
# File 'lib/klaviyo-api-sdk/models/review_block_styles.rb', line 129

def verified_letter_spacing
  @verified_letter_spacing
end

#verified_text_decorationObject

Returns the value of attribute verified_text_decoration.



131
132
133
# File 'lib/klaviyo-api-sdk/models/review_block_styles.rb', line 131

def verified_text_decoration
  @verified_text_decoration
end

Class Method Details

.acceptable_attributesObject

Returns all the JSON keys this model knows about



223
224
225
# File 'lib/klaviyo-api-sdk/models/review_block_styles.rb', line 223

def self.acceptable_attributes
  attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
210
211
212
213
214
215
216
217
218
219
220
# File 'lib/klaviyo-api-sdk/models/review_block_styles.rb', line 163

def self.attribute_map
  {
    :'author_align' => :'author_align',
    :'author_color' => :'author_color',
    :'author_font_family' => :'author_font_family',
    :'author_font_size' => :'author_font_size',
    :'author_font_style' => :'author_font_style',
    :'author_font_weight' => :'author_font_weight',
    :'author_letter_spacing' => :'author_letter_spacing',
    :'author_text_decoration' => :'author_text_decoration',
    :'block_background_color' => :'block_background_color',
    :'block_padding_bottom' => :'block_padding_bottom',
    :'block_padding_left' => :'block_padding_left',
    :'block_padding_right' => :'block_padding_right',
    :'block_padding_top' => :'block_padding_top',
    :'border_radius' => :'border_radius',
    :'border_style' => :'border_style',
    :'border_width' => :'border_width',
    :'empty_star_color' => :'empty_star_color',
    :'layout' => :'layout',
    :'product_name_align' => :'product_name_align',
    :'product_name_color' => :'product_name_color',
    :'product_name_font_family' => :'product_name_font_family',
    :'product_name_font_size' => :'product_name_font_size',
    :'product_name_font_style' => :'product_name_font_style',
    :'product_name_font_weight' => :'product_name_font_weight',
    :'product_name_letter_spacing' => :'product_name_letter_spacing',
    :'product_name_text_decoration' => :'product_name_text_decoration',
    :'quote_align' => :'quote_align',
    :'quote_color' => :'quote_color',
    :'quote_font_family' => :'quote_font_family',
    :'quote_font_size' => :'quote_font_size',
    :'quote_font_style' => :'quote_font_style',
    :'quote_font_weight' => :'quote_font_weight',
    :'quote_letter_spacing' => :'quote_letter_spacing',
    :'quote_line_height' => :'quote_line_height',
    :'quote_style' => :'quote_style',
    :'quote_text_decoration' => :'quote_text_decoration',
    :'shadow_color' => :'shadow_color',
    :'star_color' => :'star_color',
    :'star_size' => :'star_size',
    :'star_rating_shape' => :'star_rating_shape',
    :'star_icon_spacing' => :'star_icon_spacing',
    :'star_alignment' => :'star_alignment',
    :'text_area_bg_color' => :'text_area_bg_color',
    :'text_area_border_color' => :'text_area_border_color',
    :'verified_color' => :'verified_color',
    :'verified_font_family' => :'verified_font_family',
    :'verified_font_size' => :'verified_font_size',
    :'verified_font_style' => :'verified_font_style',
    :'verified_font_weight' => :'verified_font_weight',
    :'verified_letter_spacing' => :'verified_letter_spacing',
    :'verified_text_decoration' => :'verified_text_decoration',
    :'verified_badge_color' => :'verified_badge_color',
    :'verified_badge_size' => :'verified_badge_size',
    :'verified_badge_style' => :'verified_badge_style'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



848
849
850
# File 'lib/klaviyo-api-sdk/models/review_block_styles.rb', line 848

def self.build_from_hash(attributes)
  new.build_from_hash(attributes)
end

.openapi_nullableObject

List of attributes with nullable: true



288
289
290
291
292
293
294
295
296
297
298
299
300
301
302
303
304
305
306
307
308
309
310
311
312
313
314
315
316
317
318
319
320
321
322
323
324
325
326
327
328
329
330
331
332
333
334
335
336
337
338
339
340
341
342
343
344
345
# File 'lib/klaviyo-api-sdk/models/review_block_styles.rb', line 288

def self.openapi_nullable
  Set.new([
    :'author_align',
    :'author_color',
    :'author_font_family',
    :'author_font_size',
    :'author_font_style',
    :'author_font_weight',
    :'author_letter_spacing',
    :'author_text_decoration',
    :'block_background_color',
    :'block_padding_bottom',
    :'block_padding_left',
    :'block_padding_right',
    :'block_padding_top',
    :'border_radius',
    :'border_style',
    :'border_width',
    :'empty_star_color',
    :'layout',
    :'product_name_align',
    :'product_name_color',
    :'product_name_font_family',
    :'product_name_font_size',
    :'product_name_font_style',
    :'product_name_font_weight',
    :'product_name_letter_spacing',
    :'product_name_text_decoration',
    :'quote_align',
    :'quote_color',
    :'quote_font_family',
    :'quote_font_size',
    :'quote_font_style',
    :'quote_font_weight',
    :'quote_letter_spacing',
    :'quote_line_height',
    :'quote_style',
    :'quote_text_decoration',
    :'shadow_color',
    :'star_color',
    :'star_size',
    :'star_rating_shape',
    :'star_icon_spacing',
    :'star_alignment',
    :'text_area_bg_color',
    :'text_area_border_color',
    :'verified_color',
    :'verified_font_family',
    :'verified_font_size',
    :'verified_font_style',
    :'verified_font_weight',
    :'verified_letter_spacing',
    :'verified_text_decoration',
    :'verified_badge_color',
    :'verified_badge_size',
    :'verified_badge_style'
  ])
end

.openapi_typesObject

Attribute type mapping.



228
229
230
231
232
233
234
235
236
237
238
239
240
241
242
243
244
245
246
247
248
249
250
251
252
253
254
255
256
257
258
259
260
261
262
263
264
265
266
267
268
269
270
271
272
273
274
275
276
277
278
279
280
281
282
283
284
285
# File 'lib/klaviyo-api-sdk/models/review_block_styles.rb', line 228

def self.openapi_types
  {
    :'author_align' => :'String',
    :'author_color' => :'String',
    :'author_font_family' => :'String',
    :'author_font_size' => :'Integer',
    :'author_font_style' => :'String',
    :'author_font_weight' => :'String',
    :'author_letter_spacing' => :'Integer',
    :'author_text_decoration' => :'String',
    :'block_background_color' => :'String',
    :'block_padding_bottom' => :'Integer',
    :'block_padding_left' => :'Integer',
    :'block_padding_right' => :'Integer',
    :'block_padding_top' => :'Integer',
    :'border_radius' => :'Integer',
    :'border_style' => :'String',
    :'border_width' => :'Integer',
    :'empty_star_color' => :'String',
    :'layout' => :'String',
    :'product_name_align' => :'String',
    :'product_name_color' => :'String',
    :'product_name_font_family' => :'String',
    :'product_name_font_size' => :'Integer',
    :'product_name_font_style' => :'String',
    :'product_name_font_weight' => :'String',
    :'product_name_letter_spacing' => :'Integer',
    :'product_name_text_decoration' => :'String',
    :'quote_align' => :'String',
    :'quote_color' => :'String',
    :'quote_font_family' => :'String',
    :'quote_font_size' => :'Integer',
    :'quote_font_style' => :'String',
    :'quote_font_weight' => :'String',
    :'quote_letter_spacing' => :'Integer',
    :'quote_line_height' => :'Float',
    :'quote_style' => :'String',
    :'quote_text_decoration' => :'String',
    :'shadow_color' => :'String',
    :'star_color' => :'String',
    :'star_size' => :'String',
    :'star_rating_shape' => :'String',
    :'star_icon_spacing' => :'Integer',
    :'star_alignment' => :'String',
    :'text_area_bg_color' => :'String',
    :'text_area_border_color' => :'String',
    :'verified_color' => :'String',
    :'verified_font_family' => :'String',
    :'verified_font_size' => :'Integer',
    :'verified_font_style' => :'String',
    :'verified_font_weight' => :'String',
    :'verified_letter_spacing' => :'Integer',
    :'verified_text_decoration' => :'String',
    :'verified_badge_color' => :'String',
    :'verified_badge_size' => :'Integer',
    :'verified_badge_style' => :'String'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



774
775
776
777
778
779
780
781
782
783
784
785
786
787
788
789
790
791
792
793
794
795
796
797
798
799
800
801
802
803
804
805
806
807
808
809
810
811
812
813
814
815
816
817
818
819
820
821
822
823
824
825
826
827
828
829
830
831
# File 'lib/klaviyo-api-sdk/models/review_block_styles.rb', line 774

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      author_align == o.author_align &&
      author_color == o.author_color &&
      author_font_family == o.author_font_family &&
      author_font_size == o.author_font_size &&
      author_font_style == o.author_font_style &&
      author_font_weight == o.author_font_weight &&
      author_letter_spacing == o.author_letter_spacing &&
      author_text_decoration == o.author_text_decoration &&
      block_background_color == o.block_background_color &&
      block_padding_bottom == o.block_padding_bottom &&
      block_padding_left == o.block_padding_left &&
      block_padding_right == o.block_padding_right &&
      block_padding_top == o.block_padding_top &&
      border_radius == o.border_radius &&
      border_style == o.border_style &&
      border_width == o.border_width &&
      empty_star_color == o.empty_star_color &&
      layout == o.layout &&
      product_name_align == o.product_name_align &&
      product_name_color == o.product_name_color &&
      product_name_font_family == o.product_name_font_family &&
      product_name_font_size == o.product_name_font_size &&
      product_name_font_style == o.product_name_font_style &&
      product_name_font_weight == o.product_name_font_weight &&
      product_name_letter_spacing == o.product_name_letter_spacing &&
      product_name_text_decoration == o.product_name_text_decoration &&
      quote_align == o.quote_align &&
      quote_color == o.quote_color &&
      quote_font_family == o.quote_font_family &&
      quote_font_size == o.quote_font_size &&
      quote_font_style == o.quote_font_style &&
      quote_font_weight == o.quote_font_weight &&
      quote_letter_spacing == o.quote_letter_spacing &&
      quote_line_height == o.quote_line_height &&
      quote_style == o.quote_style &&
      quote_text_decoration == o.quote_text_decoration &&
      shadow_color == o.shadow_color &&
      star_color == o.star_color &&
      star_size == o.star_size &&
      star_rating_shape == o.star_rating_shape &&
      star_icon_spacing == o.star_icon_spacing &&
      star_alignment == o.star_alignment &&
      text_area_bg_color == o.text_area_bg_color &&
      text_area_border_color == o.text_area_border_color &&
      verified_color == o.verified_color &&
      verified_font_family == o.verified_font_family &&
      verified_font_size == o.verified_font_size &&
      verified_font_style == o.verified_font_style &&
      verified_font_weight == o.verified_font_weight &&
      verified_letter_spacing == o.verified_letter_spacing &&
      verified_text_decoration == o.verified_text_decoration &&
      verified_badge_color == o.verified_badge_color &&
      verified_badge_size == o.verified_badge_size &&
      verified_badge_style == o.verified_badge_style
end

#_deserialize(type, value) ⇒ Object

Deserializes the data based on type

Parameters:

  • string

    type Data type

  • string

    value Value to be deserialized

Returns:

  • (Object)

    Deserialized data



879
880
881
882
883
884
885
886
887
888
889
890
891
892
893
894
895
896
897
898
899
900
901
902
903
904
905
906
907
908
909
910
911
912
913
914
915
916
# File 'lib/klaviyo-api-sdk/models/review_block_styles.rb', line 879

def _deserialize(type, value)
  case type.to_sym
  when :Time
    Time.parse(value)
  when :Date
    Date.parse(value)
  when :String
    value.to_s
  when :Integer
    value.to_i
  when :Float
    value.to_f
  when :Boolean
    if value.to_s =~ /\A(true|t|yes|y|1)\z/i
      true
    else
      false
    end
  when :Object
    # generic object (usually a Hash), return directly
    value
  when /\AArray<(?<inner_type>.+)>\z/
    inner_type = Regexp.last_match[:inner_type]
    value.map { |v| _deserialize(inner_type, v) }
  when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/
    k_type = Regexp.last_match[:k_type]
    v_type = Regexp.last_match[:v_type]
    {}.tap do |hash|
      value.each do |k, v|
        hash[_deserialize(k_type, k)] = _deserialize(v_type, v)
      end
    end
  else # model
    # models (e.g. Pet) or oneOf
    klass = KlaviyoAPI.const_get(type)
    klass.respond_to?(:openapi_one_of) ? klass.build(value) : klass.build_from_hash(value)
  end
end

#_to_hash(value) ⇒ Hash

Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value

Parameters:

  • value (Object)

    Any valid value

Returns:

  • (Hash)

    Returns the value in the form of hash



950
951
952
953
954
955
956
957
958
959
960
961
962
# File 'lib/klaviyo-api-sdk/models/review_block_styles.rb', line 950

def _to_hash(value)
  if value.is_a?(Array)
    value.compact.map { |v| _to_hash(v) }
  elsif value.is_a?(Hash)
    {}.tap do |hash|
      value.each { |k, v| hash[k] = _to_hash(v) }
    end
  elsif value.respond_to? :to_hash
    value.to_hash
  else
    value
  end
end

#build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



855
856
857
858
859
860
861
862
863
864
865
866
867
868
869
870
871
872
873
# File 'lib/klaviyo-api-sdk/models/review_block_styles.rb', line 855

def build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  self.class.openapi_types.each_pair do |key, type|
    if attributes[self.class.attribute_map[key]].nil? && self.class.openapi_nullable.include?(key)
      self.send("#{key}=", nil)
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[self.class.attribute_map[key]].is_a?(Array)
        self.send("#{key}=", attributes[self.class.attribute_map[key]].map { |v| _deserialize($1, v) })
      end
    elsif !attributes[self.class.attribute_map[key]].nil?
      self.send("#{key}=", _deserialize(type, attributes[self.class.attribute_map[key]]))
    end
  end

  self
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


835
836
837
# File 'lib/klaviyo-api-sdk/models/review_block_styles.rb', line 835

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



841
842
843
# File 'lib/klaviyo-api-sdk/models/review_block_styles.rb', line 841

def hash
  [author_align, author_color, author_font_family, author_font_size, author_font_style, author_font_weight, author_letter_spacing, author_text_decoration, block_background_color, block_padding_bottom, block_padding_left, block_padding_right, block_padding_top, border_radius, border_style, border_width, empty_star_color, layout, product_name_align, product_name_color, product_name_font_family, product_name_font_size, product_name_font_style, product_name_font_weight, product_name_letter_spacing, product_name_text_decoration, quote_align, quote_color, quote_font_family, quote_font_size, quote_font_style, quote_font_weight, quote_letter_spacing, quote_line_height, quote_style, quote_text_decoration, shadow_color, star_color, star_size, star_rating_shape, star_icon_spacing, star_alignment, text_area_bg_color, text_area_border_color, verified_color, verified_font_family, verified_font_size, verified_font_style, verified_font_weight, verified_letter_spacing, verified_text_decoration, verified_badge_color, verified_badge_size, verified_badge_style].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



581
582
583
584
# File 'lib/klaviyo-api-sdk/models/review_block_styles.rb', line 581

def list_invalid_properties
  invalid_properties = Array.new
  invalid_properties
end

#to_bodyHash

to_body is an alias to to_hash (backward compatibility)

Returns:

  • (Hash)

    Returns the object in the form of hash



926
927
928
# File 'lib/klaviyo-api-sdk/models/review_block_styles.rb', line 926

def to_body
  to_hash
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



932
933
934
935
936
937
938
939
940
941
942
943
944
# File 'lib/klaviyo-api-sdk/models/review_block_styles.rb', line 932

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#to_sString

Returns the string representation of the object

Returns:

  • (String)

    String presentation of the object



920
921
922
# File 'lib/klaviyo-api-sdk/models/review_block_styles.rb', line 920

def to_s
  to_hash.to_s
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



588
589
590
591
592
593
594
595
596
597
598
599
600
601
602
603
604
605
606
607
608
609
610
611
612
613
614
615
616
617
618
619
620
# File 'lib/klaviyo-api-sdk/models/review_block_styles.rb', line 588

def valid?
  author_align_validator = EnumAttributeValidator.new('String', ["center", "left", "right"])
  return false unless author_align_validator.valid?(@author_align)
  author_font_style_validator = EnumAttributeValidator.new('String', ["italic", "normal"])
  return false unless author_font_style_validator.valid?(@author_font_style)
  border_style_validator = EnumAttributeValidator.new('String', ["dashed", "dotted", "groove", "inset", "none", "outset", "ridge", "solid"])
  return false unless border_style_validator.valid?(@border_style)
  layout_validator = EnumAttributeValidator.new('String', ["big-quotes", "centered-in-quote-bubble", "centered-rating-first", "centered-review-first", "clean", "left-aligned", "message-bubble", "rating-highlight", "right-aligned-with-quotation-icon", "square", "stacked-card", "subtle-background"])
  return false unless layout_validator.valid?(@layout)
  product_name_align_validator = EnumAttributeValidator.new('String', ["center", "left", "right"])
  return false unless product_name_align_validator.valid?(@product_name_align)
  product_name_font_style_validator = EnumAttributeValidator.new('String', ["italic", "normal"])
  return false unless product_name_font_style_validator.valid?(@product_name_font_style)
  quote_align_validator = EnumAttributeValidator.new('String', ["center", "left", "right"])
  return false unless quote_align_validator.valid?(@quote_align)
  quote_font_style_validator = EnumAttributeValidator.new('String', ["italic", "normal"])
  return false unless quote_font_style_validator.valid?(@quote_font_style)
  quote_style_validator = EnumAttributeValidator.new('String', ["line", "square", "standard"])
  return false unless quote_style_validator.valid?(@quote_style)
  shadow_color_validator = EnumAttributeValidator.new('String', ["dark", "light", "medium"])
  return false unless shadow_color_validator.valid?(@shadow_color)
  star_size_validator = EnumAttributeValidator.new('String', ["large", "medium", "small"])
  return false unless star_size_validator.valid?(@star_size)
  star_rating_shape_validator = EnumAttributeValidator.new('String', ["circle", "heart", "star"])
  return false unless star_rating_shape_validator.valid?(@star_rating_shape)
  star_alignment_validator = EnumAttributeValidator.new('String', ["center", "left", "right"])
  return false unless star_alignment_validator.valid?(@star_alignment)
  verified_font_style_validator = EnumAttributeValidator.new('String', ["italic", "normal"])
  return false unless verified_font_style_validator.valid?(@verified_font_style)
  verified_badge_style_validator = EnumAttributeValidator.new('String', ["badge-and-text", "badge-only", "text-only"])
  return false unless verified_badge_style_validator.valid?(@verified_badge_style)
  true
end