Class: KlaviyoAPI::StaticReviewBlockProperties

Inherits:
Object
  • Object
show all
Defined in:
lib/klaviyo-api-sdk/models/static_review_block_properties.rb

Defined Under Namespace

Classes: EnumAttributeValidator

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ StaticReviewBlockProperties

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
210
211
212
213
214
215
216
217
218
219
220
221
222
223
224
225
226
227
228
229
230
# File 'lib/klaviyo-api-sdk/models/static_review_block_properties.rb', line 150

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `KlaviyoAPI::StaticReviewBlockProperties` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!self.class.attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `KlaviyoAPI::StaticReviewBlockProperties`. Please check the name to make sure it's valid. List of attributes: " + self.class.attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'show_rating')
    self.show_rating = attributes[:'show_rating']
  end

  if attributes.key?(:'show_reviewer_name')
    self.show_reviewer_name = attributes[:'show_reviewer_name']
  end

  if attributes.key?(:'show_product_name')
    self.show_product_name = attributes[:'show_product_name']
  end

  if attributes.key?(:'show_variant_name')
    self.show_variant_name = attributes[:'show_variant_name']
  end

  if attributes.key?(:'show_verified_badge')
    self.show_verified_badge = attributes[:'show_verified_badge']
  end

  if attributes.key?(:'author_placeholder')
    self.author_placeholder = attributes[:'author_placeholder']
  end

  if attributes.key?(:'quote_placeholder')
    self.quote_placeholder = attributes[:'quote_placeholder']
  end

  if attributes.key?(:'product_name_placeholder')
    self.product_name_placeholder = attributes[:'product_name_placeholder']
  end

  if attributes.key?(:'product_variant_name_placeholder')
    self.product_variant_name_placeholder = attributes[:'product_variant_name_placeholder']
  end

  if attributes.key?(:'verified_badge_language')
    self.verified_badge_language = attributes[:'verified_badge_language']
  end

  if attributes.key?(:'dynamic')
    self.dynamic = attributes[:'dynamic']
  end

  if attributes.key?(:'author')
    self.author = attributes[:'author']
  end

  if attributes.key?(:'product_name')
    self.product_name = attributes[:'product_name']
  end

  if attributes.key?(:'product_variant_name')
    self.product_variant_name = attributes[:'product_variant_name']
  end

  if attributes.key?(:'quote')
    self.quote = attributes[:'quote']
  end

  if attributes.key?(:'stars')
    self.stars = attributes[:'stars']
  end

  if attributes.key?(:'verified')
    self.verified = attributes[:'verified']
  end
end

Instance Attribute Details

#authorObject

Returns the value of attribute author.



40
41
42
# File 'lib/klaviyo-api-sdk/models/static_review_block_properties.rb', line 40

def author
  @author
end

#author_placeholderObject

Returns the value of attribute author_placeholder.



27
28
29
# File 'lib/klaviyo-api-sdk/models/static_review_block_properties.rb', line 27

def author_placeholder
  @author_placeholder
end

#dynamicObject

Returns the value of attribute dynamic.



38
39
40
# File 'lib/klaviyo-api-sdk/models/static_review_block_properties.rb', line 38

def dynamic
  @dynamic
end

#product_nameObject

Returns the value of attribute product_name.



42
43
44
# File 'lib/klaviyo-api-sdk/models/static_review_block_properties.rb', line 42

def product_name
  @product_name
end

#product_name_placeholderObject

Returns the value of attribute product_name_placeholder.



31
32
33
# File 'lib/klaviyo-api-sdk/models/static_review_block_properties.rb', line 31

def product_name_placeholder
  @product_name_placeholder
end

#product_variant_nameObject

Returns the value of attribute product_variant_name.



44
45
46
# File 'lib/klaviyo-api-sdk/models/static_review_block_properties.rb', line 44

def product_variant_name
  @product_variant_name
end

#product_variant_name_placeholderObject

Returns the value of attribute product_variant_name_placeholder.



33
34
35
# File 'lib/klaviyo-api-sdk/models/static_review_block_properties.rb', line 33

def product_variant_name_placeholder
  @product_variant_name_placeholder
end

#quoteObject

Returns the value of attribute quote.



46
47
48
# File 'lib/klaviyo-api-sdk/models/static_review_block_properties.rb', line 46

def quote
  @quote
end

#quote_placeholderObject

Returns the value of attribute quote_placeholder.



29
30
31
# File 'lib/klaviyo-api-sdk/models/static_review_block_properties.rb', line 29

def quote_placeholder
  @quote_placeholder
end

#show_product_nameObject

Returns the value of attribute show_product_name.



21
22
23
# File 'lib/klaviyo-api-sdk/models/static_review_block_properties.rb', line 21

def show_product_name
  @show_product_name
end

#show_ratingObject

Returns the value of attribute show_rating.



17
18
19
# File 'lib/klaviyo-api-sdk/models/static_review_block_properties.rb', line 17

def show_rating
  @show_rating
end

#show_reviewer_nameObject

Returns the value of attribute show_reviewer_name.



19
20
21
# File 'lib/klaviyo-api-sdk/models/static_review_block_properties.rb', line 19

def show_reviewer_name
  @show_reviewer_name
end

#show_variant_nameObject

Returns the value of attribute show_variant_name.



23
24
25
# File 'lib/klaviyo-api-sdk/models/static_review_block_properties.rb', line 23

def show_variant_name
  @show_variant_name
end

#show_verified_badgeObject

Returns the value of attribute show_verified_badge.



25
26
27
# File 'lib/klaviyo-api-sdk/models/static_review_block_properties.rb', line 25

def show_verified_badge
  @show_verified_badge
end

#starsObject

Returns the value of attribute stars.



48
49
50
# File 'lib/klaviyo-api-sdk/models/static_review_block_properties.rb', line 48

def stars
  @stars
end

#verifiedObject

Returns the value of attribute verified.



50
51
52
# File 'lib/klaviyo-api-sdk/models/static_review_block_properties.rb', line 50

def verified
  @verified
end

#verified_badge_languageObject

Review block verified badge language.



36
37
38
# File 'lib/klaviyo-api-sdk/models/static_review_block_properties.rb', line 36

def verified_badge_language
  @verified_badge_language
end

Class Method Details

.acceptable_attributesObject

Returns all the JSON keys this model knows about



98
99
100
# File 'lib/klaviyo-api-sdk/models/static_review_block_properties.rb', line 98

def self.acceptable_attributes
  attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



75
76
77
78
79
80
81
82
83
84
85
86
87
88
89
90
91
92
93
94
95
# File 'lib/klaviyo-api-sdk/models/static_review_block_properties.rb', line 75

def self.attribute_map
  {
    :'show_rating' => :'show_rating',
    :'show_reviewer_name' => :'show_reviewer_name',
    :'show_product_name' => :'show_product_name',
    :'show_variant_name' => :'show_variant_name',
    :'show_verified_badge' => :'show_verified_badge',
    :'author_placeholder' => :'author_placeholder',
    :'quote_placeholder' => :'quote_placeholder',
    :'product_name_placeholder' => :'product_name_placeholder',
    :'product_variant_name_placeholder' => :'product_variant_name_placeholder',
    :'verified_badge_language' => :'verified_badge_language',
    :'dynamic' => :'dynamic',
    :'author' => :'author',
    :'product_name' => :'product_name',
    :'product_variant_name' => :'product_variant_name',
    :'quote' => :'quote',
    :'stars' => :'stars',
    :'verified' => :'verified'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



308
309
310
# File 'lib/klaviyo-api-sdk/models/static_review_block_properties.rb', line 308

def self.build_from_hash(attributes)
  new.build_from_hash(attributes)
end

.openapi_nullableObject

List of attributes with nullable: true



126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
# File 'lib/klaviyo-api-sdk/models/static_review_block_properties.rb', line 126

def self.openapi_nullable
  Set.new([
    :'show_rating',
    :'show_reviewer_name',
    :'show_product_name',
    :'show_variant_name',
    :'show_verified_badge',
    :'author_placeholder',
    :'quote_placeholder',
    :'product_name_placeholder',
    :'product_variant_name_placeholder',
    :'verified_badge_language',
    :'dynamic',
    :'author',
    :'product_name',
    :'product_variant_name',
    :'quote',
    :'stars',
    :'verified'
  ])
end

.openapi_typesObject

Attribute type mapping.



103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
# File 'lib/klaviyo-api-sdk/models/static_review_block_properties.rb', line 103

def self.openapi_types
  {
    :'show_rating' => :'Boolean',
    :'show_reviewer_name' => :'Boolean',
    :'show_product_name' => :'Boolean',
    :'show_variant_name' => :'Boolean',
    :'show_verified_badge' => :'Boolean',
    :'author_placeholder' => :'String',
    :'quote_placeholder' => :'String',
    :'product_name_placeholder' => :'String',
    :'product_variant_name_placeholder' => :'String',
    :'verified_badge_language' => :'String',
    :'dynamic' => :'Boolean',
    :'author' => :'String',
    :'product_name' => :'String',
    :'product_variant_name' => :'String',
    :'quote' => :'String',
    :'stars' => :'Integer',
    :'verified' => :'Boolean'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



271
272
273
274
275
276
277
278
279
280
281
282
283
284
285
286
287
288
289
290
291
# File 'lib/klaviyo-api-sdk/models/static_review_block_properties.rb', line 271

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      show_rating == o.show_rating &&
      show_reviewer_name == o.show_reviewer_name &&
      show_product_name == o.show_product_name &&
      show_variant_name == o.show_variant_name &&
      show_verified_badge == o.show_verified_badge &&
      author_placeholder == o.author_placeholder &&
      quote_placeholder == o.quote_placeholder &&
      product_name_placeholder == o.product_name_placeholder &&
      product_variant_name_placeholder == o.product_variant_name_placeholder &&
      verified_badge_language == o.verified_badge_language &&
      dynamic == o.dynamic &&
      author == o.author &&
      product_name == o.product_name &&
      product_variant_name == o.product_variant_name &&
      quote == o.quote &&
      stars == o.stars &&
      verified == o.verified
end

#_deserialize(type, value) ⇒ Object

Deserializes the data based on type

Parameters:

  • string

    type Data type

  • string

    value Value to be deserialized

Returns:

  • (Object)

    Deserialized data



339
340
341
342
343
344
345
346
347
348
349
350
351
352
353
354
355
356
357
358
359
360
361
362
363
364
365
366
367
368
369
370
371
372
373
374
375
376
# File 'lib/klaviyo-api-sdk/models/static_review_block_properties.rb', line 339

def _deserialize(type, value)
  case type.to_sym
  when :Time
    Time.parse(value)
  when :Date
    Date.parse(value)
  when :String
    value.to_s
  when :Integer
    value.to_i
  when :Float
    value.to_f
  when :Boolean
    if value.to_s =~ /\A(true|t|yes|y|1)\z/i
      true
    else
      false
    end
  when :Object
    # generic object (usually a Hash), return directly
    value
  when /\AArray<(?<inner_type>.+)>\z/
    inner_type = Regexp.last_match[:inner_type]
    value.map { |v| _deserialize(inner_type, v) }
  when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/
    k_type = Regexp.last_match[:k_type]
    v_type = Regexp.last_match[:v_type]
    {}.tap do |hash|
      value.each do |k, v|
        hash[_deserialize(k_type, k)] = _deserialize(v_type, v)
      end
    end
  else # model
    # models (e.g. Pet) or oneOf
    klass = KlaviyoAPI.const_get(type)
    klass.respond_to?(:openapi_one_of) ? klass.build(value) : klass.build_from_hash(value)
  end
end

#_to_hash(value) ⇒ Hash

Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value

Parameters:

  • value (Object)

    Any valid value

Returns:

  • (Hash)

    Returns the value in the form of hash



410
411
412
413
414
415
416
417
418
419
420
421
422
# File 'lib/klaviyo-api-sdk/models/static_review_block_properties.rb', line 410

def _to_hash(value)
  if value.is_a?(Array)
    value.compact.map { |v| _to_hash(v) }
  elsif value.is_a?(Hash)
    {}.tap do |hash|
      value.each { |k, v| hash[k] = _to_hash(v) }
    end
  elsif value.respond_to? :to_hash
    value.to_hash
  else
    value
  end
end

#build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



315
316
317
318
319
320
321
322
323
324
325
326
327
328
329
330
331
332
333
# File 'lib/klaviyo-api-sdk/models/static_review_block_properties.rb', line 315

def build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  self.class.openapi_types.each_pair do |key, type|
    if attributes[self.class.attribute_map[key]].nil? && self.class.openapi_nullable.include?(key)
      self.send("#{key}=", nil)
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[self.class.attribute_map[key]].is_a?(Array)
        self.send("#{key}=", attributes[self.class.attribute_map[key]].map { |v| _deserialize($1, v) })
      end
    elsif !attributes[self.class.attribute_map[key]].nil?
      self.send("#{key}=", _deserialize(type, attributes[self.class.attribute_map[key]]))
    end
  end

  self
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


295
296
297
# File 'lib/klaviyo-api-sdk/models/static_review_block_properties.rb', line 295

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



301
302
303
# File 'lib/klaviyo-api-sdk/models/static_review_block_properties.rb', line 301

def hash
  [show_rating, show_reviewer_name, show_product_name, show_variant_name, show_verified_badge, author_placeholder, quote_placeholder, product_name_placeholder, product_variant_name_placeholder, verified_badge_language, dynamic, author, product_name, product_variant_name, quote, stars, verified].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



234
235
236
237
# File 'lib/klaviyo-api-sdk/models/static_review_block_properties.rb', line 234

def list_invalid_properties
  invalid_properties = Array.new
  invalid_properties
end

#to_bodyHash

to_body is an alias to to_hash (backward compatibility)

Returns:

  • (Hash)

    Returns the object in the form of hash



386
387
388
# File 'lib/klaviyo-api-sdk/models/static_review_block_properties.rb', line 386

def to_body
  to_hash
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



392
393
394
395
396
397
398
399
400
401
402
403
404
# File 'lib/klaviyo-api-sdk/models/static_review_block_properties.rb', line 392

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#to_sString

Returns the string representation of the object

Returns:

  • (String)

    String presentation of the object



380
381
382
# File 'lib/klaviyo-api-sdk/models/static_review_block_properties.rb', line 380

def to_s
  to_hash.to_s
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



241
242
243
244
245
246
247
# File 'lib/klaviyo-api-sdk/models/static_review_block_properties.rb', line 241

def valid?
  verified_badge_language_validator = EnumAttributeValidator.new('String', ["dutch", "english", "french", "german", "hungarian", "italian", "japanese", "korean", "portuguese", "spanish"])
  return false unless verified_badge_language_validator.valid?(@verified_badge_language)
  dynamic_validator = EnumAttributeValidator.new('Boolean', ["false"])
  return false unless dynamic_validator.valid?(@dynamic)
  true
end