Class: KlaviyoAPI::TableFallbackTextSubBlock

Inherits:
Object
  • Object
show all
Defined in:
lib/klaviyo-api-sdk/models/table_fallback_text_sub_block.rb

Defined Under Namespace

Classes: EnumAttributeValidator

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ TableFallbackTextSubBlock

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
# File 'lib/klaviyo-api-sdk/models/table_fallback_text_sub_block.rb', line 131

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `KlaviyoAPI::TableFallbackTextSubBlock` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!self.class.attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `KlaviyoAPI::TableFallbackTextSubBlock`. Please check the name to make sure it's valid. List of attributes: " + self.class.attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'content')
    self.content = attributes[:'content']
  end

  if attributes.key?(:'cell_text_align')
    self.cell_text_align = attributes[:'cell_text_align']
  end

  if attributes.key?(:'color')
    self.color = attributes[:'color']
  end

  if attributes.key?(:'font_family')
    self.font_family = attributes[:'font_family']
  end

  if attributes.key?(:'font_size')
    self.font_size = attributes[:'font_size']
  end

  if attributes.key?(:'font_style')
    self.font_style = attributes[:'font_style']
  end

  if attributes.key?(:'font_weight')
    self.font_weight = attributes[:'font_weight']
  end

  if attributes.key?(:'letter_spacing')
    self.letter_spacing = attributes[:'letter_spacing']
  end

  if attributes.key?(:'show_on')
    self.show_on = attributes[:'show_on']
  end

  if attributes.key?(:'table_column_width')
    self.table_column_width = attributes[:'table_column_width']
  end

  if attributes.key?(:'text_decoration')
    self.text_decoration = attributes[:'text_decoration']
  end

  if attributes.key?(:'id')
    self.id = attributes[:'id']
  end

  if attributes.key?(:'type')
    self.type = attributes[:'type']
  end
end

Instance Attribute Details

#cell_text_alignObject

Text Alignment.



20
21
22
# File 'lib/klaviyo-api-sdk/models/table_fallback_text_sub_block.rb', line 20

def cell_text_align
  @cell_text_align
end

#colorObject

Returns the value of attribute color.



22
23
24
# File 'lib/klaviyo-api-sdk/models/table_fallback_text_sub_block.rb', line 22

def color
  @color
end

#contentObject

Returns the value of attribute content.



17
18
19
# File 'lib/klaviyo-api-sdk/models/table_fallback_text_sub_block.rb', line 17

def content
  @content
end

#font_familyObject

Returns the value of attribute font_family.



24
25
26
# File 'lib/klaviyo-api-sdk/models/table_fallback_text_sub_block.rb', line 24

def font_family
  @font_family
end

#font_sizeObject

Returns the value of attribute font_size.



26
27
28
# File 'lib/klaviyo-api-sdk/models/table_fallback_text_sub_block.rb', line 26

def font_size
  @font_size
end

#font_styleObject

Font style.



29
30
31
# File 'lib/klaviyo-api-sdk/models/table_fallback_text_sub_block.rb', line 29

def font_style
  @font_style
end

#font_weightObject

Returns the value of attribute font_weight.



31
32
33
# File 'lib/klaviyo-api-sdk/models/table_fallback_text_sub_block.rb', line 31

def font_weight
  @font_weight
end

#idObject

Returns the value of attribute id.



42
43
44
# File 'lib/klaviyo-api-sdk/models/table_fallback_text_sub_block.rb', line 42

def id
  @id
end

#letter_spacingObject

Returns the value of attribute letter_spacing.



33
34
35
# File 'lib/klaviyo-api-sdk/models/table_fallback_text_sub_block.rb', line 33

def letter_spacing
  @letter_spacing
end

#show_onObject

Show on.



36
37
38
# File 'lib/klaviyo-api-sdk/models/table_fallback_text_sub_block.rb', line 36

def show_on
  @show_on
end

#table_column_widthObject

Returns the value of attribute table_column_width.



38
39
40
# File 'lib/klaviyo-api-sdk/models/table_fallback_text_sub_block.rb', line 38

def table_column_width
  @table_column_width
end

#text_decorationObject

Returns the value of attribute text_decoration.



40
41
42
# File 'lib/klaviyo-api-sdk/models/table_fallback_text_sub_block.rb', line 40

def text_decoration
  @text_decoration
end

#typeObject

Returns the value of attribute type.



44
45
46
# File 'lib/klaviyo-api-sdk/models/table_fallback_text_sub_block.rb', line 44

def type
  @type
end

Class Method Details

.acceptable_attributesObject

Returns all the JSON keys this model knows about



88
89
90
# File 'lib/klaviyo-api-sdk/models/table_fallback_text_sub_block.rb', line 88

def self.acceptable_attributes
  attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



69
70
71
72
73
74
75
76
77
78
79
80
81
82
83
84
85
# File 'lib/klaviyo-api-sdk/models/table_fallback_text_sub_block.rb', line 69

def self.attribute_map
  {
    :'content' => :'content',
    :'cell_text_align' => :'cell_text_align',
    :'color' => :'color',
    :'font_family' => :'font_family',
    :'font_size' => :'font_size',
    :'font_style' => :'font_style',
    :'font_weight' => :'font_weight',
    :'letter_spacing' => :'letter_spacing',
    :'show_on' => :'show_on',
    :'table_column_width' => :'table_column_width',
    :'text_decoration' => :'text_decoration',
    :'id' => :'id',
    :'type' => :'type'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



298
299
300
# File 'lib/klaviyo-api-sdk/models/table_fallback_text_sub_block.rb', line 298

def self.build_from_hash(attributes)
  new.build_from_hash(attributes)
end

.openapi_nullableObject

List of attributes with nullable: true



112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
# File 'lib/klaviyo-api-sdk/models/table_fallback_text_sub_block.rb', line 112

def self.openapi_nullable
  Set.new([
    :'content',
    :'cell_text_align',
    :'color',
    :'font_family',
    :'font_size',
    :'font_style',
    :'font_weight',
    :'letter_spacing',
    :'show_on',
    :'table_column_width',
    :'text_decoration',
    :'id',
  ])
end

.openapi_typesObject

Attribute type mapping.



93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
# File 'lib/klaviyo-api-sdk/models/table_fallback_text_sub_block.rb', line 93

def self.openapi_types
  {
    :'content' => :'String',
    :'cell_text_align' => :'String',
    :'color' => :'String',
    :'font_family' => :'String',
    :'font_size' => :'Integer',
    :'font_style' => :'String',
    :'font_weight' => :'String',
    :'letter_spacing' => :'Integer',
    :'show_on' => :'String',
    :'table_column_width' => :'String',
    :'text_decoration' => :'String',
    :'id' => :'String',
    :'type' => :'String'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



265
266
267
268
269
270
271
272
273
274
275
276
277
278
279
280
281
# File 'lib/klaviyo-api-sdk/models/table_fallback_text_sub_block.rb', line 265

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      content == o.content &&
      cell_text_align == o.cell_text_align &&
      color == o.color &&
      font_family == o.font_family &&
      font_size == o.font_size &&
      font_style == o.font_style &&
      font_weight == o.font_weight &&
      letter_spacing == o.letter_spacing &&
      show_on == o.show_on &&
      table_column_width == o.table_column_width &&
      text_decoration == o.text_decoration &&
      id == o.id &&
      type == o.type
end

#_deserialize(type, value) ⇒ Object

Deserializes the data based on type

Parameters:

  • string

    type Data type

  • string

    value Value to be deserialized

Returns:

  • (Object)

    Deserialized data



329
330
331
332
333
334
335
336
337
338
339
340
341
342
343
344
345
346
347
348
349
350
351
352
353
354
355
356
357
358
359
360
361
362
363
364
365
366
# File 'lib/klaviyo-api-sdk/models/table_fallback_text_sub_block.rb', line 329

def _deserialize(type, value)
  case type.to_sym
  when :Time
    Time.parse(value)
  when :Date
    Date.parse(value)
  when :String
    value.to_s
  when :Integer
    value.to_i
  when :Float
    value.to_f
  when :Boolean
    if value.to_s =~ /\A(true|t|yes|y|1)\z/i
      true
    else
      false
    end
  when :Object
    # generic object (usually a Hash), return directly
    value
  when /\AArray<(?<inner_type>.+)>\z/
    inner_type = Regexp.last_match[:inner_type]
    value.map { |v| _deserialize(inner_type, v) }
  when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/
    k_type = Regexp.last_match[:k_type]
    v_type = Regexp.last_match[:v_type]
    {}.tap do |hash|
      value.each do |k, v|
        hash[_deserialize(k_type, k)] = _deserialize(v_type, v)
      end
    end
  else # model
    # models (e.g. Pet) or oneOf
    klass = KlaviyoAPI.const_get(type)
    klass.respond_to?(:openapi_one_of) ? klass.build(value) : klass.build_from_hash(value)
  end
end

#_to_hash(value) ⇒ Hash

Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value

Parameters:

  • value (Object)

    Any valid value

Returns:

  • (Hash)

    Returns the value in the form of hash



400
401
402
403
404
405
406
407
408
409
410
411
412
# File 'lib/klaviyo-api-sdk/models/table_fallback_text_sub_block.rb', line 400

def _to_hash(value)
  if value.is_a?(Array)
    value.compact.map { |v| _to_hash(v) }
  elsif value.is_a?(Hash)
    {}.tap do |hash|
      value.each { |k, v| hash[k] = _to_hash(v) }
    end
  elsif value.respond_to? :to_hash
    value.to_hash
  else
    value
  end
end

#build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



305
306
307
308
309
310
311
312
313
314
315
316
317
318
319
320
321
322
323
# File 'lib/klaviyo-api-sdk/models/table_fallback_text_sub_block.rb', line 305

def build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  self.class.openapi_types.each_pair do |key, type|
    if attributes[self.class.attribute_map[key]].nil? && self.class.openapi_nullable.include?(key)
      self.send("#{key}=", nil)
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[self.class.attribute_map[key]].is_a?(Array)
        self.send("#{key}=", attributes[self.class.attribute_map[key]].map { |v| _deserialize($1, v) })
      end
    elsif !attributes[self.class.attribute_map[key]].nil?
      self.send("#{key}=", _deserialize(type, attributes[self.class.attribute_map[key]]))
    end
  end

  self
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


285
286
287
# File 'lib/klaviyo-api-sdk/models/table_fallback_text_sub_block.rb', line 285

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



291
292
293
# File 'lib/klaviyo-api-sdk/models/table_fallback_text_sub_block.rb', line 291

def hash
  [content, cell_text_align, color, font_family, font_size, font_style, font_weight, letter_spacing, show_on, table_column_width, text_decoration, id, type].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



199
200
201
202
203
204
205
206
# File 'lib/klaviyo-api-sdk/models/table_fallback_text_sub_block.rb', line 199

def list_invalid_properties
  invalid_properties = Array.new
  if @type.nil?
    invalid_properties.push('invalid value for "type", type cannot be nil.')
  end

  invalid_properties
end

#to_bodyHash

to_body is an alias to to_hash (backward compatibility)

Returns:

  • (Hash)

    Returns the object in the form of hash



376
377
378
# File 'lib/klaviyo-api-sdk/models/table_fallback_text_sub_block.rb', line 376

def to_body
  to_hash
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



382
383
384
385
386
387
388
389
390
391
392
393
394
# File 'lib/klaviyo-api-sdk/models/table_fallback_text_sub_block.rb', line 382

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#to_sString

Returns the string representation of the object

Returns:

  • (String)

    String presentation of the object



370
371
372
# File 'lib/klaviyo-api-sdk/models/table_fallback_text_sub_block.rb', line 370

def to_s
  to_hash.to_s
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



210
211
212
213
214
215
216
217
218
219
220
221
# File 'lib/klaviyo-api-sdk/models/table_fallback_text_sub_block.rb', line 210

def valid?
  cell_text_align_validator = EnumAttributeValidator.new('String', ["center", "left", "right"])
  return false unless cell_text_align_validator.valid?(@cell_text_align)
  font_style_validator = EnumAttributeValidator.new('String', ["italic", "normal"])
  return false unless font_style_validator.valid?(@font_style)
  show_on_validator = EnumAttributeValidator.new('String', ["all", "desktop", "mobile"])
  return false unless show_on_validator.valid?(@show_on)
  return false if @type.nil?
  type_validator = EnumAttributeValidator.new('String', ["table_fallback_text"])
  return false unless type_validator.valid?(@type)
  true
end