Class: KlaviyoAPI::TextStyleStyles
- Inherits:
-
Object
- Object
- KlaviyoAPI::TextStyleStyles
- Defined in:
- lib/klaviyo-api-sdk/models/text_style_styles.rb
Defined Under Namespace
Classes: EnumAttributeValidator
Instance Attribute Summary collapse
-
#color ⇒ Object
Returns the value of attribute color.
-
#font_family ⇒ Object
Returns the value of attribute font_family.
-
#font_size ⇒ Object
Returns the value of attribute font_size.
-
#font_style ⇒ Object
Font style.
-
#font_weight ⇒ Object
Returns the value of attribute font_weight.
-
#letter_spacing ⇒ Object
Returns the value of attribute letter_spacing.
-
#line_height ⇒ Object
Returns the value of attribute line_height.
-
#mobile_font_size ⇒ Object
Returns the value of attribute mobile_font_size.
-
#mobile_line_height ⇒ Object
Returns the value of attribute mobile_line_height.
-
#text_align ⇒ Object
Text Alignment.
-
#text_decoration ⇒ Object
Returns the value of attribute text_decoration.
Class Method Summary collapse
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
-
#_deserialize(type, value) ⇒ Object
Deserializes the data based on type.
-
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ TextStyleStyles
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility).
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Constructor Details
#initialize(attributes = {}) ⇒ TextStyleStyles
Initializes the object
121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 |
# File 'lib/klaviyo-api-sdk/models/text_style_styles.rb', line 121 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `KlaviyoAPI::TextStyleStyles` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| if (!self.class.attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `KlaviyoAPI::TextStyleStyles`. Please check the name to make sure it's valid. List of attributes: " + self.class.attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'color') self.color = attributes[:'color'] end if attributes.key?(:'font_family') self.font_family = attributes[:'font_family'] end if attributes.key?(:'font_size') self.font_size = attributes[:'font_size'] end if attributes.key?(:'font_style') self.font_style = attributes[:'font_style'] end if attributes.key?(:'font_weight') self.font_weight = attributes[:'font_weight'] end if attributes.key?(:'letter_spacing') self.letter_spacing = attributes[:'letter_spacing'] end if attributes.key?(:'line_height') self.line_height = attributes[:'line_height'] end if attributes.key?(:'mobile_font_size') self.mobile_font_size = attributes[:'mobile_font_size'] end if attributes.key?(:'mobile_line_height') self.mobile_line_height = attributes[:'mobile_line_height'] end if attributes.key?(:'text_align') self.text_align = attributes[:'text_align'] end if attributes.key?(:'text_decoration') self.text_decoration = attributes[:'text_decoration'] end end |
Instance Attribute Details
#color ⇒ Object
Returns the value of attribute color.
17 18 19 |
# File 'lib/klaviyo-api-sdk/models/text_style_styles.rb', line 17 def color @color end |
#font_family ⇒ Object
Returns the value of attribute font_family.
19 20 21 |
# File 'lib/klaviyo-api-sdk/models/text_style_styles.rb', line 19 def font_family @font_family end |
#font_size ⇒ Object
Returns the value of attribute font_size.
21 22 23 |
# File 'lib/klaviyo-api-sdk/models/text_style_styles.rb', line 21 def font_size @font_size end |
#font_style ⇒ Object
Font style.
24 25 26 |
# File 'lib/klaviyo-api-sdk/models/text_style_styles.rb', line 24 def font_style @font_style end |
#font_weight ⇒ Object
Returns the value of attribute font_weight.
26 27 28 |
# File 'lib/klaviyo-api-sdk/models/text_style_styles.rb', line 26 def font_weight @font_weight end |
#letter_spacing ⇒ Object
Returns the value of attribute letter_spacing.
28 29 30 |
# File 'lib/klaviyo-api-sdk/models/text_style_styles.rb', line 28 def letter_spacing @letter_spacing end |
#line_height ⇒ Object
Returns the value of attribute line_height.
30 31 32 |
# File 'lib/klaviyo-api-sdk/models/text_style_styles.rb', line 30 def line_height @line_height end |
#mobile_font_size ⇒ Object
Returns the value of attribute mobile_font_size.
32 33 34 |
# File 'lib/klaviyo-api-sdk/models/text_style_styles.rb', line 32 def mobile_font_size @mobile_font_size end |
#mobile_line_height ⇒ Object
Returns the value of attribute mobile_line_height.
34 35 36 |
# File 'lib/klaviyo-api-sdk/models/text_style_styles.rb', line 34 def mobile_line_height @mobile_line_height end |
#text_align ⇒ Object
Text Alignment.
37 38 39 |
# File 'lib/klaviyo-api-sdk/models/text_style_styles.rb', line 37 def text_align @text_align end |
#text_decoration ⇒ Object
Returns the value of attribute text_decoration.
39 40 41 |
# File 'lib/klaviyo-api-sdk/models/text_style_styles.rb', line 39 def text_decoration @text_decoration end |
Class Method Details
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
81 82 83 |
# File 'lib/klaviyo-api-sdk/models/text_style_styles.rb', line 81 def self.acceptable_attributes attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 |
# File 'lib/klaviyo-api-sdk/models/text_style_styles.rb', line 64 def self.attribute_map { :'color' => :'color', :'font_family' => :'font_family', :'font_size' => :'font_size', :'font_style' => :'font_style', :'font_weight' => :'font_weight', :'letter_spacing' => :'letter_spacing', :'line_height' => :'line_height', :'mobile_font_size' => :'mobile_font_size', :'mobile_line_height' => :'mobile_line_height', :'text_align' => :'text_align', :'text_decoration' => :'text_decoration' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
249 250 251 |
# File 'lib/klaviyo-api-sdk/models/text_style_styles.rb', line 249 def self.build_from_hash(attributes) new.build_from_hash(attributes) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 |
# File 'lib/klaviyo-api-sdk/models/text_style_styles.rb', line 103 def self.openapi_nullable Set.new([ :'color', :'font_family', :'font_size', :'font_style', :'font_weight', :'letter_spacing', :'line_height', :'mobile_font_size', :'mobile_line_height', :'text_align', :'text_decoration' ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 |
# File 'lib/klaviyo-api-sdk/models/text_style_styles.rb', line 86 def self.openapi_types { :'color' => :'String', :'font_family' => :'String', :'font_size' => :'Integer', :'font_style' => :'String', :'font_weight' => :'String', :'letter_spacing' => :'Integer', :'line_height' => :'Float', :'mobile_font_size' => :'Integer', :'mobile_line_height' => :'Float', :'text_align' => :'String', :'text_decoration' => :'String' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
218 219 220 221 222 223 224 225 226 227 228 229 230 231 232 |
# File 'lib/klaviyo-api-sdk/models/text_style_styles.rb', line 218 def ==(o) return true if self.equal?(o) self.class == o.class && color == o.color && font_family == o.font_family && font_size == o.font_size && font_style == o.font_style && font_weight == o.font_weight && letter_spacing == o.letter_spacing && line_height == o.line_height && mobile_font_size == o.mobile_font_size && mobile_line_height == o.mobile_line_height && text_align == o.text_align && text_decoration == o.text_decoration end |
#_deserialize(type, value) ⇒ Object
Deserializes the data based on type
280 281 282 283 284 285 286 287 288 289 290 291 292 293 294 295 296 297 298 299 300 301 302 303 304 305 306 307 308 309 310 311 312 313 314 315 316 317 |
# File 'lib/klaviyo-api-sdk/models/text_style_styles.rb', line 280 def _deserialize(type, value) case type.to_sym when :Time Time.parse(value) when :Date Date.parse(value) when :String value.to_s when :Integer value.to_i when :Float value.to_f when :Boolean if value.to_s =~ /\A(true|t|yes|y|1)\z/i true else false end when :Object # generic object (usually a Hash), return directly value when /\AArray<(?<inner_type>.+)>\z/ inner_type = Regexp.last_match[:inner_type] value.map { |v| _deserialize(inner_type, v) } when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/ k_type = Regexp.last_match[:k_type] v_type = Regexp.last_match[:v_type] {}.tap do |hash| value.each do |k, v| hash[_deserialize(k_type, k)] = _deserialize(v_type, v) end end else # model # models (e.g. Pet) or oneOf klass = KlaviyoAPI.const_get(type) klass.respond_to?(:openapi_one_of) ? klass.build(value) : klass.build_from_hash(value) end end |
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value
351 352 353 354 355 356 357 358 359 360 361 362 363 |
# File 'lib/klaviyo-api-sdk/models/text_style_styles.rb', line 351 def _to_hash(value) if value.is_a?(Array) value.compact.map { |v| _to_hash(v) } elsif value.is_a?(Hash) {}.tap do |hash| value.each { |k, v| hash[k] = _to_hash(v) } end elsif value.respond_to? :to_hash value.to_hash else value end end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
256 257 258 259 260 261 262 263 264 265 266 267 268 269 270 271 272 273 274 |
# File 'lib/klaviyo-api-sdk/models/text_style_styles.rb', line 256 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) self.class.openapi_types.each_pair do |key, type| if attributes[self.class.attribute_map[key]].nil? && self.class.openapi_nullable.include?(key) self.send("#{key}=", nil) elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) self.send("#{key}=", attributes[self.class.attribute_map[key]].map { |v| _deserialize($1, v) }) end elsif !attributes[self.class.attribute_map[key]].nil? self.send("#{key}=", _deserialize(type, attributes[self.class.attribute_map[key]])) end end self end |
#eql?(o) ⇒ Boolean
236 237 238 |
# File 'lib/klaviyo-api-sdk/models/text_style_styles.rb', line 236 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
242 243 244 |
# File 'lib/klaviyo-api-sdk/models/text_style_styles.rb', line 242 def hash [color, font_family, font_size, font_style, font_weight, letter_spacing, line_height, mobile_font_size, mobile_line_height, text_align, text_decoration].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
181 182 183 184 |
# File 'lib/klaviyo-api-sdk/models/text_style_styles.rb', line 181 def list_invalid_properties invalid_properties = Array.new invalid_properties end |
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility)
327 328 329 |
# File 'lib/klaviyo-api-sdk/models/text_style_styles.rb', line 327 def to_body to_hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
333 334 335 336 337 338 339 340 341 342 343 344 345 |
# File 'lib/klaviyo-api-sdk/models/text_style_styles.rb', line 333 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
321 322 323 |
# File 'lib/klaviyo-api-sdk/models/text_style_styles.rb', line 321 def to_s to_hash.to_s end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
188 189 190 191 192 193 194 |
# File 'lib/klaviyo-api-sdk/models/text_style_styles.rb', line 188 def valid? font_style_validator = EnumAttributeValidator.new('String', ["italic", "normal"]) return false unless font_style_validator.valid?(@font_style) text_align_validator = EnumAttributeValidator.new('String', ["center", "left", "right"]) return false unless text_align_validator.valid?(@text_align) true end |