Class: KlaviyoAPI::Version

Inherits:
Object
  • Object
show all
Defined in:
lib/klaviyo-api-sdk/models/version.rb

Defined Under Namespace

Classes: EnumAttributeValidator

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ Version

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
# File 'lib/klaviyo-api-sdk/models/version.rb', line 123

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `KlaviyoAPI::Version` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!self.class.attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `KlaviyoAPI::Version`. Please check the name to make sure it's valid. List of attributes: " + self.class.attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'id')
    self.id = attributes[:'id']
  end

  if attributes.key?(:'steps')
    if (value = attributes[:'steps']).is_a?(Array)
      self.steps = value
    end
  end

  if attributes.key?(:'triggers')
    if (value = attributes[:'triggers']).is_a?(Array)
      self.triggers = value
    end
  end

  if attributes.key?(:'teasers')
    if (value = attributes[:'teasers']).is_a?(Array)
      self.teasers = value
    end
  end

  if attributes.key?(:'dynamic_button')
    self.dynamic_button = attributes[:'dynamic_button']
  end

  if attributes.key?(:'name')
    self.name = attributes[:'name']
  end

  if attributes.key?(:'styles')
    self.styles = attributes[:'styles']
  end

  if attributes.key?(:'properties')
    self.properties = attributes[:'properties']
  end

  if attributes.key?(:'type')
    self.type = attributes[:'type']
  else
    self.type = 'popup'
  end

  if attributes.key?(:'location')
    self.location = attributes[:'location']
  end

  if attributes.key?(:'status')
    self.status = attributes[:'status']
  else
    self.status = 'draft'
  end

  if attributes.key?(:'ab_test')
    self.ab_test = attributes[:'ab_test']
  else
    self.ab_test = false
  end

  if attributes.key?(:'specialties')
    if (value = attributes[:'specialties']).is_a?(Array)
      self.specialties = value
    end
  end
end

Instance Attribute Details

#ab_testObject

Returns the value of attribute ab_test.



43
44
45
# File 'lib/klaviyo-api-sdk/models/version.rb', line 43

def ab_test
  @ab_test
end

#dynamic_buttonObject

Returns the value of attribute dynamic_button.



26
27
28
# File 'lib/klaviyo-api-sdk/models/version.rb', line 26

def dynamic_button
  @dynamic_button
end

#idObject

Not allowed on create.



18
19
20
# File 'lib/klaviyo-api-sdk/models/version.rb', line 18

def id
  @id
end

#locationObject

Display location enumeration.



38
39
40
# File 'lib/klaviyo-api-sdk/models/version.rb', line 38

def location
  @location
end

#nameObject

Returns the value of attribute name.



28
29
30
# File 'lib/klaviyo-api-sdk/models/version.rb', line 28

def name
  @name
end

#propertiesObject

Returns the value of attribute properties.



32
33
34
# File 'lib/klaviyo-api-sdk/models/version.rb', line 32

def properties
  @properties
end

#specialtiesObject

Returns the value of attribute specialties.



45
46
47
# File 'lib/klaviyo-api-sdk/models/version.rb', line 45

def specialties
  @specialties
end

#statusObject

Form status enumeration.



41
42
43
# File 'lib/klaviyo-api-sdk/models/version.rb', line 41

def status
  @status
end

#stepsObject

Returns the value of attribute steps.



20
21
22
# File 'lib/klaviyo-api-sdk/models/version.rb', line 20

def steps
  @steps
end

#stylesObject

Returns the value of attribute styles.



30
31
32
# File 'lib/klaviyo-api-sdk/models/version.rb', line 30

def styles
  @styles
end

#teasersObject

Returns the value of attribute teasers.



24
25
26
# File 'lib/klaviyo-api-sdk/models/version.rb', line 24

def teasers
  @teasers
end

#triggersObject

Returns the value of attribute triggers.



22
23
24
# File 'lib/klaviyo-api-sdk/models/version.rb', line 22

def triggers
  @triggers
end

#typeObject

Form type enumeration.



35
36
37
# File 'lib/klaviyo-api-sdk/models/version.rb', line 35

def type
  @type
end

Class Method Details

.acceptable_attributesObject

Returns all the JSON keys this model knows about



89
90
91
# File 'lib/klaviyo-api-sdk/models/version.rb', line 89

def self.acceptable_attributes
  attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



70
71
72
73
74
75
76
77
78
79
80
81
82
83
84
85
86
# File 'lib/klaviyo-api-sdk/models/version.rb', line 70

def self.attribute_map
  {
    :'id' => :'id',
    :'steps' => :'steps',
    :'triggers' => :'triggers',
    :'teasers' => :'teasers',
    :'dynamic_button' => :'dynamic_button',
    :'name' => :'name',
    :'styles' => :'styles',
    :'properties' => :'properties',
    :'type' => :'type',
    :'location' => :'location',
    :'status' => :'status',
    :'ab_test' => :'ab_test',
    :'specialties' => :'specialties'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



292
293
294
# File 'lib/klaviyo-api-sdk/models/version.rb', line 292

def self.build_from_hash(attributes)
  new.build_from_hash(attributes)
end

.openapi_nullableObject

List of attributes with nullable: true



113
114
115
116
117
118
119
# File 'lib/klaviyo-api-sdk/models/version.rb', line 113

def self.openapi_nullable
  Set.new([
    :'id',
    :'name',
    :'location',
  ])
end

.openapi_typesObject

Attribute type mapping.



94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
# File 'lib/klaviyo-api-sdk/models/version.rb', line 94

def self.openapi_types
  {
    :'id' => :'Integer',
    :'steps' => :'Array<Step>',
    :'triggers' => :'Array<VersionTriggersInner>',
    :'teasers' => :'Array<Teaser>',
    :'dynamic_button' => :'DynamicButton',
    :'name' => :'String',
    :'styles' => :'VersionStyles',
    :'properties' => :'VersionProperties',
    :'type' => :'String',
    :'location' => :'String',
    :'status' => :'String',
    :'ab_test' => :'Boolean',
    :'specialties' => :'Array<String>'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



259
260
261
262
263
264
265
266
267
268
269
270
271
272
273
274
275
# File 'lib/klaviyo-api-sdk/models/version.rb', line 259

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      id == o.id &&
      steps == o.steps &&
      triggers == o.triggers &&
      teasers == o.teasers &&
      dynamic_button == o.dynamic_button &&
      name == o.name &&
      styles == o.styles &&
      properties == o.properties &&
      type == o.type &&
      location == o.location &&
      status == o.status &&
      ab_test == o.ab_test &&
      specialties == o.specialties
end

#_deserialize(type, value) ⇒ Object

Deserializes the data based on type

Parameters:

  • string

    type Data type

  • string

    value Value to be deserialized

Returns:

  • (Object)

    Deserialized data



323
324
325
326
327
328
329
330
331
332
333
334
335
336
337
338
339
340
341
342
343
344
345
346
347
348
349
350
351
352
353
354
355
356
357
358
359
360
# File 'lib/klaviyo-api-sdk/models/version.rb', line 323

def _deserialize(type, value)
  case type.to_sym
  when :Time
    Time.parse(value)
  when :Date
    Date.parse(value)
  when :String
    value.to_s
  when :Integer
    value.to_i
  when :Float
    value.to_f
  when :Boolean
    if value.to_s =~ /\A(true|t|yes|y|1)\z/i
      true
    else
      false
    end
  when :Object
    # generic object (usually a Hash), return directly
    value
  when /\AArray<(?<inner_type>.+)>\z/
    inner_type = Regexp.last_match[:inner_type]
    value.map { |v| _deserialize(inner_type, v) }
  when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/
    k_type = Regexp.last_match[:k_type]
    v_type = Regexp.last_match[:v_type]
    {}.tap do |hash|
      value.each do |k, v|
        hash[_deserialize(k_type, k)] = _deserialize(v_type, v)
      end
    end
  else # model
    # models (e.g. Pet) or oneOf
    klass = KlaviyoAPI.const_get(type)
    klass.respond_to?(:openapi_one_of) ? klass.build(value) : klass.build_from_hash(value)
  end
end

#_to_hash(value) ⇒ Hash

Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value

Parameters:

  • value (Object)

    Any valid value

Returns:

  • (Hash)

    Returns the value in the form of hash



394
395
396
397
398
399
400
401
402
403
404
405
406
# File 'lib/klaviyo-api-sdk/models/version.rb', line 394

def _to_hash(value)
  if value.is_a?(Array)
    value.compact.map { |v| _to_hash(v) }
  elsif value.is_a?(Hash)
    {}.tap do |hash|
      value.each { |k, v| hash[k] = _to_hash(v) }
    end
  elsif value.respond_to? :to_hash
    value.to_hash
  else
    value
  end
end

#build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



299
300
301
302
303
304
305
306
307
308
309
310
311
312
313
314
315
316
317
# File 'lib/klaviyo-api-sdk/models/version.rb', line 299

def build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  self.class.openapi_types.each_pair do |key, type|
    if attributes[self.class.attribute_map[key]].nil? && self.class.openapi_nullable.include?(key)
      self.send("#{key}=", nil)
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[self.class.attribute_map[key]].is_a?(Array)
        self.send("#{key}=", attributes[self.class.attribute_map[key]].map { |v| _deserialize($1, v) })
      end
    elsif !attributes[self.class.attribute_map[key]].nil?
      self.send("#{key}=", _deserialize(type, attributes[self.class.attribute_map[key]]))
    end
  end

  self
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


279
280
281
# File 'lib/klaviyo-api-sdk/models/version.rb', line 279

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



285
286
287
# File 'lib/klaviyo-api-sdk/models/version.rb', line 285

def hash
  [id, steps, triggers, teasers, dynamic_button, name, styles, properties, type, location, status, ab_test, specialties].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



205
206
207
208
209
210
211
212
# File 'lib/klaviyo-api-sdk/models/version.rb', line 205

def list_invalid_properties
  invalid_properties = Array.new
  if @steps.nil?
    invalid_properties.push('invalid value for "steps", steps cannot be nil.')
  end

  invalid_properties
end

#to_bodyHash

to_body is an alias to to_hash (backward compatibility)

Returns:

  • (Hash)

    Returns the object in the form of hash



370
371
372
# File 'lib/klaviyo-api-sdk/models/version.rb', line 370

def to_body
  to_hash
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



376
377
378
379
380
381
382
383
384
385
386
387
388
# File 'lib/klaviyo-api-sdk/models/version.rb', line 376

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#to_sString

Returns the string representation of the object

Returns:

  • (String)

    String presentation of the object



364
365
366
# File 'lib/klaviyo-api-sdk/models/version.rb', line 364

def to_s
  to_hash.to_s
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



216
217
218
219
220
221
222
223
224
225
# File 'lib/klaviyo-api-sdk/models/version.rb', line 216

def valid?
  return false if @steps.nil?
  type_validator = EnumAttributeValidator.new('String', ["banner", "embed", "flyout", "full_screen", "popup"])
  return false unless type_validator.valid?(@type)
  location_validator = EnumAttributeValidator.new('String', ["bottom_center", "bottom_left", "bottom_right", "center_left", "center_right", "top_center", "top_left", "top_right"])
  return false unless location_validator.valid?(@location)
  status_validator = EnumAttributeValidator.new('String', ["draft", "live"])
  return false unless status_validator.valid?(@status)
  true
end