Class: KlaviyoAPI::HeaderBlockStyles
- Inherits:
-
Object
- Object
- KlaviyoAPI::HeaderBlockStyles
- Defined in:
- lib/klaviyo-api-sdk/models/header_block_styles.rb
Defined Under Namespace
Classes: EnumAttributeValidator
Instance Attribute Summary collapse
-
#block_background_color ⇒ Object
Returns the value of attribute block_background_color.
-
#block_padding_bottom ⇒ Object
Returns the value of attribute block_padding_bottom.
-
#block_padding_left ⇒ Object
Returns the value of attribute block_padding_left.
-
#block_padding_right ⇒ Object
Returns the value of attribute block_padding_right.
-
#block_padding_top ⇒ Object
Returns the value of attribute block_padding_top.
-
#border_color ⇒ Object
Returns the value of attribute border_color.
-
#border_radius ⇒ Object
Returns the value of attribute border_radius.
-
#border_style ⇒ Object
Border style.
-
#border_width ⇒ Object
Returns the value of attribute border_width.
-
#color ⇒ Object
Returns the value of attribute color.
-
#desktop_layout ⇒ Object
Header block desktop layout.
-
#font_family ⇒ Object
Returns the value of attribute font_family.
-
#font_size ⇒ Object
Returns the value of attribute font_size.
-
#font_style ⇒ Object
Font style.
-
#font_weight ⇒ Object
Returns the value of attribute font_weight.
-
#inner_padding_bottom ⇒ Object
Returns the value of attribute inner_padding_bottom.
-
#inner_padding_left ⇒ Object
Returns the value of attribute inner_padding_left.
-
#inner_padding_right ⇒ Object
Returns the value of attribute inner_padding_right.
-
#inner_padding_top ⇒ Object
Returns the value of attribute inner_padding_top.
-
#item_align ⇒ Object
Text Alignment.
-
#item_spacing ⇒ Object
Returns the value of attribute item_spacing.
-
#item_spacing_type ⇒ Object
Header block item spacing type.
-
#letter_spacing ⇒ Object
Returns the value of attribute letter_spacing.
-
#logo_align ⇒ Object
Text Alignment.
-
#logo_link_spacing ⇒ Object
Returns the value of attribute logo_link_spacing.
-
#mobile_layout ⇒ Object
Header block mobile layout.
-
#mobile_spacing ⇒ Object
Returns the value of attribute mobile_spacing.
-
#mobile_wrap ⇒ Object
Returns the value of attribute mobile_wrap.
-
#text_decoration ⇒ Object
Returns the value of attribute text_decoration.
-
#vertical_align ⇒ Object
Vertical alignment.
Class Method Summary collapse
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
-
#_deserialize(type, value) ⇒ Object
Deserializes the data based on type.
-
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ HeaderBlockStyles
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility).
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Constructor Details
#initialize(attributes = {}) ⇒ HeaderBlockStyles
Initializes the object
222 223 224 225 226 227 228 229 230 231 232 233 234 235 236 237 238 239 240 241 242 243 244 245 246 247 248 249 250 251 252 253 254 255 256 257 258 259 260 261 262 263 264 265 266 267 268 269 270 271 272 273 274 275 276 277 278 279 280 281 282 283 284 285 286 287 288 289 290 291 292 293 294 295 296 297 298 299 300 301 302 303 304 305 306 307 308 309 310 311 312 313 314 315 316 317 318 319 320 321 322 323 324 325 326 327 328 329 330 331 332 333 334 335 336 337 338 339 340 341 342 343 344 345 346 347 348 349 350 351 352 353 354 |
# File 'lib/klaviyo-api-sdk/models/header_block_styles.rb', line 222 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `KlaviyoAPI::HeaderBlockStyles` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| if (!self.class.attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `KlaviyoAPI::HeaderBlockStyles`. Please check the name to make sure it's valid. List of attributes: " + self.class.attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'block_background_color') self.block_background_color = attributes[:'block_background_color'] end if attributes.key?(:'block_padding_bottom') self.block_padding_bottom = attributes[:'block_padding_bottom'] end if attributes.key?(:'block_padding_left') self.block_padding_left = attributes[:'block_padding_left'] end if attributes.key?(:'block_padding_right') self.block_padding_right = attributes[:'block_padding_right'] end if attributes.key?(:'block_padding_top') self.block_padding_top = attributes[:'block_padding_top'] end if attributes.key?(:'border_color') self.border_color = attributes[:'border_color'] end if attributes.key?(:'border_radius') self.border_radius = attributes[:'border_radius'] end if attributes.key?(:'border_style') self.border_style = attributes[:'border_style'] end if attributes.key?(:'border_width') self.border_width = attributes[:'border_width'] end if attributes.key?(:'color') self.color = attributes[:'color'] end if attributes.key?(:'desktop_layout') self.desktop_layout = attributes[:'desktop_layout'] end if attributes.key?(:'font_family') self.font_family = attributes[:'font_family'] end if attributes.key?(:'font_size') self.font_size = attributes[:'font_size'] end if attributes.key?(:'font_style') self.font_style = attributes[:'font_style'] end if attributes.key?(:'font_weight') self.font_weight = attributes[:'font_weight'] end if attributes.key?(:'inner_padding_bottom') self.inner_padding_bottom = attributes[:'inner_padding_bottom'] end if attributes.key?(:'inner_padding_left') self.inner_padding_left = attributes[:'inner_padding_left'] end if attributes.key?(:'inner_padding_right') self.inner_padding_right = attributes[:'inner_padding_right'] end if attributes.key?(:'inner_padding_top') self.inner_padding_top = attributes[:'inner_padding_top'] end if attributes.key?(:'item_align') self.item_align = attributes[:'item_align'] end if attributes.key?(:'item_spacing') self.item_spacing = attributes[:'item_spacing'] end if attributes.key?(:'item_spacing_type') self.item_spacing_type = attributes[:'item_spacing_type'] end if attributes.key?(:'letter_spacing') self.letter_spacing = attributes[:'letter_spacing'] end if attributes.key?(:'logo_align') self.logo_align = attributes[:'logo_align'] end if attributes.key?(:'logo_link_spacing') self.logo_link_spacing = attributes[:'logo_link_spacing'] end if attributes.key?(:'mobile_layout') self.mobile_layout = attributes[:'mobile_layout'] end if attributes.key?(:'mobile_spacing') self.mobile_spacing = attributes[:'mobile_spacing'] end if attributes.key?(:'mobile_wrap') self.mobile_wrap = attributes[:'mobile_wrap'] end if attributes.key?(:'text_decoration') self.text_decoration = attributes[:'text_decoration'] end if attributes.key?(:'vertical_align') self.vertical_align = attributes[:'vertical_align'] end end |
Instance Attribute Details
#block_background_color ⇒ Object
Returns the value of attribute block_background_color.
17 18 19 |
# File 'lib/klaviyo-api-sdk/models/header_block_styles.rb', line 17 def block_background_color @block_background_color end |
#block_padding_bottom ⇒ Object
Returns the value of attribute block_padding_bottom.
19 20 21 |
# File 'lib/klaviyo-api-sdk/models/header_block_styles.rb', line 19 def block_padding_bottom @block_padding_bottom end |
#block_padding_left ⇒ Object
Returns the value of attribute block_padding_left.
21 22 23 |
# File 'lib/klaviyo-api-sdk/models/header_block_styles.rb', line 21 def block_padding_left @block_padding_left end |
#block_padding_right ⇒ Object
Returns the value of attribute block_padding_right.
23 24 25 |
# File 'lib/klaviyo-api-sdk/models/header_block_styles.rb', line 23 def block_padding_right @block_padding_right end |
#block_padding_top ⇒ Object
Returns the value of attribute block_padding_top.
25 26 27 |
# File 'lib/klaviyo-api-sdk/models/header_block_styles.rb', line 25 def block_padding_top @block_padding_top end |
#border_color ⇒ Object
Returns the value of attribute border_color.
27 28 29 |
# File 'lib/klaviyo-api-sdk/models/header_block_styles.rb', line 27 def border_color @border_color end |
#border_radius ⇒ Object
Returns the value of attribute border_radius.
29 30 31 |
# File 'lib/klaviyo-api-sdk/models/header_block_styles.rb', line 29 def border_radius @border_radius end |
#border_style ⇒ Object
Border style.
32 33 34 |
# File 'lib/klaviyo-api-sdk/models/header_block_styles.rb', line 32 def border_style @border_style end |
#border_width ⇒ Object
Returns the value of attribute border_width.
34 35 36 |
# File 'lib/klaviyo-api-sdk/models/header_block_styles.rb', line 34 def border_width @border_width end |
#color ⇒ Object
Returns the value of attribute color.
36 37 38 |
# File 'lib/klaviyo-api-sdk/models/header_block_styles.rb', line 36 def color @color end |
#desktop_layout ⇒ Object
Header block desktop layout.
39 40 41 |
# File 'lib/klaviyo-api-sdk/models/header_block_styles.rb', line 39 def desktop_layout @desktop_layout end |
#font_family ⇒ Object
Returns the value of attribute font_family.
41 42 43 |
# File 'lib/klaviyo-api-sdk/models/header_block_styles.rb', line 41 def font_family @font_family end |
#font_size ⇒ Object
Returns the value of attribute font_size.
43 44 45 |
# File 'lib/klaviyo-api-sdk/models/header_block_styles.rb', line 43 def font_size @font_size end |
#font_style ⇒ Object
Font style.
46 47 48 |
# File 'lib/klaviyo-api-sdk/models/header_block_styles.rb', line 46 def font_style @font_style end |
#font_weight ⇒ Object
Returns the value of attribute font_weight.
48 49 50 |
# File 'lib/klaviyo-api-sdk/models/header_block_styles.rb', line 48 def font_weight @font_weight end |
#inner_padding_bottom ⇒ Object
Returns the value of attribute inner_padding_bottom.
50 51 52 |
# File 'lib/klaviyo-api-sdk/models/header_block_styles.rb', line 50 def inner_padding_bottom @inner_padding_bottom end |
#inner_padding_left ⇒ Object
Returns the value of attribute inner_padding_left.
52 53 54 |
# File 'lib/klaviyo-api-sdk/models/header_block_styles.rb', line 52 def inner_padding_left @inner_padding_left end |
#inner_padding_right ⇒ Object
Returns the value of attribute inner_padding_right.
54 55 56 |
# File 'lib/klaviyo-api-sdk/models/header_block_styles.rb', line 54 def inner_padding_right @inner_padding_right end |
#inner_padding_top ⇒ Object
Returns the value of attribute inner_padding_top.
56 57 58 |
# File 'lib/klaviyo-api-sdk/models/header_block_styles.rb', line 56 def inner_padding_top @inner_padding_top end |
#item_align ⇒ Object
Text Alignment.
59 60 61 |
# File 'lib/klaviyo-api-sdk/models/header_block_styles.rb', line 59 def item_align @item_align end |
#item_spacing ⇒ Object
Returns the value of attribute item_spacing.
61 62 63 |
# File 'lib/klaviyo-api-sdk/models/header_block_styles.rb', line 61 def item_spacing @item_spacing end |
#item_spacing_type ⇒ Object
Header block item spacing type.
64 65 66 |
# File 'lib/klaviyo-api-sdk/models/header_block_styles.rb', line 64 def item_spacing_type @item_spacing_type end |
#letter_spacing ⇒ Object
Returns the value of attribute letter_spacing.
66 67 68 |
# File 'lib/klaviyo-api-sdk/models/header_block_styles.rb', line 66 def letter_spacing @letter_spacing end |
#logo_align ⇒ Object
Text Alignment.
69 70 71 |
# File 'lib/klaviyo-api-sdk/models/header_block_styles.rb', line 69 def logo_align @logo_align end |
#logo_link_spacing ⇒ Object
Returns the value of attribute logo_link_spacing.
71 72 73 |
# File 'lib/klaviyo-api-sdk/models/header_block_styles.rb', line 71 def logo_link_spacing @logo_link_spacing end |
#mobile_layout ⇒ Object
Header block mobile layout.
74 75 76 |
# File 'lib/klaviyo-api-sdk/models/header_block_styles.rb', line 74 def mobile_layout @mobile_layout end |
#mobile_spacing ⇒ Object
Returns the value of attribute mobile_spacing.
76 77 78 |
# File 'lib/klaviyo-api-sdk/models/header_block_styles.rb', line 76 def mobile_spacing @mobile_spacing end |
#mobile_wrap ⇒ Object
Returns the value of attribute mobile_wrap.
78 79 80 |
# File 'lib/klaviyo-api-sdk/models/header_block_styles.rb', line 78 def mobile_wrap @mobile_wrap end |
#text_decoration ⇒ Object
Returns the value of attribute text_decoration.
80 81 82 |
# File 'lib/klaviyo-api-sdk/models/header_block_styles.rb', line 80 def text_decoration @text_decoration end |
#vertical_align ⇒ Object
Vertical alignment.
83 84 85 |
# File 'lib/klaviyo-api-sdk/models/header_block_styles.rb', line 83 def vertical_align @vertical_align end |
Class Method Details
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
144 145 146 |
# File 'lib/klaviyo-api-sdk/models/header_block_styles.rb', line 144 def self.acceptable_attributes attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 |
# File 'lib/klaviyo-api-sdk/models/header_block_styles.rb', line 108 def self.attribute_map { :'block_background_color' => :'block_background_color', :'block_padding_bottom' => :'block_padding_bottom', :'block_padding_left' => :'block_padding_left', :'block_padding_right' => :'block_padding_right', :'block_padding_top' => :'block_padding_top', :'border_color' => :'border_color', :'border_radius' => :'border_radius', :'border_style' => :'border_style', :'border_width' => :'border_width', :'color' => :'color', :'desktop_layout' => :'desktop_layout', :'font_family' => :'font_family', :'font_size' => :'font_size', :'font_style' => :'font_style', :'font_weight' => :'font_weight', :'inner_padding_bottom' => :'inner_padding_bottom', :'inner_padding_left' => :'inner_padding_left', :'inner_padding_right' => :'inner_padding_right', :'inner_padding_top' => :'inner_padding_top', :'item_align' => :'item_align', :'item_spacing' => :'item_spacing', :'item_spacing_type' => :'item_spacing_type', :'letter_spacing' => :'letter_spacing', :'logo_align' => :'logo_align', :'logo_link_spacing' => :'logo_link_spacing', :'mobile_layout' => :'mobile_layout', :'mobile_spacing' => :'mobile_spacing', :'mobile_wrap' => :'mobile_wrap', :'text_decoration' => :'text_decoration', :'vertical_align' => :'vertical_align' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
517 518 519 |
# File 'lib/klaviyo-api-sdk/models/header_block_styles.rb', line 517 def self.build_from_hash(attributes) new.build_from_hash(attributes) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 209 210 211 212 213 214 215 216 217 218 |
# File 'lib/klaviyo-api-sdk/models/header_block_styles.rb', line 185 def self.openapi_nullable Set.new([ :'block_background_color', :'block_padding_bottom', :'block_padding_left', :'block_padding_right', :'block_padding_top', :'border_color', :'border_radius', :'border_style', :'border_width', :'color', :'desktop_layout', :'font_family', :'font_size', :'font_style', :'font_weight', :'inner_padding_bottom', :'inner_padding_left', :'inner_padding_right', :'inner_padding_top', :'item_align', :'item_spacing', :'item_spacing_type', :'letter_spacing', :'logo_align', :'logo_link_spacing', :'mobile_layout', :'mobile_spacing', :'mobile_wrap', :'text_decoration', :'vertical_align' ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 |
# File 'lib/klaviyo-api-sdk/models/header_block_styles.rb', line 149 def self.openapi_types { :'block_background_color' => :'String', :'block_padding_bottom' => :'Integer', :'block_padding_left' => :'Integer', :'block_padding_right' => :'Integer', :'block_padding_top' => :'Integer', :'border_color' => :'String', :'border_radius' => :'Integer', :'border_style' => :'String', :'border_width' => :'Integer', :'color' => :'String', :'desktop_layout' => :'String', :'font_family' => :'String', :'font_size' => :'Integer', :'font_style' => :'String', :'font_weight' => :'String', :'inner_padding_bottom' => :'Integer', :'inner_padding_left' => :'Integer', :'inner_padding_right' => :'Integer', :'inner_padding_top' => :'Integer', :'item_align' => :'String', :'item_spacing' => :'Integer', :'item_spacing_type' => :'String', :'letter_spacing' => :'Integer', :'logo_align' => :'String', :'logo_link_spacing' => :'Integer', :'mobile_layout' => :'String', :'mobile_spacing' => :'Integer', :'mobile_wrap' => :'Boolean', :'text_decoration' => :'String', :'vertical_align' => :'String' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
467 468 469 470 471 472 473 474 475 476 477 478 479 480 481 482 483 484 485 486 487 488 489 490 491 492 493 494 495 496 497 498 499 500 |
# File 'lib/klaviyo-api-sdk/models/header_block_styles.rb', line 467 def ==(o) return true if self.equal?(o) self.class == o.class && block_background_color == o.block_background_color && block_padding_bottom == o.block_padding_bottom && block_padding_left == o.block_padding_left && block_padding_right == o.block_padding_right && block_padding_top == o.block_padding_top && border_color == o.border_color && border_radius == o.border_radius && border_style == o.border_style && border_width == o.border_width && color == o.color && desktop_layout == o.desktop_layout && font_family == o.font_family && font_size == o.font_size && font_style == o.font_style && font_weight == o.font_weight && inner_padding_bottom == o.inner_padding_bottom && inner_padding_left == o.inner_padding_left && inner_padding_right == o.inner_padding_right && inner_padding_top == o.inner_padding_top && item_align == o.item_align && item_spacing == o.item_spacing && item_spacing_type == o.item_spacing_type && letter_spacing == o.letter_spacing && logo_align == o.logo_align && logo_link_spacing == o.logo_link_spacing && mobile_layout == o.mobile_layout && mobile_spacing == o.mobile_spacing && mobile_wrap == o.mobile_wrap && text_decoration == o.text_decoration && vertical_align == o.vertical_align end |
#_deserialize(type, value) ⇒ Object
Deserializes the data based on type
548 549 550 551 552 553 554 555 556 557 558 559 560 561 562 563 564 565 566 567 568 569 570 571 572 573 574 575 576 577 578 579 580 581 582 583 584 585 |
# File 'lib/klaviyo-api-sdk/models/header_block_styles.rb', line 548 def _deserialize(type, value) case type.to_sym when :Time Time.parse(value) when :Date Date.parse(value) when :String value.to_s when :Integer value.to_i when :Float value.to_f when :Boolean if value.to_s =~ /\A(true|t|yes|y|1)\z/i true else false end when :Object # generic object (usually a Hash), return directly value when /\AArray<(?<inner_type>.+)>\z/ inner_type = Regexp.last_match[:inner_type] value.map { |v| _deserialize(inner_type, v) } when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/ k_type = Regexp.last_match[:k_type] v_type = Regexp.last_match[:v_type] {}.tap do |hash| value.each do |k, v| hash[_deserialize(k_type, k)] = _deserialize(v_type, v) end end else # model # models (e.g. Pet) or oneOf klass = KlaviyoAPI.const_get(type) klass.respond_to?(:openapi_one_of) ? klass.build(value) : klass.build_from_hash(value) end end |
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value
619 620 621 622 623 624 625 626 627 628 629 630 631 |
# File 'lib/klaviyo-api-sdk/models/header_block_styles.rb', line 619 def _to_hash(value) if value.is_a?(Array) value.compact.map { |v| _to_hash(v) } elsif value.is_a?(Hash) {}.tap do |hash| value.each { |k, v| hash[k] = _to_hash(v) } end elsif value.respond_to? :to_hash value.to_hash else value end end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
524 525 526 527 528 529 530 531 532 533 534 535 536 537 538 539 540 541 542 |
# File 'lib/klaviyo-api-sdk/models/header_block_styles.rb', line 524 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) self.class.openapi_types.each_pair do |key, type| if attributes[self.class.attribute_map[key]].nil? && self.class.openapi_nullable.include?(key) self.send("#{key}=", nil) elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) self.send("#{key}=", attributes[self.class.attribute_map[key]].map { |v| _deserialize($1, v) }) end elsif !attributes[self.class.attribute_map[key]].nil? self.send("#{key}=", _deserialize(type, attributes[self.class.attribute_map[key]])) end end self end |
#eql?(o) ⇒ Boolean
504 505 506 |
# File 'lib/klaviyo-api-sdk/models/header_block_styles.rb', line 504 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
510 511 512 |
# File 'lib/klaviyo-api-sdk/models/header_block_styles.rb', line 510 def hash [block_background_color, block_padding_bottom, block_padding_left, block_padding_right, block_padding_top, border_color, border_radius, border_style, border_width, color, desktop_layout, font_family, font_size, font_style, font_weight, inner_padding_bottom, inner_padding_left, inner_padding_right, inner_padding_top, item_align, item_spacing, item_spacing_type, letter_spacing, logo_align, logo_link_spacing, mobile_layout, mobile_spacing, mobile_wrap, text_decoration, vertical_align].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
358 359 360 361 |
# File 'lib/klaviyo-api-sdk/models/header_block_styles.rb', line 358 def list_invalid_properties invalid_properties = Array.new invalid_properties end |
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility)
595 596 597 |
# File 'lib/klaviyo-api-sdk/models/header_block_styles.rb', line 595 def to_body to_hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
601 602 603 604 605 606 607 608 609 610 611 612 613 |
# File 'lib/klaviyo-api-sdk/models/header_block_styles.rb', line 601 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
589 590 591 |
# File 'lib/klaviyo-api-sdk/models/header_block_styles.rb', line 589 def to_s to_hash.to_s end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
365 366 367 368 369 370 371 372 373 374 375 376 377 378 379 380 381 382 383 |
# File 'lib/klaviyo-api-sdk/models/header_block_styles.rb', line 365 def valid? border_style_validator = EnumAttributeValidator.new('String', ["dashed", "dotted", "groove", "inset", "none", "outset", "ridge", "solid"]) return false unless border_style_validator.valid?(@border_style) desktop_layout_validator = EnumAttributeValidator.new('String', ["centered", "inline", "links", "stacked"]) return false unless desktop_layout_validator.valid?(@desktop_layout) font_style_validator = EnumAttributeValidator.new('String', ["italic", "normal"]) return false unless font_style_validator.valid?(@font_style) item_align_validator = EnumAttributeValidator.new('String', ["center", "left", "right"]) return false unless item_align_validator.valid?(@item_align) item_spacing_type_validator = EnumAttributeValidator.new('String', ["auto", "manual"]) return false unless item_spacing_type_validator.valid?(@item_spacing_type) logo_align_validator = EnumAttributeValidator.new('String', ["center", "left", "right"]) return false unless logo_align_validator.valid?(@logo_align) mobile_layout_validator = EnumAttributeValidator.new('String', ["inline", "links", "links-stacked", "logo-stacked", "stacked"]) return false unless mobile_layout_validator.valid?(@mobile_layout) vertical_align_validator = EnumAttributeValidator.new('String', ["baseline", "bottom", "middle", "top"]) return false unless vertical_align_validator.valid?(@vertical_align) true end |